@@ -1,5 +1,24 @@
 var NAVTREEINDEX10 =
 {
+"legacymidiccout_2source_2version_8h.html#aa863825ce130d257c1ba798e4e639d67":[3,0,273,6],
+"legacymidiccout_2source_2version_8h.html#ab3aa50bfa1df9fe473bf9202c2bff0cd":[3,0,273,3],
+"legacymidiccout_2source_2version_8h.html#adb58dbe9424bfe0a2e594a5e6399c3e2":[3,0,273,0],
+"logevents_8h.html":[3,0,48],
+"logevents_8h.html#a2cd9d1eb177a484140e69f47afd55568":[3,0,48,4],
+"logevents_8h.html#a3ff8f70a8e7742a391579647a740b0cc":[3,0,48,17],
+"logevents_8h.html#a53f9f6500f910d315237711949181611":[3,0,48,20],
+"logevents_8h.html#a553a124e1d5855773c74cb5561dec040":[3,0,48,13],
+"logevents_8h.html#a75fdd038db87810b8297b0289230a80e":[3,0,48,8],
+"logevents_8h.html#a779b90f0bd4c9d431184500eff9a3a83":[3,0,48,21],
+"logevents_8h.html#a79bbc9918c2c113a446503e386a2747c":[3,0,48,6],
+"logevents_8h.html#a7f0a527dddc93495221e8603c29df7f9":[3,0,48,7],
+"logevents_8h.html#a96fad55b3f5adf08c39e4c877cf185e3":[3,0,48,14],
+"logevents_8h.html#a987df35cd56a96cf7e2c4e63ffb0e38d":[3,0,48,3],
+"logevents_8h.html#aa4a759ebcb6194d2d4a86b05f4889388":[3,0,48,12],
+"logevents_8h.html#aab4457bfe7f68d261eb606601c698cf0":[3,0,48,5],
+"logevents_8h.html#aac9b17824a28a84dfef658574649e37c":[3,0,48,11],
+"logevents_8h.html#aacd2cf60f504e45efada9aec028ee3cd":[3,0,48,2],
+"logevents_8h.html#ad0f48101b43e62a857a56e15651ee234":[3,0,48,18],
 "logevents_8h.html#ad535885ce8f80d2d5eddc5423e73393e":[3,0,48,10],
 "logevents_8h.html#ad76f3128fb1f4ed00962293d7839e901":[3,0,48,9],
 "logevents_8h.html#adfcd222e817c0d2841fc4adaf1353850":[3,0,48,1],
@@ -7,7 +26,7 @@ var NAVTREEINDEX10 =
 "logevents_8h.html#aeb4f36db01bd128c7afeac5889dac311":[3,0,48,16],
 "logevents_8h.html#afc507aa9af80c3191815907e53ecd31c":[3,0,48,19],
 "logevents_8h.html#afc84f29132b630b33d341d0769a66d46":[3,0,48,22],
-"logevents_8h.html#afc84f29132b630b33d341d0769a66d46a017971e2dcae41d78c3e0892d77fa9ae":[3,0,48,22,171],
+"logevents_8h.html#afc84f29132b630b33d341d0769a66d46a017971e2dcae41d78c3e0892d77fa9ae":[3,0,48,22,174],
 "logevents_8h.html#afc84f29132b630b33d341d0769a66d46a026bc622b5b78782da47ea94c0b3867d":[3,0,48,22,70],
 "logevents_8h.html#afc84f29132b630b33d341d0769a66d46a02f2c32c63ec29184beffe72dad2d9fe":[3,0,48,22,18],
 "logevents_8h.html#afc84f29132b630b33d341d0769a66d46a0575a52841d1413897ba65aa355f3169":[3,0,48,22,42],
@@ -20,6 +39,7 @@ var NAVTREEINDEX10 =
 "logevents_8h.html#afc84f29132b630b33d341d0769a66d46a0d6e5bf3a4de523c42bb71f5c31ff7d0":[3,0,48,22,130],
 "logevents_8h.html#afc84f29132b630b33d341d0769a66d46a0e0c10ec27ae314ef6dafa6ded605ceb":[3,0,48,22,136],
 "logevents_8h.html#afc84f29132b630b33d341d0769a66d46a0f126be06bac7a5f43c0f3c32bd6768f":[3,0,48,22,103],
+"logevents_8h.html#afc84f29132b630b33d341d0769a66d46a0f7f5adeb3173c19e571735678d68018":[3,0,48,22,170],
 "logevents_8h.html#afc84f29132b630b33d341d0769a66d46a10780bd74e20d8bf0c31b100dbe7dde5":[3,0,48,22,159],
 "logevents_8h.html#afc84f29132b630b33d341d0769a66d46a11da6aa621784b650ffc431bb7e61562":[3,0,48,22,83],
 "logevents_8h.html#afc84f29132b630b33d341d0769a66d46a147943e18caa0f6f5fd9f6123e590715":[3,0,48,22,154],
@@ -108,6 +128,7 @@ var NAVTREEINDEX10 =
 "logevents_8h.html#afc84f29132b630b33d341d0769a66d46a9d91a480296e3378e7235199aeb85f21":[3,0,48,22,118],
 "logevents_8h.html#afc84f29132b630b33d341d0769a66d46aa26196d83bcafdaa6dae199297379046":[3,0,48,22,131],
 "logevents_8h.html#afc84f29132b630b33d341d0769a66d46aa392ddebd5fded35801d16213835d80b":[3,0,48,22,138],
+"logevents_8h.html#afc84f29132b630b33d341d0769a66d46aa3f3a2c766cf6c485962c1dfb01d00d3":[3,0,48,22,171],
 "logevents_8h.html#afc84f29132b630b33d341d0769a66d46aa493a95d6ef3a58d65dac2896a1f9e3e":[3,0,48,22,54],
 "logevents_8h.html#afc84f29132b630b33d341d0769a66d46aa64318f163741a2b46e6d6be3919ac39":[3,0,48,22,150],
 "logevents_8h.html#afc84f29132b630b33d341d0769a66d46aa6e9ee7941dbfaa2697fb36147470c67":[3,0,48,22,102],
@@ -131,6 +152,7 @@ var NAVTREEINDEX10 =
 "logevents_8h.html#afc84f29132b630b33d341d0769a66d46abdde3c71e26acc95d638c4055f9f8816":[3,0,48,22,69],
 "logevents_8h.html#afc84f29132b630b33d341d0769a66d46abff4951b11cabb42cc2b0c1e598fa2c0":[3,0,48,22,52],
 "logevents_8h.html#afc84f29132b630b33d341d0769a66d46ac259cd881ad45c5f84417ae2b2297461":[3,0,48,22,23],
+"logevents_8h.html#afc84f29132b630b33d341d0769a66d46ac27418bea5f0894399402e1c67d9d73f":[3,0,48,22,172],
 "logevents_8h.html#afc84f29132b630b33d341d0769a66d46ac28f350d90314b1c5701947ef08c0229":[3,0,48,22,15],
 "logevents_8h.html#afc84f29132b630b33d341d0769a66d46ac378b712a17479518fae523d789378c0":[3,0,48,22,161],
 "logevents_8h.html#afc84f29132b630b33d341d0769a66d46ac488f17e2ed31ee0ab63781b95a1e578":[3,0,48,22,19],
@@ -163,7 +185,7 @@ var NAVTREEINDEX10 =
 "logevents_8h.html#afc84f29132b630b33d341d0769a66d46ae60e595aa437c08884e7ece02c3d158d":[3,0,48,22,164],
 "logevents_8h.html#afc84f29132b630b33d341d0769a66d46ae7f3dc2a418f6ea1bab85a972eda397e":[3,0,48,22,50],
 "logevents_8h.html#afc84f29132b630b33d341d0769a66d46ae9fc5c75cff407d888117c27e2656eb9":[3,0,48,22,148],
-"logevents_8h.html#afc84f29132b630b33d341d0769a66d46aea5987edd85d670fe157a6bde424efb9":[3,0,48,22,170],
+"logevents_8h.html#afc84f29132b630b33d341d0769a66d46aea5987edd85d670fe157a6bde424efb9":[3,0,48,22,173],
 "logevents_8h.html#afc84f29132b630b33d341d0769a66d46aeb5b2e4c0904288f6fdd62b96bbf40e0":[3,0,48,22,140],
 "logevents_8h.html#afc84f29132b630b33d341d0769a66d46aeb6f321b4804b03d006eb11118742676":[3,0,48,22,41],
 "logevents_8h.html#afc84f29132b630b33d341d0769a66d46aeccac95af4f90b8e1c75a232cc79fad8":[3,0,48,22,98],
@@ -227,27 +249,5 @@ var NAVTREEINDEX10 =
 "mdaDeEsserController_8cpp.html":[3,0,72],
 "mdaDeEsserController_8h.html":[3,0,73],
 "mdaDeEsserProcessor_8cpp.html":[3,0,74],
-"mdaDeEsserProcessor_8h.html":[3,0,75],
-"mdaDegradeController_8cpp.html":[3,0,76],
-"mdaDegradeController_8h.html":[3,0,77],
-"mdaDegradeProcessor_8cpp.html":[3,0,78],
-"mdaDegradeProcessor_8h.html":[3,0,79],
-"mdaDelayController_8cpp.html":[3,0,80],
-"mdaDelayController_8h.html":[3,0,81],
-"mdaDelayProcessor_8cpp.html":[3,0,82],
-"mdaDelayProcessor_8h.html":[3,0,83],
-"mdaDetuneController_8cpp.html":[3,0,84],
-"mdaDetuneController_8h.html":[3,0,85],
-"mdaDetuneProcessor_8cpp.html":[3,0,86],
-"mdaDetuneProcessor_8cpp.html#aa893c2c75e0d3d0258e09fbd136ffaed":[3,0,86,0],
-"mdaDetuneProcessor_8h.html":[3,0,87],
-"mdaDitherController_8cpp.html":[3,0,88],
-"mdaDitherController_8h.html":[3,0,89],
-"mdaDitherProcessor_8cpp.html":[3,0,90],
-"mdaDitherProcessor_8h.html":[3,0,91],
-"mdaDubDelayController_8cpp.html":[3,0,92],
-"mdaDubDelayController_8h.html":[3,0,93],
-"mdaDubDelayProcessor_8cpp.html":[3,0,94],
-"mdaDubDelayProcessor_8h.html":[3,0,95],
-"mdaDynamicsController_8cpp.html":[3,0,100]
+"mdaDeEsserProcessor_8h.html":[3,0,75]
 };
