@@ -1,5 +1,27 @@
 var NAVTREEINDEX11 =
 {
+"mdaDegradeController_8cpp.html":[3,0,76],
+"mdaDegradeController_8h.html":[3,0,77],
+"mdaDegradeProcessor_8cpp.html":[3,0,78],
+"mdaDegradeProcessor_8h.html":[3,0,79],
+"mdaDelayController_8cpp.html":[3,0,80],
+"mdaDelayController_8h.html":[3,0,81],
+"mdaDelayProcessor_8cpp.html":[3,0,82],
+"mdaDelayProcessor_8h.html":[3,0,83],
+"mdaDetuneController_8cpp.html":[3,0,84],
+"mdaDetuneController_8h.html":[3,0,85],
+"mdaDetuneProcessor_8cpp.html":[3,0,86],
+"mdaDetuneProcessor_8cpp.html#aa893c2c75e0d3d0258e09fbd136ffaed":[3,0,86,0],
+"mdaDetuneProcessor_8h.html":[3,0,87],
+"mdaDitherController_8cpp.html":[3,0,88],
+"mdaDitherController_8h.html":[3,0,89],
+"mdaDitherProcessor_8cpp.html":[3,0,90],
+"mdaDitherProcessor_8h.html":[3,0,91],
+"mdaDubDelayController_8cpp.html":[3,0,92],
+"mdaDubDelayController_8h.html":[3,0,93],
+"mdaDubDelayProcessor_8cpp.html":[3,0,94],
+"mdaDubDelayProcessor_8h.html":[3,0,95],
+"mdaDynamicsController_8cpp.html":[3,0,100],
 "mdaDynamicsController_8h.html":[3,0,101],
 "mdaDynamicsProcessor_8cpp.html":[3,0,102],
 "mdaDynamicsProcessor_8h.html":[3,0,103],
@@ -124,18 +146,18 @@ var NAVTREEINDEX11 =
 "mdaTrackerProcessor_8h.html":[3,0,196],
 "mdafactory_8cpp.html":[3,0,109],
 "mdafactory_8cpp.html#a7a6b11a55e9b38681d4d7941f3cd28d6":[3,0,109,0],
-"namespaceSteinberg_1_1HostChecker.html":[1,0,0,2],
 "namespaceSteinberg_1_1HostChecker.html":[2,0,0,2],
-"namespaceSteinberg_1_1Panner.html":[1,0,0,3],
+"namespaceSteinberg_1_1HostChecker.html":[1,0,0,2],
 "namespaceSteinberg_1_1Panner.html":[2,0,0,3],
-"namespaceSteinberg_1_1Vst_1_1AudioHost.html":[2,0,0,1,3],
+"namespaceSteinberg_1_1Panner.html":[1,0,0,3],
 "namespaceSteinberg_1_1Vst_1_1AudioHost.html":[1,0,0,1,3],
-"namespaceSteinberg_1_1Vst_1_1EditorHost.html":[1,0,0,1,4],
+"namespaceSteinberg_1_1Vst_1_1AudioHost.html":[2,0,0,1,3],
 "namespaceSteinberg_1_1Vst_1_1EditorHost.html":[2,0,0,1,4],
+"namespaceSteinberg_1_1Vst_1_1EditorHost.html":[1,0,0,1,4],
 "namespaceSteinberg_1_1Vst_1_1LegacyMIDICCOut.html":[2,0,0,1,0],
 "namespaceSteinberg_1_1Vst_1_1LegacyMIDICCOut.html":[1,0,0,1,0],
-"namespaceSteinberg_1_1Vst_1_1NoteExpressionSynth.html":[2,0,0,1,2],
 "namespaceSteinberg_1_1Vst_1_1NoteExpressionSynth.html":[1,0,0,1,2],
+"namespaceSteinberg_1_1Vst_1_1NoteExpressionSynth.html":[2,0,0,1,2],
 "namespaceSteinberg_1_1Vst_1_1mda.html":[2,0,0,1,1],
 "namespaceSteinberg_1_1Vst_1_1mda.html":[1,0,0,1,1],
 "namespacemembers.html":[1,1,0],
@@ -227,27 +249,5 @@ var NAVTREEINDEX11 =
 "note__expression__text_2source_2plugentry_8cpp.html#a53ac779212edf501532da8751b27572c":[3,0,241,3],
 "note__expression__text_2source_2plugentry_8cpp.html#a580d3236cf2654394fd9dda85651efc0":[3,0,241,0],
 "note__expression__text_2source_2plugentry_8cpp.html#a7668929ac981fa3b7c508e7578a3e357":[3,0,241,2],
-"note__expression__text_2source_2plugentry_8cpp.html#ac09825b56d6a6e6099918f3b532a58b2":[3,0,241,4],
-"note__expression__text_2source_2plugentry_8cpp.html#af95bfaaff460967d112f7e5db4232ea2":[3,0,241,5],
-"note__expression__text_2source_2plugparamids_8h.html":[3,0,247],
-"note__expression__text_2source_2plugparamids_8h.html#a05589fbab0657f08285ebdfe93f5ec9eaf4e2f2cc267406eb8c152ecab32fd088":[3,0,247,0],
-"note__expression__text_2source_2version_8h.html":[3,0,276],
-"note__expression__text_2source_2version_8h.html#a642cf2d637621b344ca826ba26e3da52":[3,0,276,2],
-"note__expression__text_2source_2version_8h.html#a7b9ca76cb4cc59f027ddabbe5f3f2118":[3,0,276,5],
-"note__expression__text_2source_2version_8h.html#a9278205f41909b317803db604ed1075d":[3,0,276,1],
-"note__expression__text_2source_2version_8h.html#a959cc5c14daa39d176d88fffd211aa6c":[3,0,276,4],
-"note__expression__text_2source_2version_8h.html#aa863825ce130d257c1ba798e4e639d67":[3,0,276,6],
-"note__expression__text_2source_2version_8h.html#ab3aa50bfa1df9fe473bf9202c2bff0cd":[3,0,276,3],
-"note__expression__text_2source_2version_8h.html#adb58dbe9424bfe0a2e594a5e6399c3e2":[3,0,276,0],
-"note__touch__controller_8cpp.html":[3,0,205],
-"note__touch__controller_8cpp.html#a03663db7e11721953b32b303ebb4d808":[3,0,205,0],
-"note__touch__controller_8cpp.html#aa2fb66f34e187ffb9a0eb6a9727a820c":[3,0,205,1],
-"note__touch__controller_8h.html":[3,0,206],
-"pages.html":[],
-"panner_2source_2plugcontroller_8cpp.html":[3,0,231],
-"parameterchangescheck_8cpp.html":[3,0,207],
-"parameterchangescheck_8h.html":[3,0,208],
-"pitchnames_2source_2factory_8cpp.html":[3,0,39],
-"pitchnames_2source_2factory_8cpp.html#a580d3236cf2654394fd9dda85651efc0":[3,0,39,0],
-"pitchnames_2source_2version_8h.html":[3,0,277]
+"note__expression__text_2source_2plugentry_8cpp.html#ac09825b56d6a6e6099918f3b532a58b2":[3,0,241,4]
 };
