@@ -1,5 +1,27 @@
 var NAVTREEINDEX12 =
 {
+"note__expression__text_2source_2plugentry_8cpp.html#af95bfaaff460967d112f7e5db4232ea2":[3,0,241,5],
+"note__expression__text_2source_2plugparamids_8h.html":[3,0,247],
+"note__expression__text_2source_2plugparamids_8h.html#a05589fbab0657f08285ebdfe93f5ec9eaf4e2f2cc267406eb8c152ecab32fd088":[3,0,247,0],
+"note__expression__text_2source_2version_8h.html":[3,0,276],
+"note__expression__text_2source_2version_8h.html#a642cf2d637621b344ca826ba26e3da52":[3,0,276,2],
+"note__expression__text_2source_2version_8h.html#a7b9ca76cb4cc59f027ddabbe5f3f2118":[3,0,276,5],
+"note__expression__text_2source_2version_8h.html#a9278205f41909b317803db604ed1075d":[3,0,276,1],
+"note__expression__text_2source_2version_8h.html#a959cc5c14daa39d176d88fffd211aa6c":[3,0,276,4],
+"note__expression__text_2source_2version_8h.html#aa863825ce130d257c1ba798e4e639d67":[3,0,276,6],
+"note__expression__text_2source_2version_8h.html#ab3aa50bfa1df9fe473bf9202c2bff0cd":[3,0,276,3],
+"note__expression__text_2source_2version_8h.html#adb58dbe9424bfe0a2e594a5e6399c3e2":[3,0,276,0],
+"note__touch__controller_8cpp.html":[3,0,205],
+"note__touch__controller_8cpp.html#a03663db7e11721953b32b303ebb4d808":[3,0,205,0],
+"note__touch__controller_8cpp.html#aa2fb66f34e187ffb9a0eb6a9727a820c":[3,0,205,1],
+"note__touch__controller_8h.html":[3,0,206],
+"pages.html":[],
+"panner_2source_2plugcontroller_8cpp.html":[3,0,231],
+"parameterchangescheck_8cpp.html":[3,0,207],
+"parameterchangescheck_8h.html":[3,0,208],
+"pitchnames_2source_2factory_8cpp.html":[3,0,39],
+"pitchnames_2source_2factory_8cpp.html#a580d3236cf2654394fd9dda85651efc0":[3,0,39,0],
+"pitchnames_2source_2version_8h.html":[3,0,277],
 "pitchnames_2source_2version_8h.html#a642cf2d637621b344ca826ba26e3da52":[3,0,277,2],
 "pitchnames_2source_2version_8h.html#a7b9ca76cb4cc59f027ddabbe5f3f2118":[3,0,277,5],
 "pitchnames_2source_2version_8h.html#a9278205f41909b317803db604ed1075d":[3,0,277,1],
@@ -227,23 +249,5 @@ var NAVTREEINDEX12 =
 "syncdelayids_8h.html":[3,0,259],
 "syncdelayids_8h.html#aaf105ae5beaca1dee30ae54530691fcea57a371feb983eb7350939ef1aab87090":[3,0,259,1],
 "syncdelayids_8h.html#aaf105ae5beaca1dee30ae54530691fcea7d4228d4da0ae0131ef1783f79526104":[3,0,259,0],
-"syncdelayprocessor_8cpp.html":[3,0,260],
-"syncdelayprocessor_8h.html":[3,0,261],
-"syncdelayversion_8h.html":[3,0,262],
-"syncdelayversion_8h.html#a642cf2d637621b344ca826ba26e3da52":[3,0,262,2],
-"syncdelayversion_8h.html#a7b9ca76cb4cc59f027ddabbe5f3f2118":[3,0,262,5],
-"syncdelayversion_8h.html#a9278205f41909b317803db604ed1075d":[3,0,262,1],
-"syncdelayversion_8h.html#a959cc5c14daa39d176d88fffd211aa6c":[3,0,262,4],
-"syncdelayversion_8h.html#aa863825ce130d257c1ba798e4e639d67":[3,0,262,6],
-"syncdelayversion_8h.html#ab3aa50bfa1df9fe473bf9202c2bff0cd":[3,0,262,3],
-"syncdelayversion_8h.html#adb58dbe9424bfe0a2e594a5e6399c3e2":[3,0,262,0],
-"testsuite_8h.html":[3,0,263],
-"validator_2source_2usediids_8cpp.html":[3,0,266],
-"validator_8cpp.html":[3,0,267],
-"validator_8h.html":[3,0,268],
-"voicebase_8h.html":[3,0,280],
-"voicebase_8h.html#a571d51360926bac393fcf9c972a5ffa8":[3,0,280,1],
-"voiceprocessor_8h.html":[3,0,281],
-"voiceprocessor_8h.html#a571d51360926bac393fcf9c972a5ffa8":[3,0,281,2],
-"voiceprocessor_8h.html#ad02c1f770ebad9d3f30b3f046ebcea00":[3,0,281,3]
+"syncdelayprocessor_8cpp.html":[3,0,260]
 };
