@@ -81,10 +81,14 @@ var searchData=
   ['againuimessagecontroller_2eh',['againuimessagecontroller.h',['../againuimessagecontroller_8h.html',1,'']]],
   ['againvst3category',['AGainVST3Category',['../againcids_8h.html#a379f45d1d3bc07e8916d65b9b234c936',1,'againcids.h']]],
   ['againwithsidechain',['AGainWithSideChain',['../classSteinberg_1_1Vst_1_1AGainWithSideChain.html',1,'Steinberg::Vst']]],
+  ['alignedalloc_2eh',['alignedalloc.h',['../../vstsdk/alignedalloc_8h.html',1,'']]],
+  ['alignment',['alignment',['../../vstsdk/structSteinberg_1_1Vst_1_1DataExchangeHandler_1_1Config.html#ae60a9b82d7097942c8d2e3a5d434a897',1,'Steinberg::Vst::DataExchangeHandler::Config']]],
   ['allnotesoff',['allNotesOff',['../classSteinberg_1_1Vst_1_1mda_1_1PianoProcessor.html#aec246739838d962211ec3124c7f26ff3',1,'Steinberg::Vst::mda::PianoProcessor']]],
   ['allocatemessage',['allocateMessage',['../../vstsdk/classSteinberg_1_1Vst_1_1ComponentBase.html#aae7bbbf07353224bb0ba77a091b87d33',1,'Steinberg::Vst::AudioEffect']]],
   ['allocationerror',['allocationError',['../../vstsdk/classSteinberg_1_1MemoryStream.html#a1bfaf9acdd950aac257085ff792dfedb',1,'Steinberg::MemoryStream']]],
   ['allocparameters',['allocParameters',['../classSteinberg_1_1Vst_1_1mda_1_1Processor.html#aa0717eb65af14a8ec9de39bbc5ba5037',1,'Steinberg::Vst::mda::Processor::allocParameters()'],['../classSteinberg_1_1Vst_1_1mda_1_1SampleAccurateBaseProcessor.html#a009053d0bf0fe9fb13b29fc3155e8b8c',1,'Steinberg::Vst::mda::SampleAccurateBaseProcessor::allocParameters()']]],
+  ['allowallocatesize',['allowAllocateSize',['../../vstsdk/structSteinberg_1_1Vst_1_1IDataExchangeHandlerHost.html#a34e686050e3477b842a5589d171a57be',1,'Steinberg::Vst::IDataExchangeHandlerHost']]],
+  ['allowqueuelistresize',['allowQueueListResize',['../../vstsdk/structSteinberg_1_1Vst_1_1IDataExchangeHandlerHost.html#ad0fba34c6a580a12c6bbd572c7951f01',1,'Steinberg::Vst::IDataExchangeHandlerHost']]],
   ['ambiencecontroller',['AmbienceController',['../classSteinberg_1_1Vst_1_1mda_1_1AmbienceController.html',1,'Steinberg::Vst::mda']]],
   ['ambiencecontroller',['AmbienceController',['../classSteinberg_1_1Vst_1_1mda_1_1AmbienceController.html#a16a6af7c0cdae25064c2193b1bb611d1',1,'Steinberg::Vst::mda::AmbienceController']]],
   ['ambienceprocessor',['AmbienceProcessor',['../classSteinberg_1_1Vst_1_1mda_1_1AmbienceProcessor.html',1,'Steinberg::Vst::mda']]],
@@ -119,17 +123,17 @@ var searchData=
   ['aucocoaview_2eh',['aucocoaview.h',['../../vstsdk/aucocoaview_8h.html',1,'']]],
   ['aucocoaview_2emm',['aucocoaview.mm',['../../vstsdk/aucocoaview_8mm.html',1,'']]],
   ['audio_5fbuffer',['AUDIO_BUFFER',['../logevents_8h.html#a987df35cd56a96cf7e2c4e63ffb0e38d',1,'logevents.h']]],
-  ['audiobuffer',['AudioBuffer',['../../vstsdk/classSteinberg_1_1Vst_1_1AudioBuffer.html',1,'Steinberg::Vst']]],
   ['audiobuffer',['AudioBuffer',['../../vstsdk/classSteinberg_1_1Vst_1_1AudioBuffer.html#a53af24182f3165ed15b4f434d7088b53',1,'Steinberg::Vst::AudioBuffer']]],
+  ['audiobuffer',['AudioBuffer',['../../vstsdk/classSteinberg_1_1Vst_1_1AudioBuffer.html',1,'Steinberg::Vst']]],
   ['audiobuffer_3c_20t_20_3e',['AudioBuffer&lt; T &gt;',['../../vstsdk/classSteinberg_1_1Vst_1_1AudioBuffer.html',1,'Steinberg::Vst']]],
   ['audiobuffers_2eh',['audiobuffers.h',['../../vstsdk/audiobuffers_8h.html',1,'']]],
-  ['audiobus',['AudioBus',['../../vstsdk/classSteinberg_1_1Vst_1_1AudioBus.html#aa88e9bd8e9d969a00f0bd035a03c359f',1,'Steinberg::Vst::AudioBus']]],
   ['audiobus',['AudioBus',['../../vstsdk/classSteinberg_1_1Vst_1_1AudioBus.html',1,'Steinberg::Vst']]],
+  ['audiobus',['AudioBus',['../../vstsdk/classSteinberg_1_1Vst_1_1AudioBus.html#aa88e9bd8e9d969a00f0bd035a03c359f',1,'Steinberg::Vst::AudioBus']]],
   ['audiobusbuffers',['AudioBusBuffers',['../../vstinterfaces/structSteinberg_1_1Vst_1_1AudioBusBuffers.html#a9b1b17da17d0a50b82b03273caae2b8b',1,'Steinberg::Vst::AudioBusBuffers']]],
   ['audiobusbuffers',['AudioBusBuffers',['../../vstinterfaces/structSteinberg_1_1Vst_1_1AudioBusBuffers.html',1,'Steinberg::Vst']]],
   ['audiodefaults',['AudioDefaults',['../../vstsdk/classSteinberg_1_1Vst_1_1TestEnh.html#aeeab75fa34b77d026422bf02ea2a7716',1,'Steinberg::Vst::TestEnh']]],
-  ['audioeffect',['AudioEffect',['../../vstsdk/classSteinberg_1_1Vst_1_1AudioEffect.html#a491f4bb6a5f726c520667832df4b9a14',1,'Steinberg::Vst::AudioEffect::AudioEffect()'],['../../vstsdk/classSteinberg_1_1Vst_1_1TestEnh.html#a13adc72f47daf6dc87f28e58b52c72d0',1,'Steinberg::Vst::TestEnh::audioEffect()']]],
   ['audioeffect',['AudioEffect',['../../vstsdk/classSteinberg_1_1Vst_1_1AudioEffect.html',1,'Steinberg::Vst']]],
+  ['audioeffect',['AudioEffect',['../../vstsdk/classSteinberg_1_1Vst_1_1AudioEffect.html#a491f4bb6a5f726c520667832df4b9a14',1,'Steinberg::Vst::AudioEffect::AudioEffect()'],['../../vstsdk/classSteinberg_1_1Vst_1_1TestEnh.html#a13adc72f47daf6dc87f28e58b52c72d0',1,'Steinberg::Vst::TestEnh::audioEffect()']]],
   ['audiohost_2ecpp',['audiohost.cpp',['../audiohost_8cpp.html',1,'']]],
   ['audiohost_2eh',['audiohost.h',['../audiohost_8h.html',1,'']]],
   ['audioinputs',['audioInputs',['../../vstsdk/classSteinberg_1_1Vst_1_1Component.html#a3bb91eeb91df8bc7446713244ae11bac',1,'Steinberg::Vst::AudioEffect::audioInputs()'],['../../vstsdk/classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a4918c0fce4a78d193457bcca2a6d4cca',1,'Steinberg::Vst::SingleComponentEffect::audioInputs()']]],
@@ -143,6 +147,6 @@ var searchData=
   ['auwrapper_2emm',['auwrapper.mm',['../../vstsdk/auwrapper_8mm.html',1,'']]],
   ['factory_2ecpp',['factory.cpp',['../adelay_2source_2factory_8cpp.html',1,'']]],
   ['usediids_2ecpp',['usediids.cpp',['../audiohost_2source_2usediids_8cpp.html',1,'']]],
-  ['version_2eh',['version.h',['../adelay_2source_2version_8h.html',1,'']]],
-  ['version_2eh',['version.h',['../again_2source_2version_8h.html',1,'']]]
+  ['version_2eh',['version.h',['../again_2source_2version_8h.html',1,'']]],
+  ['version_2eh',['version.h',['../adelay_2source_2version_8h.html',1,'']]]
 ];
