@@ -49,7 +49,7 @@ var searchData=
   ['lin2',['lin2',['../classSteinberg_1_1Vst_1_1mda_1_1DegradeProcessor.html#a2b14e4cce2142c4ff74ceb653cee8c13',1,'Steinberg::Vst::mda::DegradeProcessor']]],
   ['ll',['ll',['../classSteinberg_1_1Vst_1_1mda_1_1SplitterProcessor.html#a4b4c1671e848c3debb26cc1fd9c0de77',1,'Steinberg::Vst::mda::SplitterProcessor']]],
   ['llev',['llev',['../classSteinberg_1_1Vst_1_1mda_1_1LeslieProcessor.html#ade24b85bbc1d40c8b9dd564baabd809d',1,'Steinberg::Vst::mda::LeslieProcessor']]],
-  ['lmin',['lmin',['../classSteinberg_1_1Vst_1_1mda_1_1SpecMeterProcessor.html#a66d1a8d9f79b7f3e7378a379fbcf6a0b',1,'Steinberg::Vst::mda::SpecMeterProcessor::lmin()'],['../classSteinberg_1_1Vst_1_1mda_1_1SpecMeterProcessor.html#a5d5f28315548a7d539bf0266562a7c86',1,'Steinberg::Vst::mda::SpecMeterProcessor::Lmin()']]],
+  ['lmin',['Lmin',['../classSteinberg_1_1Vst_1_1mda_1_1SpecMeterProcessor.html#a5d5f28315548a7d539bf0266562a7c86',1,'Steinberg::Vst::mda::SpecMeterProcessor::Lmin()'],['../classSteinberg_1_1Vst_1_1mda_1_1SpecMeterProcessor.html#a66d1a8d9f79b7f3e7378a379fbcf6a0b',1,'Steinberg::Vst::mda::SpecMeterProcessor::lmin()']]],
   ['lmix',['lmix',['../classSteinberg_1_1Vst_1_1mda_1_1DelayProcessor.html#a4cb5678cbeef8c076aedc860368cc4fa',1,'Steinberg::Vst::mda::DelayProcessor::lmix()'],['../classSteinberg_1_1Vst_1_1mda_1_1DubDelayProcessor.html#a4cb5678cbeef8c076aedc860368cc4fa',1,'Steinberg::Vst::mda::DubDelayProcessor::lmix()']]],
   ['lmod',['lmod',['../classSteinberg_1_1Vst_1_1mda_1_1EPianoProcessor.html#a2377c4ea182991ab3c1380c90b0b7894',1,'Steinberg::Vst::mda::EPianoProcessor']]],
   ['lmom',['lmom',['../classSteinberg_1_1Vst_1_1mda_1_1LeslieProcessor.html#a65b24ccf522cbce071a5fd3694a15435',1,'Steinberg::Vst::mda::LeslieProcessor']]],
@@ -58,6 +58,7 @@ var searchData=
   ['loadnextpreset',['loadNextPreset',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IInterAppAudioPresetManager.html#a6d707548076cb27d64e04c155ccba7d2',1,'Steinberg::Vst::IInterAppAudioPresetManager::loadNextPreset()'],['../../vstsdk/classSteinberg_1_1Vst_1_1InterAppAudio_1_1PresetManager.html#a3cabde7a9da60ba41d928d08bc60b374',1,'Steinberg::Vst::InterAppAudio::PresetManager::loadNextPreset()']]],
   ['loadpreset',['loadPreset',['../../vstsdk/classSteinberg_1_1Vst_1_1PresetFile.html#a934b8dae5ccc233b79fcc8a25e0c4235',1,'Steinberg::Vst::PresetFile::loadPreset()'],['../../vstsdk/classSteinberg_1_1Vst_1_1InterAppAudio_1_1PresetManager.html#a499c00d1698d113024242d598d5ace69',1,'Steinberg::Vst::InterAppAudio::PresetManager::loadPreset(bool next)'],['../../vstsdk/classSteinberg_1_1Vst_1_1InterAppAudio_1_1PresetManager.html#a89d71e499b5dd3bf4c5ed2d75811f1b5',1,'Steinberg::Vst::InterAppAudio::PresetManager::loadPreset(const char *path)']]],
   ['loadpreviouspreset',['loadPreviousPreset',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IInterAppAudioPresetManager.html#a726a6db5c25f476bcb9d0f8bc7f24245',1,'Steinberg::Vst::IInterAppAudioPresetManager::loadPreviousPreset()'],['../../vstsdk/classSteinberg_1_1Vst_1_1InterAppAudio_1_1PresetManager.html#a03e03c3eacafc1b39524a5ccbab50faf',1,'Steinberg::Vst::InterAppAudio::PresetManager::loadPreviousPreset()']]],
+  ['lockblock',['lockBlock',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IDataExchangeHandler.html#a364dfe59ecafb51bd6520fa5ce527540',1,'Steinberg::Vst::IDataExchangeHandler']]],
   ['log_5fcontext',['LOG_CONTEXT',['../logevents_8h.html#a779b90f0bd4c9d431184500eff9a3a83',1,'logevents.h']]],
   ['log_5fdesc',['LOG_DESC',['../logevents_8h.html#a53f9f6500f910d315237711949181611',1,'logevents.h']]],
   ['log_5ferr',['LOG_ERR',['../logevents_8h.html#a96fad55b3f5adf08c39e4c877cf185e3',1,'logevents.h']]],
@@ -73,8 +74,8 @@ var searchData=
   ['logscale',['LogScale',['../classSteinberg_1_1Vst_1_1LogScale.html',1,'Steinberg::Vst']]],
   ['logscale_2eh',['logscale.h',['../logscale_8h.html',1,'']]],
   ['logscale_3c_20paramvalue_20_3e',['LogScale&lt; ParamValue &gt;',['../classSteinberg_1_1Vst_1_1LogScale.html',1,'Steinberg::Vst']]],
-  ['logscaleparameter',['LogScaleParameter',['../classSteinberg_1_1Vst_1_1LogScaleParameter.html#a97df6afca0d6e50d9f96e05c33ab7d5a',1,'Steinberg::Vst::LogScaleParameter']]],
   ['logscaleparameter',['LogScaleParameter',['../classSteinberg_1_1Vst_1_1LogScaleParameter.html',1,'Steinberg::Vst']]],
+  ['logscaleparameter',['LogScaleParameter',['../classSteinberg_1_1Vst_1_1LogScaleParameter.html#a97df6afca0d6e50d9f96e05c33ab7d5a',1,'Steinberg::Vst::LogScaleParameter']]],
   ['loop',['loop',['../structSteinberg_1_1Vst_1_1mda_1_1EPianoProcessor_1_1VOICE.html#a9531807d582fba717657d34fc72584cf',1,'Steinberg::Vst::mda::EPianoProcessor::VOICE::loop()'],['../structSteinberg_1_1Vst_1_1mda_1_1EPianoProcessor_1_1KGRP.html#a9531807d582fba717657d34fc72584cf',1,'Steinberg::Vst::mda::EPianoProcessor::KGRP::loop()'],['../structSteinberg_1_1Vst_1_1mda_1_1PianoProcessor_1_1VOICE.html#a9531807d582fba717657d34fc72584cf',1,'Steinberg::Vst::mda::PianoProcessor::VOICE::loop()'],['../structSteinberg_1_1Vst_1_1mda_1_1PianoProcessor_1_1KGRP.html#a9531807d582fba717657d34fc72584cf',1,'Steinberg::Vst::mda::PianoProcessor::KGRP::loop()']]],
   ['loudnesscontroller',['LoudnessController',['../classSteinberg_1_1Vst_1_1mda_1_1LoudnessController.html#ab1e069a5e328d16ced977ee0bf131833',1,'Steinberg::Vst::mda::LoudnessController']]],
   ['loudnesscontroller',['LoudnessController',['../classSteinberg_1_1Vst_1_1mda_1_1LoudnessController.html',1,'Steinberg::Vst::mda']]],
