@@ -102,7 +102,7 @@ var group__containerviews =
       [ "onViewRemoved", "exception_v_s_t_g_u_i_1_1_c_frame.html#a062fdd8e28c1cbaeffa9e5ce6ca8f5ec", null ],
       [ "open", "exception_v_s_t_g_u_i_1_1_c_frame.html#aa8975c5d50e8eadd2d091eec4a1a8756", null ],
       [ "performDrag", "exception_v_s_t_g_u_i_1_1_c_frame.html#a3a5227c713cb76d053376057d3ec164b", null ],
-      [ "platformDrawRect", "exception_v_s_t_g_u_i_1_1_c_frame.html#aafce94f30653d0fa99e31362075921c8", null ],
+      [ "platformDrawRects", "exception_v_s_t_g_u_i_1_1_c_frame.html#a15cb9a517c6c2d6d8a4f1ff021bdd9a3", null ],
       [ "platformOnActivate", "exception_v_s_t_g_u_i_1_1_c_frame.html#a0262eb0830a81380a1970988cc4ccb40", null ],
       [ "platformOnDragEnter", "exception_v_s_t_g_u_i_1_1_c_frame.html#a2ed1afc6fe8c0b6c026a504dd46b691d", null ],
       [ "platformOnDragLeave", "exception_v_s_t_g_u_i_1_1_c_frame.html#adce58f8ff9f7d7c3791b0dc8fc5b9f78", null ],
@@ -146,7 +146,7 @@ var group__containerviews =
       [ "~CLayeredViewContainer", "class_v_s_t_g_u_i_1_1_c_layered_view_container.html#a508d8bfaf155e7e7770b71bffb56f717", null ],
       [ "attached", "class_v_s_t_g_u_i_1_1_c_layered_view_container.html#a522467127f90bd5e2a6856e09b1b7bf2", null ],
       [ "drawRect", "class_v_s_t_g_u_i_1_1_c_layered_view_container.html#ac3627a2e2abcfe4e6df2a77e4829446a", null ],
-      [ "drawViewLayer", "class_v_s_t_g_u_i_1_1_c_layered_view_container.html#a005f718035d5093fac737c6e748e1c64", null ],
+      [ "drawViewLayerRects", "class_v_s_t_g_u_i_1_1_c_layered_view_container.html#a8501ac9401d85b0a4c62ebe85d273948", null ],
       [ "getDrawTransform", "class_v_s_t_g_u_i_1_1_c_layered_view_container.html#a852e37cb94f2ccd5a0bc8a8f6a9e2ee7", null ],
       [ "getPlatformLayer", "class_v_s_t_g_u_i_1_1_c_layered_view_container.html#a8f584ab1deaf1ef7587df93564c6015f", null ],
       [ "getZIndex", "class_v_s_t_g_u_i_1_1_c_layered_view_container.html#a34ed4276adc53dac080e163029e1d5b6", null ],
