@@ -49,26 +49,27 @@ var NAVTREEINDEX =
 "annotated.html",
 "class_v_s_t_g_u_i_1_1_bitmap_filter_1_1_filter_base.html#a2ff96652e89b99f424c047a59e85850d",
 "class_v_s_t_g_u_i_1_1_c_check_box.html",
-"class_v_s_t_g_u_i_1_1_c_draw_context.html#a622734e81b6fc1a89480d47fc4dc6f01",
-"class_v_s_t_g_u_i_1_1_c_kick_button.html#a8885308969382a38b3f72325fff3efc3",
-"class_v_s_t_g_u_i_1_1_c_movie_bitmap.html#ab84ddc9a4171391fa1aaab1e4aceeba4",
-"class_v_s_t_g_u_i_1_1_c_param_display.html#addb2fa415e015ee482fa2cd9eba96af7a60b39817e2fbec3a3ebaccd5fbbb93a9",
-"class_v_s_t_g_u_i_1_1_c_search_text_edit.html",
-"class_v_s_t_g_u_i_1_1_c_split_view.html#a54f2ef725a3284c7cadc1cc0c7dcc527",
-"class_v_s_t_g_u_i_1_1_c_text_button.html#af58ac07c30b89558b198cac6884f8c2c",
-"class_v_s_t_g_u_i_1_1_c_view.html#ae7b11de49c83518bc4e91feb6c2e9b9f",
-"class_v_s_t_g_u_i_1_1_final_action.html#aeab4b1101686b539f3de159820be39d6",
-"class_v_s_t_g_u_i_1_1_i_view_container_listener.html",
-"class_v_s_t_g_u_i_1_1_standalone_1_1_i_menu_builder.html",
-"class_v_s_t_g_u_i_1_1_u_i_attributes.html#a37ce269aca215ad88f2c4a05a9e6d456",
-"class_v_s_t_g_u_i_1_1_u_t_f8_code_point_iterator.html#a75543acf144195808cb7e0b0074bd45d",
-"exception_v_s_t_g_u_i_1_1_buffer.html#ab23dbde36badcbd0d9dbc8ea21f928e3",
-"functions_vars_0x64.html",
-"namespacemembers_0x66.html",
-"struct_v_s_t_g_u_i_1_1_c_frame_1_1_impl.html#a01d261b33a34bd0a3bf951da935c3067",
-"struct_v_s_t_g_u_i_1_1_c_view_container_1_1_impl.html#a0a10a5d6efc9ffc1e4745a0092c9b42e",
-"struct_v_s_t_g_u_i_1_1_standalone_1_1_application_1_1_init.html",
-"struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_rocker_switch_creator.html"
+"class_v_s_t_g_u_i_1_1_c_draw_context.html#a59b405c179bf9c106c3066654a5aa57d",
+"class_v_s_t_g_u_i_1_1_c_horizontal_switch.html#a84f1ef44c839b7efebf5771f7e7b13f8",
+"class_v_s_t_g_u_i_1_1_c_menu_item.html#ad82def3068a469a676185f3d5de8bb4b",
+"class_v_s_t_g_u_i_1_1_c_param_display.html#a8a7b630abf596701c7bc80250640196d",
+"class_v_s_t_g_u_i_1_1_c_scrollbar.html#a44a11177bab5ba2fb4156a8f17bfb844",
+"class_v_s_t_g_u_i_1_1_c_splash_screen.html#a5dd3200e872b6337fa6eefe9599dd596",
+"class_v_s_t_g_u_i_1_1_c_text_button.html#ac7733fe737fd1ea71efd94f8412db816",
+"class_v_s_t_g_u_i_1_1_c_view.html#aa5d991b079a9b01c1fbd08f47a730a00",
+"class_v_s_t_g_u_i_1_1_dispatch_list.html#a70fe12582bcf419de251270fe7962f11",
+"class_v_s_t_g_u_i_1_1_i_u_i_description.html#a9be7386acf741ab1a566b5ded3bde525",
+"class_v_s_t_g_u_i_1_1_standalone_1_1_application_1_1_i_delegate.html#a8a28d4b05e693ac79413b46d46723dc0",
+"class_v_s_t_g_u_i_1_1_string_list_control_drawer.html#aa0ed77b9ef6964efb9b6acad4cd36a41",
+"class_v_s_t_g_u_i_1_1_u_t_f8_character_iterator.html#a03dc55107bee72cd1fccd0fa44d9d211",
+"class_v_s_t_g_u_i_1_1_z_lib_output_stream.html#a76ec7b21ec43ef90c1e1d1b72e3b7974",
+"functions_func_0x64.html",
+"namespace_v_s_t_g_u_i_1_1_standalone_1_1_async.html",
+"struct_v_s_t_g_u_i_1_1_c_draw_context_1_1_impl.html#a62d920a9a06d7ac5b8c98e175defd014",
+"struct_v_s_t_g_u_i_1_1_c_rect.html#ab15157ccf75e649aaea63fc9ad471b1a",
+"struct_v_s_t_g_u_i_1_1_modal_view_session.html#ad39ca9b34b02113ca0befe08c1d0b9b2",
+"struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_control_creator.html#a5af7fb20d7ef2a8263b3ec7b0f410753",
+"struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_u_i_view_switch_container_creator.html"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
