@@ -1,5 +1,34 @@
 var NAVTREEINDEX17 =
 {
+"functions_func_0x64.html":[10,3,1,3],
+"functions_func_0x65.html":[10,3,1,4],
+"functions_func_0x66.html":[10,3,1,5],
+"functions_func_0x67.html":[10,3,1,6],
+"functions_func_0x68.html":[10,3,1,7],
+"functions_func_0x69.html":[10,3,1,8],
+"functions_func_0x6b.html":[10,3,1,9],
+"functions_func_0x6c.html":[10,3,1,10],
+"functions_func_0x6d.html":[10,3,1,11],
+"functions_func_0x6e.html":[10,3,1,12],
+"functions_func_0x6f.html":[10,3,1,13],
+"functions_func_0x70.html":[10,3,1,14],
+"functions_func_0x71.html":[10,3,1,15],
+"functions_func_0x72.html":[10,3,1,16],
+"functions_func_0x73.html":[10,3,1,17],
+"functions_func_0x74.html":[10,3,1,18],
+"functions_func_0x75.html":[10,3,1,19],
+"functions_func_0x76.html":[10,3,1,20],
+"functions_func_0x77.html":[10,3,1,21],
+"functions_func_0x78.html":[10,3,1,22],
+"functions_func_0x7a.html":[10,3,1,23],
+"functions_func_0x7e.html":[10,3,1,24],
+"functions_rela.html":[10,3,6],
+"functions_type.html":[10,3,3],
+"functions_vars.html":[10,3,2],
+"functions_vars.html":[10,3,2,0],
+"functions_vars_0x61.html":[10,3,2,1],
+"functions_vars_0x62.html":[10,3,2,2],
+"functions_vars_0x63.html":[10,3,2,3],
 "functions_vars_0x64.html":[10,3,2,4],
 "functions_vars_0x65.html":[10,3,2,5],
 "functions_vars_0x66.html":[10,3,2,6],
@@ -60,8 +89,8 @@ var NAVTREEINDEX17 =
 "group__new__in__4__11.html#gad1f2e10970572c81bd7156a97eafd2f8":[8,1,3,39],
 "group__new__in__4__11.html#gad31d52d12089ade44329dccbaa86bc20":[8,1,3,27],
 "group__new__in__4__11.html#gadae423c20ad541c299c37f14f60aec82":[8,1,3,40],
+"group__new__in__4__11.html#gae5d3445d69a1041130b8d453258f6a1e":[10,0,2,78,3],
 "group__new__in__4__11.html#gae5d3445d69a1041130b8d453258f6a1e":[8,1,3,42],
-"group__new__in__4__11.html#gae5d3445d69a1041130b8d453258f6a1e":[10,0,2,74,3],
 "group__new__in__4__11.html#gga51910458d0a923b29f1694654d8eb00aa0ce3266d4eb71ad50f7a90aee6d21dcd":[8,1,3,20,3],
 "group__new__in__4__11.html#gga51910458d0a923b29f1694654d8eb00aa6adf97f83acf6453d4a6a4b1070f3754":[8,1,3,20,4],
 "group__new__in__4__11.html#gga51910458d0a923b29f1694654d8eb00aa825a3d98017bab11815ad2817201324c":[8,1,3,20,0],
@@ -146,8 +175,8 @@ var NAVTREEINDEX17 =
 "group__new__in__4__12__1.html":[8,1,5],
 "group__new__in__4__12__1.html#ga4cca024629bfc0d7a7a2cf77eb386497":[8,1,4,1,8],
 "group__new__in__4__12__1.html#ga4cca024629bfc0d7a7a2cf77eb386497":[8,1,5,1],
-"group__new__in__4__12__1.html#ga92f1d595936949be30bb88842e3b14c0":[8,1,5,0],
 "group__new__in__4__12__1.html#ga92f1d595936949be30bb88842e3b14c0":[8,1,4,1,3],
+"group__new__in__4__12__1.html#ga92f1d595936949be30bb88842e3b14c0":[8,1,5,0],
 "group__new__in__4__12__2.html":[8,1,6],
 "group__new__in__4__2.html":[8,1,7],
 "group__new__in__4__3.html":[8,1,8],
@@ -184,70 +213,41 @@ var NAVTREEINDEX17 =
 "key_event_flow.html#long_story":[6,1,1],
 "key_event_flow.html#short_story":[6,1,0],
 "modules.html":[8],
-"namespace_v_s_t3_editor.html":[9,0,0],
 "namespace_v_s_t3_editor.html":[10,0,0],
-"namespace_v_s_t3_editor_internal.html":[9,0,1],
+"namespace_v_s_t3_editor.html":[9,0,0],
 "namespace_v_s_t3_editor_internal.html":[10,0,1],
-"namespace_v_s_t_g_u_i.html":[10,0,2],
+"namespace_v_s_t3_editor_internal.html":[9,0,1],
 "namespace_v_s_t_g_u_i.html":[9,0,2],
-"namespace_v_s_t_g_u_i_1_1_animation.html":[10,0,2,0],
+"namespace_v_s_t_g_u_i.html":[10,0,2],
 "namespace_v_s_t_g_u_i_1_1_animation.html":[9,0,2,0],
+"namespace_v_s_t_g_u_i_1_1_animation.html":[10,0,2,0],
 "namespace_v_s_t_g_u_i_1_1_bitmap_filter.html":[10,0,2,1],
 "namespace_v_s_t_g_u_i_1_1_bitmap_filter.html":[9,0,2,1],
 "namespace_v_s_t_g_u_i_1_1_bitmap_filter_1_1_standard.html":[10,0,2,1,0],
 "namespace_v_s_t_g_u_i_1_1_bitmap_filter_1_1_standard.html":[9,0,2,1,0],
-"namespace_v_s_t_g_u_i_1_1_bitmap_filter_1_1_standard_1_1_property.html":[9,0,2,1,0,0],
 "namespace_v_s_t_g_u_i_1_1_bitmap_filter_1_1_standard_1_1_property.html":[10,0,2,1,0,0],
-"namespace_v_s_t_g_u_i_1_1_c_clipboard_detail.html":[10,0,2,3],
+"namespace_v_s_t_g_u_i_1_1_bitmap_filter_1_1_standard_1_1_property.html":[9,0,2,1,0,0],
 "namespace_v_s_t_g_u_i_1_1_c_clipboard_detail.html":[9,0,2,3],
-"namespace_v_s_t_g_u_i_1_1_c_draw_methods.html":[9,0,2,4],
+"namespace_v_s_t_g_u_i_1_1_c_clipboard_detail.html":[10,0,2,3],
 "namespace_v_s_t_g_u_i_1_1_c_draw_methods.html":[10,0,2,4],
+"namespace_v_s_t_g_u_i_1_1_c_draw_methods.html":[9,0,2,4],
 "namespace_v_s_t_g_u_i_1_1_call.html":[9,0,2,2],
 "namespace_v_s_t_g_u_i_1_1_call.html":[10,0,2,2],
-"namespace_v_s_t_g_u_i_1_1_constants.html":[9,0,2,5],
 "namespace_v_s_t_g_u_i_1_1_constants.html":[10,0,2,5],
-"namespace_v_s_t_g_u_i_1_1_detail.html":[10,0,2,6],
+"namespace_v_s_t_g_u_i_1_1_constants.html":[9,0,2,5],
 "namespace_v_s_t_g_u_i_1_1_detail.html":[9,0,2,6],
+"namespace_v_s_t_g_u_i_1_1_detail.html":[10,0,2,6],
 "namespace_v_s_t_g_u_i_1_1_event_private.html":[10,0,2,7],
 "namespace_v_s_t_g_u_i_1_1_event_private.html":[9,0,2,7],
-"namespace_v_s_t_g_u_i_1_1_pixel_buffer.html":[10,0,2,8],
-"namespace_v_s_t_g_u_i_1_1_pixel_buffer.html":[9,0,2,8],
-"namespace_v_s_t_g_u_i_1_1_pixel_buffer_1_1_private.html":[9,0,2,8,0],
-"namespace_v_s_t_g_u_i_1_1_pixel_buffer_1_1_private.html":[10,0,2,8,0],
-"namespace_v_s_t_g_u_i_1_1_standalone.html":[10,0,2,9],
-"namespace_v_s_t_g_u_i_1_1_standalone.html":[9,0,2,9],
-"namespace_v_s_t_g_u_i_1_1_standalone_1_1_application.html":[9,0,2,9,0],
-"namespace_v_s_t_g_u_i_1_1_standalone_1_1_application.html":[10,0,2,9,0],
-"namespace_v_s_t_g_u_i_1_1_standalone_1_1_async.html":[10,0,2,9,1],
-"namespace_v_s_t_g_u_i_1_1_standalone_1_1_async.html":[9,0,2,9,1],
-"namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_group.html":[9,0,2,9,2],
-"namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_group.html":[10,0,2,9,2],
-"namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html":[10,0,2,9,3],
-"namespace_v_s_t_g_u_i_1_1_standalone_1_1_command_name.html":[9,0,2,9,3],
-"namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html":[9,0,2,9,4],
-"namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands.html":[10,0,2,9,4],
-"namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands_1_1_debug.html":[10,0,2,9,4,0],
-"namespace_v_s_t_g_u_i_1_1_standalone_1_1_commands_1_1_debug.html":[9,0,2,9,4,0],
-"namespace_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc.html":[10,0,2,9,5],
-"namespace_v_s_t_g_u_i_1_1_standalone_1_1_u_i_desc.html":[9,0,2,9,5],
-"namespace_v_s_t_g_u_i_1_1_standalone_1_1_value.html":[10,0,2,9,6],
-"namespace_v_s_t_g_u_i_1_1_standalone_1_1_value.html":[9,0,2,9,6],
-"namespace_v_s_t_g_u_i_1_1_standalone_1_1_value_1_1_detail.html":[10,0,2,9,6,0],
-"namespace_v_s_t_g_u_i_1_1_standalone_1_1_value_1_1_detail.html":[9,0,2,9,6,0],
-"namespace_v_s_t_g_u_i_1_1_string.html":[9,0,2,10],
-"namespace_v_s_t_g_u_i_1_1_string.html":[10,0,2,10],
-"namespace_v_s_t_g_u_i_1_1_u_i_description_private.html":[10,0,2,11],
-"namespace_v_s_t_g_u_i_1_1_u_i_description_private.html":[9,0,2,11],
-"namespace_v_s_t_g_u_i_1_1_u_i_view_creator.html":[9,0,2,12],
-"namespace_v_s_t_g_u_i_1_1_u_i_view_creator.html":[10,0,2,12],
-"namespace_v_s_t_g_u_i_1_1_v_s_t3_editor_internal.html":[9,0,2,13],
-"namespace_v_s_t_g_u_i_1_1_v_s_t3_editor_internal.html":[10,0,2,13],
-"namespace_v_s_t_g_u_i_1_1_xml.html":[10,0,2,14],
-"namespace_v_s_t_g_u_i_1_1_xml.html":[9,0,2,14],
-"namespacemembers.html":[9,1,0,0],
-"namespacemembers.html":[9,1,0],
-"namespacemembers_0x62.html":[9,1,0,1],
-"namespacemembers_0x63.html":[9,1,0,2],
-"namespacemembers_0x64.html":[9,1,0,3],
-"namespacemembers_0x65.html":[9,1,0,4]
+"namespace_v_s_t_g_u_i_1_1_external_view.html":[9,0,2,8],
+"namespace_v_s_t_g_u_i_1_1_external_view.html":[10,0,2,8],
+"namespace_v_s_t_g_u_i_1_1_pixel_buffer.html":[10,0,2,9],
+"namespace_v_s_t_g_u_i_1_1_pixel_buffer.html":[9,0,2,9],
+"namespace_v_s_t_g_u_i_1_1_pixel_buffer_1_1_private.html":[9,0,2,9,0],
+"namespace_v_s_t_g_u_i_1_1_pixel_buffer_1_1_private.html":[10,0,2,9,0],
+"namespace_v_s_t_g_u_i_1_1_standalone.html":[9,0,2,10],
+"namespace_v_s_t_g_u_i_1_1_standalone.html":[10,0,2,10],
+"namespace_v_s_t_g_u_i_1_1_standalone_1_1_application.html":[9,0,2,10,0],
+"namespace_v_s_t_g_u_i_1_1_standalone_1_1_application.html":[10,0,2,10,0],
+"namespace_v_s_t_g_u_i_1_1_standalone_1_1_async.html":[10,0,2,10,1]
 };
