@@ -16,6 +16,8 @@ var searchData=
   ['_7eccontrol',['~CControl',['../class_v_s_t_g_u_i_1_1_c_control.html#a9c9a30d751810c3177289a3b5d3dbcce',1,'VSTGUI::CControl']]],
   ['_7ecdatabrowser',['~CDataBrowser',['../class_v_s_t_g_u_i_1_1_c_data_browser.html#ac27bae58f2b07eac90f610661168dba1',1,'VSTGUI::CDataBrowser']]],
   ['_7ecdrawcontext',['~CDrawContext',['../class_v_s_t_g_u_i_1_1_c_draw_context.html#a0d715e718b366b3ebe233582cf4f04bd',1,'VSTGUI::CDrawContext']]],
+  ['_7ecexternalcontrol',['~CExternalControl',['../class_v_s_t_g_u_i_1_1_c_external_control.html#a09aab47c937a0848f1a3f8e014064a7f',1,'VSTGUI::CExternalControl']]],
+  ['_7ecexternalview',['~CExternalView',['../class_v_s_t_g_u_i_1_1_c_external_view.html#a8fa26c9e0788c08566629b5c99c0f0ce',1,'VSTGUI::CExternalView']]],
   ['_7ecfileextension',['~CFileExtension',['../class_v_s_t_g_u_i_1_1_c_file_extension.html#a86c04c3537f5e4d14311c69d190b8a9e',1,'VSTGUI::CFileExtension']]],
   ['_7ecfilestream',['~CFileStream',['../class_v_s_t_g_u_i_1_1_c_file_stream.html#a45a9f99f7cd8cabb0ee2156d93d808bf',1,'VSTGUI::CFileStream']]],
   ['_7ecfontchooser',['~CFontChooser',['../class_v_s_t_g_u_i_1_1_c_font_chooser.html#a0cf9c7d6ecb3c10f4dce22b500b9227d',1,'VSTGUI::CFontChooser']]],
@@ -90,9 +92,11 @@ var searchData=
   ['_7eisplitviewseparatordrawer',['~ISplitViewSeparatorDrawer',['../class_v_s_t_g_u_i_1_1_i_split_view_separator_drawer.html#a3efd8eb2dca3acfb7fdb010a11daf581',1,'VSTGUI::ISplitViewSeparatorDrawer']]],
   ['_7eitimingfunction',['~ITimingFunction',['../class_v_s_t_g_u_i_1_1_animation_1_1_i_timing_function.html#abefd528ecee7139c781e8677a1b4de5e',1,'VSTGUI::Animation::ITimingFunction']]],
   ['_7eiuidescription',['~IUIDescription',['../class_v_s_t_g_u_i_1_1_i_u_i_description.html#acaa0b39bbd092d13dda7c9ae60712230',1,'VSTGUI::IUIDescription']]],
+  ['_7eiview',['~IView',['../struct_v_s_t_g_u_i_1_1_external_view_1_1_i_view.html#a40973a2461ef40e029d7a651f07d19d5',1,'VSTGUI::ExternalView::IView']]],
   ['_7eiviewaddedremovedobserver',['~IViewAddedRemovedObserver',['../class_v_s_t_g_u_i_1_1_i_view_added_removed_observer.html#af6c214a403b68df6e8cbf153d85da498',1,'VSTGUI::IViewAddedRemovedObserver']]],
   ['_7eiviewcontainerlistener',['~IViewContainerListener',['../class_v_s_t_g_u_i_1_1_i_view_container_listener.html#a2018983b3eb4a15845011fd2c2dcd176',1,'VSTGUI::IViewContainerListener']]],
   ['_7eiviewcreator',['~IViewCreator',['../class_v_s_t_g_u_i_1_1_i_view_creator.html#ae8965f884224c40fa402fe8721a4c173',1,'VSTGUI::IViewCreator']]],
+  ['_7eiviewembedder',['~IViewEmbedder',['../struct_v_s_t_g_u_i_1_1_external_view_1_1_i_view_embedder.html#ae9f1b022c0c516a6e5c96d75ba1bf31c',1,'VSTGUI::ExternalView::IViewEmbedder']]],
   ['_7eivieweventlistener',['~IViewEventListener',['../class_v_s_t_g_u_i_1_1_i_view_event_listener.html#a25b6fd8d8af1061430e7516c4294df45',1,'VSTGUI::IViewEventListener']]],
   ['_7eiviewfactory',['~IViewFactory',['../class_v_s_t_g_u_i_1_1_i_view_factory.html#ae7579a3e6d0894080a3882453633c767',1,'VSTGUI::IViewFactory']]],
   ['_7eiviewlistener',['~IViewListener',['../class_v_s_t_g_u_i_1_1_i_view_listener.html#a13ac896186e981bbdc3e232dc1e01022',1,'VSTGUI::IViewListener']]],
