@@ -23,6 +23,9 @@ var searchData=
   ['cdrawmode',['CDrawMode',['../struct_v_s_t_g_u_i_1_1_c_draw_mode.html',1,'VSTGUI']]],
   ['cdropsource',['CDropSource',['../class_v_s_t_g_u_i_1_1_c_drop_source.html',1,'VSTGUI']]],
   ['cell',['Cell',['../struct_v_s_t_g_u_i_1_1_c_data_browser_1_1_cell.html',1,'VSTGUI::CDataBrowser']]],
+  ['cexternalcontrol',['CExternalControl',['../class_v_s_t_g_u_i_1_1_c_external_control.html',1,'VSTGUI']]],
+  ['cexternalview',['CExternalView',['../class_v_s_t_g_u_i_1_1_c_external_view.html',1,'VSTGUI']]],
+  ['cexternalviewbaseimpl',['CExternalViewBaseImpl',['../struct_v_s_t_g_u_i_1_1_c_external_view_base_impl.html',1,'VSTGUI']]],
   ['cfileextension',['CFileExtension',['../class_v_s_t_g_u_i_1_1_c_file_extension.html',1,'VSTGUI']]],
   ['cfilestream',['CFileStream',['../class_v_s_t_g_u_i_1_1_c_file_stream.html',1,'VSTGUI']]],
   ['cfontchooser',['CFontChooser',['../class_v_s_t_g_u_i_1_1_c_font_chooser.html',1,'VSTGUI']]],
@@ -66,6 +69,7 @@ var searchData=
   ['conoffbutton',['COnOffButton',['../class_v_s_t_g_u_i_1_1_c_on_off_button.html',1,'VSTGUI']]],
   ['controlcreator',['ControlCreator',['../struct_v_s_t_g_u_i_1_1_u_i_view_creator_1_1_control_creator.html',1,'VSTGUI::UIViewCreator']]],
   ['controlvalueanimation',['ControlValueAnimation',['../class_v_s_t_g_u_i_1_1_animation_1_1_control_value_animation.html',1,'VSTGUI::Animation']]],
+  ['controlviewadapter',['ControlViewAdapter',['../struct_v_s_t_g_u_i_1_1_external_view_1_1_control_view_adapter.html',1,'VSTGUI::ExternalView']]],
   ['copenglview',['COpenGLView',['../class_v_s_t_g_u_i_1_1_c_open_g_l_view.html',1,'VSTGUI']]],
   ['coptionmenu',['COptionMenu',['../class_v_s_t_g_u_i_1_1_c_option_menu.html',1,'VSTGUI']]],
   ['cparamdisplay',['CParamDisplay',['../class_v_s_t_g_u_i_1_1_c_param_display.html',1,'VSTGUI']]],
