@@ -22,6 +22,7 @@ var searchData=
   ['deltay',['deltaY',['../struct_v_s_t_g_u_i_1_1_mouse_wheel_event.html#a277407d1abe57357b468d032e12d1187',1,'VSTGUI::MouseWheelEvent']]],
   ['description',['description',['../class_v_s_t_g_u_i_1_1_v_s_t3_editor.html#a5fd668089ce77a564786b7241601563c',1,'VSTGUI::VST3Editor::description()'],['../struct_v_s_t_g_u_i_1_1_standalone_1_1_alert_box_config.html#a191c4f2865dc62dd11051b3b26c6caf3',1,'VSTGUI::Standalone::AlertBoxConfig::description()']]],
   ['destinationrect',['destinationRect',['../class_v_s_t_g_u_i_1_1_animation_1_1_exchange_view_animation.html#addefe1e99cfc37410001a032d5070173',1,'VSTGUI::Animation::ExchangeViewAnimation']]],
+  ['device',['device',['../struct_v_s_t_g_u_i_1_1_c_draw_context_1_1_impl.html#a8c878111d8fc4717dfb6c3b8c073321f',1,'VSTGUI::CDrawContext::Impl']]],
   ['direction',['direction',['../class_v_s_t_g_u_i_1_1_c_scrollbar.html#a945bc7708563ad05b79829e5eb16c2a3',1,'VSTGUI::CScrollbar']]],
   ['docreateview',['doCreateView',['../class_v_s_t_g_u_i_1_1_v_s_t3_editor.html#a7c3046f890ebb482c064efecfc5ff6ce',1,'VSTGUI::VST3Editor']]],
   ['dohovercheck',['doHoverCheck',['../struct_v_s_t_g_u_i_1_1_c_list_control_1_1_impl.html#afae9aaf33a25161415a8a7f207165229',1,'VSTGUI::CListControl::Impl']]],
@@ -31,6 +32,8 @@ var searchData=
   ['drawantialiased',['drawAntialiased',['../class_v_s_t_g_u_i_1_1_c_gradient_view.html#a080c87907324504fa7b0a046326260db',1,'VSTGUI::CGradientView']]],
   ['drawer',['drawer',['../struct_v_s_t_g_u_i_1_1_c_list_control_1_1_impl.html#aa62c0e0b50db432c2aabde0edfc68d71',1,'VSTGUI::CListControl::Impl::drawer()'],['../class_v_s_t_g_u_i_1_1_c_scrollbar.html#aad21a7d3ac3ca4e0201726d752618b49',1,'VSTGUI::CScrollbar::drawer()']]],
   ['drawfont',['drawFont',['../class_v_s_t_g_u_i_1_1_generic_string_list_data_browser_source.html#a7f1626674d409a7198c121ac02c5059d',1,'VSTGUI::GenericStringListDataBrowserSource']]],
+  ['drawmode',['drawMode',['../struct_v_s_t_g_u_i_1_1_c_draw_context_1_1_impl_1_1_state.html#a0a069fef4550a5dfcd19cefa8957bcf5',1,'VSTGUI::CDrawContext::Impl::State']]],
+  ['drawstringhelper',['drawStringHelper',['../struct_v_s_t_g_u_i_1_1_c_draw_context_1_1_impl.html#a6c8795025cd807a3194fec1d730ff355',1,'VSTGUI::CDrawContext::Impl']]],
   ['drawstyle',['drawStyle',['../class_v_s_t_g_u_i_1_1_c_knob.html#a8da7c913b2548b35f23d8e01450bae76',1,'VSTGUI::CKnob::drawStyle()'],['../struct_v_s_t_g_u_i_1_1_c_slider_1_1_impl.html#a8da7c913b2548b35f23d8e01450bae76',1,'VSTGUI::CSlider::Impl::drawStyle()']]],
   ['droptarget',['dropTarget',['../struct_v_s_t_g_u_i_1_1_c_view_container_drop_target.html#a8614e2d99c33b41a30963f1428b9023d',1,'VSTGUI::CViewContainerDropTarget']]],
   ['dx',['dx',['../struct_v_s_t_g_u_i_1_1_c_graphics_transform.html#a229d11aff11a7482259d1296b9b70b8a',1,'VSTGUI::CGraphicsTransform']]],
