@@ -8,19 +8,19 @@ var NAVTREEINDEX0 =
 ".html":[2,0,0,0],
 "annotated.html":[2,0],
 "classSteinberg_1_1IPlugFrame.html":[0,9,4],
-"classSteinberg_1_1IPlugFrame.html#a94f218315acd695606fff41166294d56":[0,9,4,0],
 "classSteinberg_1_1IPlugFrame.html#a94f218315acd695606fff41166294d56":[0,9,4,1],
+"classSteinberg_1_1IPlugFrame.html#a94f218315acd695606fff41166294d56":[0,9,4,0],
 "classSteinberg_1_1IPlugView.html":[0,9,3],
-"classSteinberg_1_1IPlugView.html#a07d7a22ae1ef493c4bb22c9411ae7ddf":[0,9,3,10],
 "classSteinberg_1_1IPlugView.html#a07d7a22ae1ef493c4bb22c9411ae7ddf":[0,9,3,22],
-"classSteinberg_1_1IPlugView.html#a3e741e55c2c047a4cc10f102661f5654":[0,9,3,7],
+"classSteinberg_1_1IPlugView.html#a07d7a22ae1ef493c4bb22c9411ae7ddf":[0,9,3,10],
 "classSteinberg_1_1IPlugView.html#a3e741e55c2c047a4cc10f102661f5654":[0,9,3,19],
-"classSteinberg_1_1IPlugView.html#a576b66ba9806bcecc3256110f5dd246a":[0,9,3,15],
+"classSteinberg_1_1IPlugView.html#a3e741e55c2c047a4cc10f102661f5654":[0,9,3,7],
 "classSteinberg_1_1IPlugView.html#a576b66ba9806bcecc3256110f5dd246a":[0,9,3,3],
+"classSteinberg_1_1IPlugView.html#a576b66ba9806bcecc3256110f5dd246a":[0,9,3,15],
 "classSteinberg_1_1IPlugView.html#a759b576f046e699c84dc07d579600b1b":[0,9,3,4],
 "classSteinberg_1_1IPlugView.html#a759b576f046e699c84dc07d579600b1b":[0,9,3,16],
-"classSteinberg_1_1IPlugView.html#a9fbc345c1e87f7e6210a8a49fdb96793":[0,9,3,13],
 "classSteinberg_1_1IPlugView.html#a9fbc345c1e87f7e6210a8a49fdb96793":[0,9,3,1],
+"classSteinberg_1_1IPlugView.html#a9fbc345c1e87f7e6210a8a49fdb96793":[0,9,3,13],
 "classSteinberg_1_1IPlugView.html#ab0f059918bbf55ce110fc410240de423":[0,9,3,9],
 "classSteinberg_1_1IPlugView.html#ab0f059918bbf55ce110fc410240de423":[0,9,3,21],
 "classSteinberg_1_1IPlugView.html#abc80a2e0d25e151cbc2fabd1bd200683":[0,9,3,8],
@@ -109,24 +109,26 @@ var NAVTREEINDEX0 =
 "classSteinberg_1_1Vst_1_1IComponent.html#a77ac39bcc5c4b15818b1a87de2573805":[2,0,0,1,26,7],
 "classSteinberg_1_1Vst_1_1IComponent.html#a8aa65685068ad033af57b1497926b689":[2,0,0,1,26,0],
 "classSteinberg_1_1Vst_1_1IComponent.html#aa0ffeccad3c44364a199ce56365a4c12":[2,0,0,1,26,4],
-"classSteinberg_1_1Vst_1_1IComponentHandler.html":[2,0,0,1,32],
-"classSteinberg_1_1Vst_1_1IComponentHandler.html#a135d4e76355ef0ba0a4162a0546d5f93":[2,0,0,1,32,1],
-"classSteinberg_1_1Vst_1_1IComponentHandler.html#a1f283573728cf0807224c5ebdf3ec3a6":[2,0,0,1,32,3],
-"classSteinberg_1_1Vst_1_1IComponentHandler.html#a8456ad739430267a12dda11a53fe9223":[2,0,0,1,32,0],
-"classSteinberg_1_1Vst_1_1IComponentHandler.html#ae380206486b11f000cad7c0d9b6e877c":[2,0,0,1,32,2],
-"classSteinberg_1_1Vst_1_1IComponentHandler2.html":[2,0,0,1,33],
-"classSteinberg_1_1Vst_1_1IComponentHandler2.html#aa457d0550984879c4094c578b914fb6d":[2,0,0,1,33,0],
-"classSteinberg_1_1Vst_1_1IComponentHandler2.html#aba339113df404a6b3c557774d4aa9102":[2,0,0,1,33,2],
-"classSteinberg_1_1Vst_1_1IComponentHandler2.html#ac7d37d88b53e9517e1b696bef2d47fa5":[2,0,0,1,33,1],
-"classSteinberg_1_1Vst_1_1IComponentHandler2.html#adbdc10ff7ecd96fa365ad4f98d57b55e":[2,0,0,1,33,3],
+"classSteinberg_1_1Vst_1_1IComponentHandler.html":[2,0,0,1,35],
+"classSteinberg_1_1Vst_1_1IComponentHandler.html#a135d4e76355ef0ba0a4162a0546d5f93":[2,0,0,1,35,1],
+"classSteinberg_1_1Vst_1_1IComponentHandler.html#a1f283573728cf0807224c5ebdf3ec3a6":[2,0,0,1,35,3],
+"classSteinberg_1_1Vst_1_1IComponentHandler.html#a8456ad739430267a12dda11a53fe9223":[2,0,0,1,35,0],
+"classSteinberg_1_1Vst_1_1IComponentHandler.html#ae380206486b11f000cad7c0d9b6e877c":[2,0,0,1,35,2],
+"classSteinberg_1_1Vst_1_1IComponentHandler2.html":[2,0,0,1,36],
+"classSteinberg_1_1Vst_1_1IComponentHandler2.html#aa457d0550984879c4094c578b914fb6d":[2,0,0,1,36,0],
+"classSteinberg_1_1Vst_1_1IComponentHandler2.html#aba339113df404a6b3c557774d4aa9102":[2,0,0,1,36,2],
+"classSteinberg_1_1Vst_1_1IComponentHandler2.html#ac7d37d88b53e9517e1b696bef2d47fa5":[2,0,0,1,36,1],
+"classSteinberg_1_1Vst_1_1IComponentHandler2.html#adbdc10ff7ecd96fa365ad4f98d57b55e":[2,0,0,1,36,3],
 "classSteinberg_1_1Vst_1_1IComponentHandler3.html":[2,0,0,1,27],
 "classSteinberg_1_1Vst_1_1IComponentHandler3.html#a0c91e0b43003a34a7f43d0c4b33aa604":[2,0,0,1,27,0],
-"classSteinberg_1_1Vst_1_1IComponentHandlerBusActivation.html":[2,0,0,1,34],
-"classSteinberg_1_1Vst_1_1IComponentHandlerBusActivation.html#a9a2bf35a7e6bc9dede587900312137fc":[2,0,0,1,34,0],
-"classSteinberg_1_1Vst_1_1IConnectionPoint.html":[2,0,0,1,58],
-"classSteinberg_1_1Vst_1_1IConnectionPoint.html#a870cdbe19a2c9798e1e68fab65e72a77":[2,0,0,1,58,2],
-"classSteinberg_1_1Vst_1_1IConnectionPoint.html#aa65d68182357737c7a1f7736400565c2":[2,0,0,1,58,0],
-"classSteinberg_1_1Vst_1_1IConnectionPoint.html#ad85bd437968bec6e403fb3cba699b01e":[2,0,0,1,58,1],
+"classSteinberg_1_1Vst_1_1IComponentHandlerBusActivation.html":[2,0,0,1,37],
+"classSteinberg_1_1Vst_1_1IComponentHandlerBusActivation.html#a9a2bf35a7e6bc9dede587900312137fc":[2,0,0,1,37,0],
+"classSteinberg_1_1Vst_1_1IComponentHandlerSystemTime.html":[2,0,0,1,43],
+"classSteinberg_1_1Vst_1_1IComponentHandlerSystemTime.html#acdbd89d88d7123f96e2920c2715749fb":[2,0,0,1,43,0],
+"classSteinberg_1_1Vst_1_1IConnectionPoint.html":[2,0,0,1,62],
+"classSteinberg_1_1Vst_1_1IConnectionPoint.html#a870cdbe19a2c9798e1e68fab65e72a77":[2,0,0,1,62,2],
+"classSteinberg_1_1Vst_1_1IConnectionPoint.html#aa65d68182357737c7a1f7736400565c2":[2,0,0,1,62,0],
+"classSteinberg_1_1Vst_1_1IConnectionPoint.html#ad85bd437968bec6e403fb3cba699b01e":[2,0,0,1,62,1],
 "classSteinberg_1_1Vst_1_1IContextMenu.html":[2,0,0,1,30],
 "classSteinberg_1_1Vst_1_1IContextMenu.html#a241e6e88af766e7075c675215a62c82d":[2,0,0,1,30,2],
 "classSteinberg_1_1Vst_1_1IContextMenu.html#a8d6e113be32dfccabcacca0c81ee6f10":[2,0,0,1,30,5],
@@ -136,85 +138,94 @@ var NAVTREEINDEX0 =
 "classSteinberg_1_1Vst_1_1IContextMenu.html#ac172d5fa00b2028a352c704dd906f236":[2,0,0,1,30,3],
 "classSteinberg_1_1Vst_1_1IContextMenuTarget.html":[2,0,0,1,28],
 "classSteinberg_1_1Vst_1_1IContextMenuTarget.html#a4a1e98d2d18ded53b636b7f36cb9f83f":[2,0,0,1,28,0],
-"classSteinberg_1_1Vst_1_1IEditController.html":[2,0,0,1,36],
-"classSteinberg_1_1Vst_1_1IEditController.html#a0ba78602ecf2f5e8d747d8b01d4cfb6c":[2,0,0,1,36,4],
-"classSteinberg_1_1Vst_1_1IEditController.html#a10db03106be8ba89d23859fa6be5d9f6":[2,0,0,1,36,2],
-"classSteinberg_1_1Vst_1_1IEditController.html#a1fa4ed10cc0979e5559045104c998b1a":[2,0,0,1,36,12],
-"classSteinberg_1_1Vst_1_1IEditController.html#a4c2e1cafd88143fda2767a9c7ba5d48f":[2,0,0,1,36,0],
-"classSteinberg_1_1Vst_1_1IEditController.html#a77ac39bcc5c4b15818b1a87de2573805":[2,0,0,1,36,1],
-"classSteinberg_1_1Vst_1_1IEditController.html#a849747dc98909312b4cdbdeea82dbae0":[2,0,0,1,36,7],
-"classSteinberg_1_1Vst_1_1IEditController.html#aab2f0b853e75361d331b667e7893962e":[2,0,0,1,36,5],
-"classSteinberg_1_1Vst_1_1IEditController.html#aab5ccab5fd1cc1cd0a59afd90279dd81":[2,0,0,1,36,11],
-"classSteinberg_1_1Vst_1_1IEditController.html#ab6ffbb8e3bf6f4829ab1c9c23fe935a1":[2,0,0,1,36,3],
-"classSteinberg_1_1Vst_1_1IEditController.html#ac5abbadd4c8326fae66fd1e63bdc15b3":[2,0,0,1,36,9],
-"classSteinberg_1_1Vst_1_1IEditController.html#aded549c5b0f342a23dee18cc41ece6b8":[2,0,0,1,36,10],
-"classSteinberg_1_1Vst_1_1IEditController.html#ae9706616ae6d938bbf102954f8f2f110":[2,0,0,1,36,8],
-"classSteinberg_1_1Vst_1_1IEditController.html#af4254a0360b21f8871a61c62fb317058":[2,0,0,1,36,6],
-"classSteinberg_1_1Vst_1_1IEditController2.html":[2,0,0,1,37],
-"classSteinberg_1_1Vst_1_1IEditController2.html#a749ceb08d2f33b5b12cdc59172d8a7c3":[2,0,0,1,37,1],
-"classSteinberg_1_1Vst_1_1IEditController2.html#aa52846d39014c3ca95224fa98930e7a8":[2,0,0,1,37,2],
-"classSteinberg_1_1Vst_1_1IEditController2.html#ad38ac70a9efcc0cfee8ac0cc2b80e648":[2,0,0,1,37,0],
-"classSteinberg_1_1Vst_1_1IEditControllerHostEditing.html":[2,0,0,1,39],
-"classSteinberg_1_1Vst_1_1IEditControllerHostEditing.html#a589c94be69d4ee5ed29cf62e437fecbb":[2,0,0,1,39,1],
-"classSteinberg_1_1Vst_1_1IEditControllerHostEditing.html#a97cc85e97b22ff0d4fb9b5109a1a2bf2":[2,0,0,1,39,0],
-"classSteinberg_1_1Vst_1_1IEventList.html":[2,0,0,1,48],
-"classSteinberg_1_1Vst_1_1IEventList.html#a2e0abd231c54bd5c5a5e6f455169311e":[2,0,0,1,48,0],
-"classSteinberg_1_1Vst_1_1IEventList.html#a604181f48ab23957b7b9fcbb09c97fc1":[2,0,0,1,48,1],
-"classSteinberg_1_1Vst_1_1IEventList.html#aa58736dbdfb425c6c8f12b2129626370":[2,0,0,1,48,2],
-"classSteinberg_1_1Vst_1_1IHostApplication.html":[2,0,0,1,49],
-"classSteinberg_1_1Vst_1_1IHostApplication.html#a701520a52c46a25fdaca39ca4a28177f":[2,0,0,1,49,0],
-"classSteinberg_1_1Vst_1_1IHostApplication.html#a931e5a2ff8867bd8dfdbae1e42b78106":[2,0,0,1,49,1],
-"classSteinberg_1_1Vst_1_1IInterAppAudioConnectionNotification.html":[2,0,0,1,55],
-"classSteinberg_1_1Vst_1_1IInterAppAudioConnectionNotification.html#a57d886cb53419b840fe75049f3f4d6a6":[2,0,0,1,55,0],
-"classSteinberg_1_1Vst_1_1IInterAppAudioHost.html":[2,0,0,1,54],
-"classSteinberg_1_1Vst_1_1IInterAppAudioHost.html#a36e1db0db800560f4c70031e3ebc0a31":[2,0,0,1,54,0],
-"classSteinberg_1_1Vst_1_1IInterAppAudioHost.html#a4ec60e594f7ad548f697c39c252191d0":[2,0,0,1,54,4],
-"classSteinberg_1_1Vst_1_1IInterAppAudioHost.html#a83a79b604432e251a09cbfcdc0b367a8":[2,0,0,1,54,5],
-"classSteinberg_1_1Vst_1_1IInterAppAudioHost.html#a85482697be15b427dd93a5488beaf9a8":[2,0,0,1,54,1],
-"classSteinberg_1_1Vst_1_1IInterAppAudioHost.html#a8b0ced23b7d8e83d9bae5dcbc324f403":[2,0,0,1,54,2],
-"classSteinberg_1_1Vst_1_1IInterAppAudioHost.html#a8d4eef17f1de81905a5936f9849de029":[2,0,0,1,54,3],
-"classSteinberg_1_1Vst_1_1IInterAppAudioHost.html#aa6d66ecd68a991b8c12c40f39a5799c1":[2,0,0,1,54,7],
-"classSteinberg_1_1Vst_1_1IInterAppAudioHost.html#ae2524b3ead8126059bc897d1a97047e5":[2,0,0,1,54,6],
-"classSteinberg_1_1Vst_1_1IInterAppAudioPresetManager.html":[2,0,0,1,56],
-"classSteinberg_1_1Vst_1_1IInterAppAudioPresetManager.html#a236a03d49a8c928c39c4191881ba5406":[2,0,0,1,56,1],
-"classSteinberg_1_1Vst_1_1IInterAppAudioPresetManager.html#a6d707548076cb27d64e04c155ccba7d2":[2,0,0,1,56,2],
-"classSteinberg_1_1Vst_1_1IInterAppAudioPresetManager.html#a726a6db5c25f476bcb9d0f8bc7f24245":[2,0,0,1,56,3],
-"classSteinberg_1_1Vst_1_1IInterAppAudioPresetManager.html#a74e27f28ba190ed2834ddcf99f8b13f7":[2,0,0,1,56,0],
-"classSteinberg_1_1Vst_1_1IKeyswitchController.html":[2,0,0,1,66],
-"classSteinberg_1_1Vst_1_1IKeyswitchController.html#a8193190849039a70d08b084241d29e38":[2,0,0,1,66,1],
-"classSteinberg_1_1Vst_1_1IKeyswitchController.html#aa98a707edb1b58d05da0c50e38983a4e":[2,0,0,1,66,0],
-"classSteinberg_1_1Vst_1_1IMessage.html":[2,0,0,1,57],
-"classSteinberg_1_1Vst_1_1IMessage.html#a56ba9d2e0ca1aa0d7f56a32e6f5d06f3":[2,0,0,1,57,0],
-"classSteinberg_1_1Vst_1_1IMessage.html#a5a8458da03aa22462a3cfdb33af08dfe":[2,0,0,1,57,1],
-"classSteinberg_1_1Vst_1_1IMessage.html#a97646f7e4a63e3ba42454b35f80cd336":[2,0,0,1,57,2],
-"classSteinberg_1_1Vst_1_1IMidiLearn.html":[2,0,0,1,59],
-"classSteinberg_1_1Vst_1_1IMidiLearn.html#a466e384c55a31345e75c59564ac0b593":[2,0,0,1,59,0],
-"classSteinberg_1_1Vst_1_1IMidiMapping.html":[2,0,0,1,38],
-"classSteinberg_1_1Vst_1_1IMidiMapping.html#a62b10d017d6b2bc0e390e30d0e2a823b":[2,0,0,1,38,0],
-"classSteinberg_1_1Vst_1_1INoteExpressionController.html":[2,0,0,1,64],
-"classSteinberg_1_1Vst_1_1INoteExpressionController.html#a197a1b66cc45ba1935d9ce0894b1ee02":[2,0,0,1,64,0],
-"classSteinberg_1_1Vst_1_1INoteExpressionController.html#a457f017fc3566d143914e44523425d23":[2,0,0,1,64,2],
-"classSteinberg_1_1Vst_1_1INoteExpressionController.html#ab12d543cbd83560a9f098ed4a5c76af8":[2,0,0,1,64,1],
-"classSteinberg_1_1Vst_1_1INoteExpressionController.html#ab79e988315e33b4c30c8f2bd47a0cffc":[2,0,0,1,64,3],
-"classSteinberg_1_1Vst_1_1INoteExpressionPhysicalUIMapping.html":[2,0,0,1,72],
-"classSteinberg_1_1Vst_1_1INoteExpressionPhysicalUIMapping.html#a8cf4ab098e30cf53962a1e3079b0f5e5":[2,0,0,1,72,0],
-"classSteinberg_1_1Vst_1_1IParamValueQueue.html":[2,0,0,1,67],
-"classSteinberg_1_1Vst_1_1IParamValueQueue.html#a89cf5bac536a4a0a97ab81c8903ff3d7":[2,0,0,1,67,1],
-"classSteinberg_1_1Vst_1_1IParamValueQueue.html#abe1cf3f748932181aa3a80a10feb3d2b":[2,0,0,1,67,0],
-"classSteinberg_1_1Vst_1_1IParamValueQueue.html#ac10774ecd1a00877d5d1b315894be1a7":[2,0,0,1,67,2],
-"classSteinberg_1_1Vst_1_1IParamValueQueue.html#acf78c435afe4e71b1be548aa03ef4e3a":[2,0,0,1,67,3],
-"classSteinberg_1_1Vst_1_1IParameterChanges.html":[2,0,0,1,68],
-"classSteinberg_1_1Vst_1_1IParameterChanges.html#a6afbd15adb1f5b2f6d2101ad73b5c375":[2,0,0,1,68,1],
-"classSteinberg_1_1Vst_1_1IParameterChanges.html#ab6ffbb8e3bf6f4829ab1c9c23fe935a1":[2,0,0,1,68,0],
-"classSteinberg_1_1Vst_1_1IParameterChanges.html#ad8a5fbbc08fc082c41ad859b01247b8e":[2,0,0,1,68,2],
+"classSteinberg_1_1Vst_1_1IDataExchangeHandler.html":[2,0,0,1,32],
+"classSteinberg_1_1Vst_1_1IDataExchangeHandler.html#a025c90a7215ee8e868dee3fac262c204":[2,0,0,1,32,3],
+"classSteinberg_1_1Vst_1_1IDataExchangeHandler.html#a364dfe59ecafb51bd6520fa5ce527540":[2,0,0,1,32,2],
+"classSteinberg_1_1Vst_1_1IDataExchangeHandler.html#a9901db75c791ff2879a906b19ed388d9":[2,0,0,1,32,0],
+"classSteinberg_1_1Vst_1_1IDataExchangeHandler.html#ac0c45b4a114f40b229820fcd8121d4c8":[2,0,0,1,32,1],
+"classSteinberg_1_1Vst_1_1IDataExchangeReceiver.html":[2,0,0,1,33],
+"classSteinberg_1_1Vst_1_1IDataExchangeReceiver.html#a0145a4f12f524bb3f9bfe42cb66ad27c":[2,0,0,1,33,0],
+"classSteinberg_1_1Vst_1_1IDataExchangeReceiver.html#a37b2181ff0ae9bdc0a6feee03b65df42":[2,0,0,1,33,1],
+"classSteinberg_1_1Vst_1_1IDataExchangeReceiver.html#ae443e9ae05f5504aadff05412c8195e6":[2,0,0,1,33,2],
+"classSteinberg_1_1Vst_1_1IEditController.html":[2,0,0,1,39],
+"classSteinberg_1_1Vst_1_1IEditController.html#a0ba78602ecf2f5e8d747d8b01d4cfb6c":[2,0,0,1,39,4],
+"classSteinberg_1_1Vst_1_1IEditController.html#a10db03106be8ba89d23859fa6be5d9f6":[2,0,0,1,39,2],
+"classSteinberg_1_1Vst_1_1IEditController.html#a1fa4ed10cc0979e5559045104c998b1a":[2,0,0,1,39,12],
+"classSteinberg_1_1Vst_1_1IEditController.html#a4c2e1cafd88143fda2767a9c7ba5d48f":[2,0,0,1,39,0],
+"classSteinberg_1_1Vst_1_1IEditController.html#a77ac39bcc5c4b15818b1a87de2573805":[2,0,0,1,39,1],
+"classSteinberg_1_1Vst_1_1IEditController.html#a849747dc98909312b4cdbdeea82dbae0":[2,0,0,1,39,7],
+"classSteinberg_1_1Vst_1_1IEditController.html#aab2f0b853e75361d331b667e7893962e":[2,0,0,1,39,5],
+"classSteinberg_1_1Vst_1_1IEditController.html#aab5ccab5fd1cc1cd0a59afd90279dd81":[2,0,0,1,39,11],
+"classSteinberg_1_1Vst_1_1IEditController.html#ab6ffbb8e3bf6f4829ab1c9c23fe935a1":[2,0,0,1,39,3],
+"classSteinberg_1_1Vst_1_1IEditController.html#ac5abbadd4c8326fae66fd1e63bdc15b3":[2,0,0,1,39,9],
+"classSteinberg_1_1Vst_1_1IEditController.html#aded549c5b0f342a23dee18cc41ece6b8":[2,0,0,1,39,10],
+"classSteinberg_1_1Vst_1_1IEditController.html#ae9706616ae6d938bbf102954f8f2f110":[2,0,0,1,39,8],
+"classSteinberg_1_1Vst_1_1IEditController.html#af4254a0360b21f8871a61c62fb317058":[2,0,0,1,39,6],
+"classSteinberg_1_1Vst_1_1IEditController2.html":[2,0,0,1,40],
+"classSteinberg_1_1Vst_1_1IEditController2.html#a749ceb08d2f33b5b12cdc59172d8a7c3":[2,0,0,1,40,1],
+"classSteinberg_1_1Vst_1_1IEditController2.html#aa52846d39014c3ca95224fa98930e7a8":[2,0,0,1,40,2],
+"classSteinberg_1_1Vst_1_1IEditController2.html#ad38ac70a9efcc0cfee8ac0cc2b80e648":[2,0,0,1,40,0],
+"classSteinberg_1_1Vst_1_1IEditControllerHostEditing.html":[2,0,0,1,42],
+"classSteinberg_1_1Vst_1_1IEditControllerHostEditing.html#a589c94be69d4ee5ed29cf62e437fecbb":[2,0,0,1,42,1],
+"classSteinberg_1_1Vst_1_1IEditControllerHostEditing.html#a97cc85e97b22ff0d4fb9b5109a1a2bf2":[2,0,0,1,42,0],
+"classSteinberg_1_1Vst_1_1IEventList.html":[2,0,0,1,52],
+"classSteinberg_1_1Vst_1_1IEventList.html#a2e0abd231c54bd5c5a5e6f455169311e":[2,0,0,1,52,0],
+"classSteinberg_1_1Vst_1_1IEventList.html#a604181f48ab23957b7b9fcbb09c97fc1":[2,0,0,1,52,1],
+"classSteinberg_1_1Vst_1_1IEventList.html#aa58736dbdfb425c6c8f12b2129626370":[2,0,0,1,52,2],
+"classSteinberg_1_1Vst_1_1IHostApplication.html":[2,0,0,1,53],
+"classSteinberg_1_1Vst_1_1IHostApplication.html#a701520a52c46a25fdaca39ca4a28177f":[2,0,0,1,53,0],
+"classSteinberg_1_1Vst_1_1IHostApplication.html#a931e5a2ff8867bd8dfdbae1e42b78106":[2,0,0,1,53,1],
+"classSteinberg_1_1Vst_1_1IInterAppAudioConnectionNotification.html":[2,0,0,1,59],
+"classSteinberg_1_1Vst_1_1IInterAppAudioConnectionNotification.html#a57d886cb53419b840fe75049f3f4d6a6":[2,0,0,1,59,0],
+"classSteinberg_1_1Vst_1_1IInterAppAudioHost.html":[2,0,0,1,58],
+"classSteinberg_1_1Vst_1_1IInterAppAudioHost.html#a36e1db0db800560f4c70031e3ebc0a31":[2,0,0,1,58,0],
+"classSteinberg_1_1Vst_1_1IInterAppAudioHost.html#a4ec60e594f7ad548f697c39c252191d0":[2,0,0,1,58,4],
+"classSteinberg_1_1Vst_1_1IInterAppAudioHost.html#a83a79b604432e251a09cbfcdc0b367a8":[2,0,0,1,58,5],
+"classSteinberg_1_1Vst_1_1IInterAppAudioHost.html#a85482697be15b427dd93a5488beaf9a8":[2,0,0,1,58,1],
+"classSteinberg_1_1Vst_1_1IInterAppAudioHost.html#a8b0ced23b7d8e83d9bae5dcbc324f403":[2,0,0,1,58,2],
+"classSteinberg_1_1Vst_1_1IInterAppAudioHost.html#a8d4eef17f1de81905a5936f9849de029":[2,0,0,1,58,3],
+"classSteinberg_1_1Vst_1_1IInterAppAudioHost.html#aa6d66ecd68a991b8c12c40f39a5799c1":[2,0,0,1,58,7],
+"classSteinberg_1_1Vst_1_1IInterAppAudioHost.html#ae2524b3ead8126059bc897d1a97047e5":[2,0,0,1,58,6],
+"classSteinberg_1_1Vst_1_1IInterAppAudioPresetManager.html":[2,0,0,1,60],
+"classSteinberg_1_1Vst_1_1IInterAppAudioPresetManager.html#a236a03d49a8c928c39c4191881ba5406":[2,0,0,1,60,1],
+"classSteinberg_1_1Vst_1_1IInterAppAudioPresetManager.html#a6d707548076cb27d64e04c155ccba7d2":[2,0,0,1,60,2],
+"classSteinberg_1_1Vst_1_1IInterAppAudioPresetManager.html#a726a6db5c25f476bcb9d0f8bc7f24245":[2,0,0,1,60,3],
+"classSteinberg_1_1Vst_1_1IInterAppAudioPresetManager.html#a74e27f28ba190ed2834ddcf99f8b13f7":[2,0,0,1,60,0],
+"classSteinberg_1_1Vst_1_1IKeyswitchController.html":[2,0,0,1,70],
+"classSteinberg_1_1Vst_1_1IKeyswitchController.html#a8193190849039a70d08b084241d29e38":[2,0,0,1,70,1],
+"classSteinberg_1_1Vst_1_1IKeyswitchController.html#aa98a707edb1b58d05da0c50e38983a4e":[2,0,0,1,70,0],
+"classSteinberg_1_1Vst_1_1IMessage.html":[2,0,0,1,61],
+"classSteinberg_1_1Vst_1_1IMessage.html#a56ba9d2e0ca1aa0d7f56a32e6f5d06f3":[2,0,0,1,61,0],
+"classSteinberg_1_1Vst_1_1IMessage.html#a5a8458da03aa22462a3cfdb33af08dfe":[2,0,0,1,61,1],
+"classSteinberg_1_1Vst_1_1IMessage.html#a97646f7e4a63e3ba42454b35f80cd336":[2,0,0,1,61,2],
+"classSteinberg_1_1Vst_1_1IMidiLearn.html":[2,0,0,1,63],
+"classSteinberg_1_1Vst_1_1IMidiLearn.html#a466e384c55a31345e75c59564ac0b593":[2,0,0,1,63,0],
+"classSteinberg_1_1Vst_1_1IMidiMapping.html":[2,0,0,1,41],
+"classSteinberg_1_1Vst_1_1IMidiMapping.html#a62b10d017d6b2bc0e390e30d0e2a823b":[2,0,0,1,41,0],
+"classSteinberg_1_1Vst_1_1INoteExpressionController.html":[2,0,0,1,68],
+"classSteinberg_1_1Vst_1_1INoteExpressionController.html#a197a1b66cc45ba1935d9ce0894b1ee02":[2,0,0,1,68,0],
+"classSteinberg_1_1Vst_1_1INoteExpressionController.html#a457f017fc3566d143914e44523425d23":[2,0,0,1,68,2],
+"classSteinberg_1_1Vst_1_1INoteExpressionController.html#ab12d543cbd83560a9f098ed4a5c76af8":[2,0,0,1,68,1],
+"classSteinberg_1_1Vst_1_1INoteExpressionController.html#ab79e988315e33b4c30c8f2bd47a0cffc":[2,0,0,1,68,3],
+"classSteinberg_1_1Vst_1_1INoteExpressionPhysicalUIMapping.html":[2,0,0,1,76],
+"classSteinberg_1_1Vst_1_1INoteExpressionPhysicalUIMapping.html#a8cf4ab098e30cf53962a1e3079b0f5e5":[2,0,0,1,76,0],
+"classSteinberg_1_1Vst_1_1IParamValueQueue.html":[2,0,0,1,71],
+"classSteinberg_1_1Vst_1_1IParamValueQueue.html#a89cf5bac536a4a0a97ab81c8903ff3d7":[2,0,0,1,71,1],
+"classSteinberg_1_1Vst_1_1IParamValueQueue.html#abe1cf3f748932181aa3a80a10feb3d2b":[2,0,0,1,71,0],
+"classSteinberg_1_1Vst_1_1IParamValueQueue.html#ac10774ecd1a00877d5d1b315894be1a7":[2,0,0,1,71,2],
+"classSteinberg_1_1Vst_1_1IParamValueQueue.html#acf78c435afe4e71b1be548aa03ef4e3a":[2,0,0,1,71,3],
+"classSteinberg_1_1Vst_1_1IParameterChanges.html":[2,0,0,1,72],
+"classSteinberg_1_1Vst_1_1IParameterChanges.html#a6afbd15adb1f5b2f6d2101ad73b5c375":[2,0,0,1,72,1],
+"classSteinberg_1_1Vst_1_1IParameterChanges.html#ab6ffbb8e3bf6f4829ab1c9c23fe935a1":[2,0,0,1,72,0],
+"classSteinberg_1_1Vst_1_1IParameterChanges.html#ad8a5fbbc08fc082c41ad859b01247b8e":[2,0,0,1,72,2],
 "classSteinberg_1_1Vst_1_1IParameterFinder.html":[0,9,1],
 "classSteinberg_1_1Vst_1_1IParameterFinder.html#afd8d9733eee7b052280d7ddd0057b8ea":[0,9,1,0],
-"classSteinberg_1_1Vst_1_1IParameterFunctionName.html":[2,0,0,1,69],
-"classSteinberg_1_1Vst_1_1IParameterFunctionName.html#a6b55bd3794ff48f3fff15b77962bccc9":[2,0,0,1,69,0],
-"classSteinberg_1_1Vst_1_1IPlugInterfaceSupport.html":[2,0,0,1,73],
-"classSteinberg_1_1Vst_1_1IPlugInterfaceSupport.html#acd41b87681c74169d1983afebc7fa3af":[2,0,0,1,73,0],
-"classSteinberg_1_1Vst_1_1IPrefetchableSupport.html":[2,0,0,1,74],
-"classSteinberg_1_1Vst_1_1IPrefetchableSupport.html#a127acb45e09dda596a2cdb7cf31b5a32":[2,0,0,1,74,0],
+"classSteinberg_1_1Vst_1_1IParameterFunctionName.html":[2,0,0,1,73],
+"classSteinberg_1_1Vst_1_1IParameterFunctionName.html#a6b55bd3794ff48f3fff15b77962bccc9":[2,0,0,1,73,0],
+"classSteinberg_1_1Vst_1_1IPlugInterfaceSupport.html":[2,0,0,1,77],
+"classSteinberg_1_1Vst_1_1IPlugInterfaceSupport.html#acd41b87681c74169d1983afebc7fa3af":[2,0,0,1,77,0],
+"classSteinberg_1_1Vst_1_1IPrefetchableSupport.html":[2,0,0,1,78],
+"classSteinberg_1_1Vst_1_1IPrefetchableSupport.html#a127acb45e09dda596a2cdb7cf31b5a32":[2,0,0,1,78,0],
 "classSteinberg_1_1Vst_1_1IProcessContextRequirements.html":[2,0,0,1,23],
 "classSteinberg_1_1Vst_1_1IProcessContextRequirements.html#a7f15e6c619e637ca67a1b0cdebdc93bc":[2,0,0,1,23,1],
 "classSteinberg_1_1Vst_1_1IProcessContextRequirements.html#aa705cf7e79a21c2352b00ffe20cd295f":[2,0,0,1,23,0],
@@ -229,25 +240,14 @@ var NAVTREEINDEX0 =
 "classSteinberg_1_1Vst_1_1IProcessContextRequirements.html#aa705cf7e79a21c2352b00ffe20cd295fab82decaf7fc62b5057ed93f563ed4945":[2,0,0,1,23,0,2],
 "classSteinberg_1_1Vst_1_1IProcessContextRequirements.html#aa705cf7e79a21c2352b00ffe20cd295faeefe9f93afa959b33c00ea3ec1373b2d":[2,0,0,1,23,0,9],
 "classSteinberg_1_1Vst_1_1IProcessContextRequirements.html#aa705cf7e79a21c2352b00ffe20cd295fafb72587bd903135883991114527e6f1d":[2,0,0,1,23,0,8],
-"classSteinberg_1_1Vst_1_1IProgramListData.html":[2,0,0,1,87],
-"classSteinberg_1_1Vst_1_1IProgramListData.html#aaff57861e6da9c4026a0737b300df28f":[2,0,0,1,87,1],
-"classSteinberg_1_1Vst_1_1IProgramListData.html#abc46e67ff37c30223ab01b70fe49a2e3":[2,0,0,1,87,0],
-"classSteinberg_1_1Vst_1_1IProgramListData.html#ac81ba6ad1e5d49d7a9884b6dc7d27507":[2,0,0,1,87,2],
-"classSteinberg_1_1Vst_1_1IProgress.html":[2,0,0,1,35],
-"classSteinberg_1_1Vst_1_1IProgress.html#a3ef076eede20a0ee55ebaaf923a3d45d":[2,0,0,1,35,4],
-"classSteinberg_1_1Vst_1_1IProgress.html#a45c90e893f7d0f2f26975dcb70d30120":[2,0,0,1,35,3],
-"classSteinberg_1_1Vst_1_1IProgress.html#a69d16526a64609e721e3a65f3353d666":[2,0,0,1,35,1],
-"classSteinberg_1_1Vst_1_1IProgress.html#a69d16526a64609e721e3a65f3353d666a8a96cf62341a7bc94fc993f779ac3e7a":[2,0,0,1,35,1,0],
-"classSteinberg_1_1Vst_1_1IProgress.html#a69d16526a64609e721e3a65f3353d666a8d3931cf6d187855412e0c5008bc945b":[2,0,0,1,35,1,1],
-"classSteinberg_1_1Vst_1_1IProgress.html#a7da93484ec5338cb5b7cfa586b2a4387":[2,0,0,1,35,0],
-"classSteinberg_1_1Vst_1_1IProgress.html#ac30d985ff73621fa4dd18c67b096e590":[2,0,0,1,35,2],
-"classSteinberg_1_1Vst_1_1IStreamAttributes.html":[2,0,0,1,17],
-"classSteinberg_1_1Vst_1_1IStreamAttributes.html#a97646f7e4a63e3ba42454b35f80cd336":[2,0,0,1,17,1],
-"classSteinberg_1_1Vst_1_1IStreamAttributes.html#ad8d90e182b51e387734f307c2c12a2f4":[2,0,0,1,17,0],
-"classSteinberg_1_1Vst_1_1ITestPlugProvider.html":[2,0,0,1,80],
-"classSteinberg_1_1Vst_1_1ITestPlugProvider.html#a3684bfce1f1a4c1141765095613bb424":[2,0,0,1,80,3],
-"classSteinberg_1_1Vst_1_1ITestPlugProvider.html#a41ed5d90224e89e2eeaa8efba4e6de6e":[2,0,0,1,80,4],
-"classSteinberg_1_1Vst_1_1ITestPlugProvider.html#a56e195d1d9cb606f7a17c49b5efcc3c9":[2,0,0,1,80,2],
-"classSteinberg_1_1Vst_1_1ITestPlugProvider.html#aaf82c4f26b97f522e6ead97028a3f7c4":[2,0,0,1,80,1],
-"classSteinberg_1_1Vst_1_1ITestPlugProvider.html#abec872fb216eae440b5b7de078d464a6":[2,0,0,1,80,0]
+"classSteinberg_1_1Vst_1_1IProgramListData.html":[2,0,0,1,91],
+"classSteinberg_1_1Vst_1_1IProgramListData.html#aaff57861e6da9c4026a0737b300df28f":[2,0,0,1,91,1],
+"classSteinberg_1_1Vst_1_1IProgramListData.html#abc46e67ff37c30223ab01b70fe49a2e3":[2,0,0,1,91,0],
+"classSteinberg_1_1Vst_1_1IProgramListData.html#ac81ba6ad1e5d49d7a9884b6dc7d27507":[2,0,0,1,91,2],
+"classSteinberg_1_1Vst_1_1IProgress.html":[2,0,0,1,38],
+"classSteinberg_1_1Vst_1_1IProgress.html#a3ef076eede20a0ee55ebaaf923a3d45d":[2,0,0,1,38,4],
+"classSteinberg_1_1Vst_1_1IProgress.html#a45c90e893f7d0f2f26975dcb70d30120":[2,0,0,1,38,3],
+"classSteinberg_1_1Vst_1_1IProgress.html#a69d16526a64609e721e3a65f3353d666":[2,0,0,1,38,1],
+"classSteinberg_1_1Vst_1_1IProgress.html#a69d16526a64609e721e3a65f3353d666a8a96cf62341a7bc94fc993f779ac3e7a":[2,0,0,1,38,1,0],
+"classSteinberg_1_1Vst_1_1IProgress.html#a69d16526a64609e721e3a65f3353d666a8d3931cf6d187855412e0c5008bc945b":[2,0,0,1,38,1,1]
 };
