@@ -1,37 +1,48 @@
 var NAVTREEINDEX1 =
 {
-"classSteinberg_1_1Vst_1_1ITestPlugProvider2.html":[2,0,0,1,81],
-"classSteinberg_1_1Vst_1_1ITestPlugProvider2.html#a9dcc98679997d133da909913d65b66ef":[2,0,0,1,81,0],
-"classSteinberg_1_1Vst_1_1IUnitData.html":[2,0,0,1,88],
-"classSteinberg_1_1Vst_1_1IUnitData.html#a0ea283ed20afcc7f1b860abd05064bbb":[2,0,0,1,88,1],
-"classSteinberg_1_1Vst_1_1IUnitData.html#a77520fed67487e60b57cebde871d7f48":[2,0,0,1,88,0],
-"classSteinberg_1_1Vst_1_1IUnitData.html#aa01ffe25404ad1810e9076e205ce25fa":[2,0,0,1,88,2],
-"classSteinberg_1_1Vst_1_1IUnitHandler.html":[2,0,0,1,84],
-"classSteinberg_1_1Vst_1_1IUnitHandler.html#a3f4dc142ae3d50a04aa416fee14d4da4":[2,0,0,1,84,1],
-"classSteinberg_1_1Vst_1_1IUnitHandler.html#ab05a9a8dcca888caeabdb8ed74766bc6":[2,0,0,1,84,0],
-"classSteinberg_1_1Vst_1_1IUnitHandler2.html":[2,0,0,1,85],
-"classSteinberg_1_1Vst_1_1IUnitHandler2.html#ad1f48213839cc5b28a612a2baaba6584":[2,0,0,1,85,0],
-"classSteinberg_1_1Vst_1_1IUnitInfo.html":[2,0,0,1,86],
-"classSteinberg_1_1Vst_1_1IUnitInfo.html#a0db929591fd4fc242935edb91e65ed30":[2,0,0,1,86,3],
-"classSteinberg_1_1Vst_1_1IUnitInfo.html#a23fd4bc09e5bfee39c31bbba1ab2385b":[2,0,0,1,86,0],
-"classSteinberg_1_1Vst_1_1IUnitInfo.html#a2504c2bb3c57742102577f34cb58e257":[2,0,0,1,86,9],
-"classSteinberg_1_1Vst_1_1IUnitInfo.html#a2d04f6147a8c2d4b11e9cb9aae39514b":[2,0,0,1,86,2],
-"classSteinberg_1_1Vst_1_1IUnitInfo.html#a4417b27a9a3730bc49a933bc0d2bde7d":[2,0,0,1,86,4],
-"classSteinberg_1_1Vst_1_1IUnitInfo.html#a6126c4506f7981b5e800c6b4daa1e66b":[2,0,0,1,86,7],
-"classSteinberg_1_1Vst_1_1IUnitInfo.html#a63c02601259d4e8690f26eefaad53195":[2,0,0,1,86,6],
-"classSteinberg_1_1Vst_1_1IUnitInfo.html#a6f1b43425ba894764f35b7d492e81c53":[2,0,0,1,86,8],
-"classSteinberg_1_1Vst_1_1IUnitInfo.html#a718fa905d04d7d559bc89c7ca761413b":[2,0,0,1,86,10],
-"classSteinberg_1_1Vst_1_1IUnitInfo.html#a7cbc86917a614918938277be9bb52e6f":[2,0,0,1,86,11],
-"classSteinberg_1_1Vst_1_1IUnitInfo.html#ac40c799f1f52837c311ac153d7a8ead7":[2,0,0,1,86,5],
-"classSteinberg_1_1Vst_1_1IUnitInfo.html#ad32cdcda859f588c84e76133f2d62923":[2,0,0,1,86,1],
-"classSteinberg_1_1Vst_1_1IVst3ToAAXWrapper.html":[2,0,0,1,52],
-"classSteinberg_1_1Vst_1_1IVst3ToAUWrapper.html":[2,0,0,1,51],
-"classSteinberg_1_1Vst_1_1IVst3ToVst2Wrapper.html":[2,0,0,1,50],
-"classSteinberg_1_1Vst_1_1IVst3WrapperMPESupport.html":[2,0,0,1,53],
-"classSteinberg_1_1Vst_1_1IVst3WrapperMPESupport.html#a322e79e7c76c3e2b5f717e9666870c58":[2,0,0,1,53,0],
-"classSteinberg_1_1Vst_1_1IVst3WrapperMPESupport.html#ae3cece9ab989e0769cb14377e2f719b1":[2,0,0,1,53,1],
-"classSteinberg_1_1Vst_1_1IXmlRepresentationController.html":[2,0,0,1,79],
-"classSteinberg_1_1Vst_1_1IXmlRepresentationController.html#a12aaff5f46c6f620fb724e9c9763ac21":[2,0,0,1,79,0],
+"classSteinberg_1_1Vst_1_1IProgress.html#a7da93484ec5338cb5b7cfa586b2a4387":[2,0,0,1,38,0],
+"classSteinberg_1_1Vst_1_1IProgress.html#ac30d985ff73621fa4dd18c67b096e590":[2,0,0,1,38,2],
+"classSteinberg_1_1Vst_1_1IStreamAttributes.html":[2,0,0,1,17],
+"classSteinberg_1_1Vst_1_1IStreamAttributes.html#a97646f7e4a63e3ba42454b35f80cd336":[2,0,0,1,17,1],
+"classSteinberg_1_1Vst_1_1IStreamAttributes.html#ad8d90e182b51e387734f307c2c12a2f4":[2,0,0,1,17,0],
+"classSteinberg_1_1Vst_1_1ITestPlugProvider.html":[2,0,0,1,84],
+"classSteinberg_1_1Vst_1_1ITestPlugProvider.html#a3684bfce1f1a4c1141765095613bb424":[2,0,0,1,84,3],
+"classSteinberg_1_1Vst_1_1ITestPlugProvider.html#a41ed5d90224e89e2eeaa8efba4e6de6e":[2,0,0,1,84,4],
+"classSteinberg_1_1Vst_1_1ITestPlugProvider.html#a56e195d1d9cb606f7a17c49b5efcc3c9":[2,0,0,1,84,2],
+"classSteinberg_1_1Vst_1_1ITestPlugProvider.html#aaf82c4f26b97f522e6ead97028a3f7c4":[2,0,0,1,84,1],
+"classSteinberg_1_1Vst_1_1ITestPlugProvider.html#abec872fb216eae440b5b7de078d464a6":[2,0,0,1,84,0],
+"classSteinberg_1_1Vst_1_1ITestPlugProvider2.html":[2,0,0,1,85],
+"classSteinberg_1_1Vst_1_1ITestPlugProvider2.html#a9dcc98679997d133da909913d65b66ef":[2,0,0,1,85,0],
+"classSteinberg_1_1Vst_1_1IUnitData.html":[2,0,0,1,92],
+"classSteinberg_1_1Vst_1_1IUnitData.html#a0ea283ed20afcc7f1b860abd05064bbb":[2,0,0,1,92,1],
+"classSteinberg_1_1Vst_1_1IUnitData.html#a77520fed67487e60b57cebde871d7f48":[2,0,0,1,92,0],
+"classSteinberg_1_1Vst_1_1IUnitData.html#aa01ffe25404ad1810e9076e205ce25fa":[2,0,0,1,92,2],
+"classSteinberg_1_1Vst_1_1IUnitHandler.html":[2,0,0,1,88],
+"classSteinberg_1_1Vst_1_1IUnitHandler.html#a3f4dc142ae3d50a04aa416fee14d4da4":[2,0,0,1,88,1],
+"classSteinberg_1_1Vst_1_1IUnitHandler.html#ab05a9a8dcca888caeabdb8ed74766bc6":[2,0,0,1,88,0],
+"classSteinberg_1_1Vst_1_1IUnitHandler2.html":[2,0,0,1,89],
+"classSteinberg_1_1Vst_1_1IUnitHandler2.html#ad1f48213839cc5b28a612a2baaba6584":[2,0,0,1,89,0],
+"classSteinberg_1_1Vst_1_1IUnitInfo.html":[2,0,0,1,90],
+"classSteinberg_1_1Vst_1_1IUnitInfo.html#a0db929591fd4fc242935edb91e65ed30":[2,0,0,1,90,3],
+"classSteinberg_1_1Vst_1_1IUnitInfo.html#a23fd4bc09e5bfee39c31bbba1ab2385b":[2,0,0,1,90,0],
+"classSteinberg_1_1Vst_1_1IUnitInfo.html#a2504c2bb3c57742102577f34cb58e257":[2,0,0,1,90,9],
+"classSteinberg_1_1Vst_1_1IUnitInfo.html#a2d04f6147a8c2d4b11e9cb9aae39514b":[2,0,0,1,90,2],
+"classSteinberg_1_1Vst_1_1IUnitInfo.html#a4417b27a9a3730bc49a933bc0d2bde7d":[2,0,0,1,90,4],
+"classSteinberg_1_1Vst_1_1IUnitInfo.html#a6126c4506f7981b5e800c6b4daa1e66b":[2,0,0,1,90,7],
+"classSteinberg_1_1Vst_1_1IUnitInfo.html#a63c02601259d4e8690f26eefaad53195":[2,0,0,1,90,6],
+"classSteinberg_1_1Vst_1_1IUnitInfo.html#a6f1b43425ba894764f35b7d492e81c53":[2,0,0,1,90,8],
+"classSteinberg_1_1Vst_1_1IUnitInfo.html#a718fa905d04d7d559bc89c7ca761413b":[2,0,0,1,90,10],
+"classSteinberg_1_1Vst_1_1IUnitInfo.html#a7cbc86917a614918938277be9bb52e6f":[2,0,0,1,90,11],
+"classSteinberg_1_1Vst_1_1IUnitInfo.html#ac40c799f1f52837c311ac153d7a8ead7":[2,0,0,1,90,5],
+"classSteinberg_1_1Vst_1_1IUnitInfo.html#ad32cdcda859f588c84e76133f2d62923":[2,0,0,1,90,1],
+"classSteinberg_1_1Vst_1_1IVst3ToAAXWrapper.html":[2,0,0,1,56],
+"classSteinberg_1_1Vst_1_1IVst3ToAUWrapper.html":[2,0,0,1,55],
+"classSteinberg_1_1Vst_1_1IVst3ToVst2Wrapper.html":[2,0,0,1,54],
+"classSteinberg_1_1Vst_1_1IVst3WrapperMPESupport.html":[2,0,0,1,57],
+"classSteinberg_1_1Vst_1_1IVst3WrapperMPESupport.html#a322e79e7c76c3e2b5f717e9666870c58":[2,0,0,1,57,0],
+"classSteinberg_1_1Vst_1_1IVst3WrapperMPESupport.html#ae3cece9ab989e0769cb14377e2f719b1":[2,0,0,1,57,1],
+"classSteinberg_1_1Vst_1_1IXmlRepresentationController.html":[2,0,0,1,83],
+"classSteinberg_1_1Vst_1_1IXmlRepresentationController.html#a12aaff5f46c6f620fb724e9c9763ac21":[2,0,0,1,83,0],
 "classes.html":[2,1],
 "files.html":[3,0],
 "functions.html":[2,3,0],
@@ -50,16 +61,35 @@ var NAVTREEINDEX1 =
 "functions_0x6e.html":[2,3,0,12],
 "functions_0x6f.html":[2,3,0,13],
 "functions_0x70.html":[2,3,0,14],
-"functions_0x72.html":[2,3,0,15],
-"functions_0x73.html":[2,3,0,16],
-"functions_0x74.html":[2,3,0,17],
-"functions_0x75.html":[2,3,0,18],
-"functions_0x76.html":[2,3,0,19],
+"functions_0x71.html":[2,3,0,15],
+"functions_0x72.html":[2,3,0,16],
+"functions_0x73.html":[2,3,0,17],
+"functions_0x74.html":[2,3,0,18],
+"functions_0x75.html":[2,3,0,19],
+"functions_0x76.html":[2,3,0,20],
 "functions_enum.html":[2,3,4],
 "functions_eval.html":[2,3,5],
 "functions_func.html":[2,3,1],
 "functions_type.html":[2,3,3],
 "functions_vars.html":[2,3,2],
+"functions_vars.html":[2,3,2,0],
+"functions_vars_0x62.html":[2,3,2,1],
+"functions_vars_0x63.html":[2,3,2,2],
+"functions_vars_0x64.html":[2,3,2,3],
+"functions_vars_0x66.html":[2,3,2,4],
+"functions_vars_0x68.html":[2,3,2,5],
+"functions_vars_0x69.html":[2,3,2,6],
+"functions_vars_0x6b.html":[2,3,2,7],
+"functions_vars_0x6c.html":[2,3,2,8],
+"functions_vars_0x6d.html":[2,3,2,9],
+"functions_vars_0x6e.html":[2,3,2,10],
+"functions_vars_0x6f.html":[2,3,2,11],
+"functions_vars_0x70.html":[2,3,2,12],
+"functions_vars_0x72.html":[2,3,2,13],
+"functions_vars_0x73.html":[2,3,2,14],
+"functions_vars_0x74.html":[2,3,2,15],
+"functions_vars_0x75.html":[2,3,2,16],
+"functions_vars_0x76.html":[2,3,2,17],
 "globals.html":[3,1,0],
 "globals_defs.html":[3,1,1],
 "group__musicalCharacter.html":[0,7],
@@ -219,35 +249,5 @@ var NAVTREEINDEX1 =
 "group__musicalInstrument.html#gaccf4a6cc04deede6234aa80f17494e62":[0,5,9],
 "group__musicalInstrument.html#gad21b480ba2888b09f222c703fbb37a91":[0,5,71],
 "group__musicalInstrument.html#gad3c91ff5b7e51b5ed71479994af1f2b0":[0,5,104],
-"group__musicalInstrument.html#gadec30a0adbbd248d6573f64342feef77":[0,5,33],
-"group__musicalInstrument.html#gae18de76efc605860475b6323ef233cc8":[0,5,79],
-"group__musicalInstrument.html#gae4e52f708efde91cf0f2a78cebbd351c":[0,5,16],
-"group__musicalInstrument.html#gae7c3bd91d4fb0872ab7db0ed74d91445":[0,5,14],
-"group__musicalInstrument.html#gae87c28eecf427576aaba8dba45506307":[0,5,50],
-"group__musicalInstrument.html#gaeb469e5850a09e7863b3a411bd839185":[0,5,100],
-"group__musicalInstrument.html#gaeee07c58574e18dd64d3be93f7088a35":[0,5,19],
-"group__musicalInstrument.html#gaf1c302e30ac59f819c846264553cbb61":[0,5,101],
-"group__musicalInstrument.html#gaf2a091ea57274b72699e9f9df7715b17":[0,5,70],
-"group__musicalInstrument.html#gaf3cb2d886c19f654e5d4d8b25eb5477e":[0,5,58],
-"group__musicalInstrument.html#gaf85c8e569ae8d22ab2c233006a99f82e":[0,5,30],
-"group__musicalInstrument.html#gaf8cf7e44674db2aca92f56fd73f92006":[0,5,76],
-"group__musicalInstrument.html#gaf907f1b0c6b112a7a7ef2c26d181345b":[0,5,45],
-"group__musicalInstrument.html#gafd8251cd1e2beb471fb880eff54122a2":[0,5,90],
-"group__musicalStyle.html":[0,6],
-"group__musicalStyle.html#ga00100f8944908f3f674b077b8e7bf5ae":[0,6,18],
-"group__musicalStyle.html#ga03a11de347ee7fbfa80f6040e5838c06":[0,6,91],
-"group__musicalStyle.html#ga04e06e3becb8bca4036fd5856682a393":[0,6,50],
-"group__musicalStyle.html#ga04fc9ede978682cf37a56876ba9dba9d":[0,6,59],
-"group__musicalStyle.html#ga070e85734aa0ebd786f2c8ff8dca8301":[0,6,13],
-"group__musicalStyle.html#ga080e7eebf7cfeef648604aab356d9249":[0,6,7],
-"group__musicalStyle.html#ga09caf2a39534495b771aa65a0d969ad1":[0,6,99],
-"group__musicalStyle.html#ga0ade597c6d17afc9e6cf4a7bdf34de9b":[0,6,57],
-"group__musicalStyle.html#ga0d9c9e5d1d7762b13270a0cd388b2d7e":[0,6,3],
-"group__musicalStyle.html#ga0ee890f05a7479865af9eda6d34bc857":[0,6,62],
-"group__musicalStyle.html#ga13e10384c541982e7ebea23ae4cc0057":[0,6,51],
-"group__musicalStyle.html#ga1578d35d598b30c1a8aca33c94e33213":[0,6,36],
-"group__musicalStyle.html#ga17f0e511cbcdedf14156ba499a54d615":[0,6,100],
-"group__musicalStyle.html#ga1a1b8c73dee78995dfc73a9cbe1855fa":[0,6,26],
-"group__musicalStyle.html#ga1abdca80184a162d425c61f053530dea":[0,6,12],
-"group__musicalStyle.html#ga1b66689bf69717c4af8ad85835737acf":[0,6,79]
+"group__musicalInstrument.html#gadec30a0adbbd248d6573f64342feef77":[0,5,33]
 };
