@@ -1,5 +1,35 @@
 var NAVTREEINDEX2 =
 {
+"group__musicalInstrument.html#gae18de76efc605860475b6323ef233cc8":[0,5,79],
+"group__musicalInstrument.html#gae4e52f708efde91cf0f2a78cebbd351c":[0,5,16],
+"group__musicalInstrument.html#gae7c3bd91d4fb0872ab7db0ed74d91445":[0,5,14],
+"group__musicalInstrument.html#gae87c28eecf427576aaba8dba45506307":[0,5,50],
+"group__musicalInstrument.html#gaeb469e5850a09e7863b3a411bd839185":[0,5,100],
+"group__musicalInstrument.html#gaeee07c58574e18dd64d3be93f7088a35":[0,5,19],
+"group__musicalInstrument.html#gaf1c302e30ac59f819c846264553cbb61":[0,5,101],
+"group__musicalInstrument.html#gaf2a091ea57274b72699e9f9df7715b17":[0,5,70],
+"group__musicalInstrument.html#gaf3cb2d886c19f654e5d4d8b25eb5477e":[0,5,58],
+"group__musicalInstrument.html#gaf85c8e569ae8d22ab2c233006a99f82e":[0,5,30],
+"group__musicalInstrument.html#gaf8cf7e44674db2aca92f56fd73f92006":[0,5,76],
+"group__musicalInstrument.html#gaf907f1b0c6b112a7a7ef2c26d181345b":[0,5,45],
+"group__musicalInstrument.html#gafd8251cd1e2beb471fb880eff54122a2":[0,5,90],
+"group__musicalStyle.html":[0,6],
+"group__musicalStyle.html#ga00100f8944908f3f674b077b8e7bf5ae":[0,6,18],
+"group__musicalStyle.html#ga03a11de347ee7fbfa80f6040e5838c06":[0,6,91],
+"group__musicalStyle.html#ga04e06e3becb8bca4036fd5856682a393":[0,6,50],
+"group__musicalStyle.html#ga04fc9ede978682cf37a56876ba9dba9d":[0,6,59],
+"group__musicalStyle.html#ga070e85734aa0ebd786f2c8ff8dca8301":[0,6,13],
+"group__musicalStyle.html#ga080e7eebf7cfeef648604aab356d9249":[0,6,7],
+"group__musicalStyle.html#ga09caf2a39534495b771aa65a0d969ad1":[0,6,99],
+"group__musicalStyle.html#ga0ade597c6d17afc9e6cf4a7bdf34de9b":[0,6,57],
+"group__musicalStyle.html#ga0d9c9e5d1d7762b13270a0cd388b2d7e":[0,6,3],
+"group__musicalStyle.html#ga0ee890f05a7479865af9eda6d34bc857":[0,6,62],
+"group__musicalStyle.html#ga13e10384c541982e7ebea23ae4cc0057":[0,6,51],
+"group__musicalStyle.html#ga1578d35d598b30c1a8aca33c94e33213":[0,6,36],
+"group__musicalStyle.html#ga17f0e511cbcdedf14156ba499a54d615":[0,6,100],
+"group__musicalStyle.html#ga1a1b8c73dee78995dfc73a9cbe1855fa":[0,6,26],
+"group__musicalStyle.html#ga1abdca80184a162d425c61f053530dea":[0,6,12],
+"group__musicalStyle.html#ga1b66689bf69717c4af8ad85835737acf":[0,6,79],
 "group__musicalStyle.html#ga1e43c81772b3227d2239c4c869194733":[0,6,81],
 "group__musicalStyle.html#ga2283c2c777c7cbb21710e11ef2ceb6af":[0,6,0],
 "group__musicalStyle.html#ga24447081033911845dd5279102bf075b":[0,6,98],
@@ -151,103 +181,73 @@ var NAVTREEINDEX2 =
 "group__presetAttributes.html#gad5fe1f71ae69e7b4daaf0e79130930c3":[0,3,6],
 "group__presetAttributes.html#gaefefe46f30651266cc9ccc8908409552":[0,3,5],
 "group__speakerArrangements.html":[0,8],
-"group__speakerArrangements.html#ga0049a81a50306a41abd45f0871e13173":[0,8,364],
-"group__speakerArrangements.html#ga006f007337addc5c126777bc9e9b774d":[0,8,326],
+"group__speakerArrangements.html#ga0049a81a50306a41abd45f0871e13173":[0,8,381],
+"group__speakerArrangements.html#ga006f007337addc5c126777bc9e9b774d":[0,8,339],
 "group__speakerArrangements.html#ga00ba599749f21d817eb4721f10d16ab7":[0,8,37],
-"group__speakerArrangements.html#ga01056324cffd7c063a51196cd8fd6847":[0,8,130],
-"group__speakerArrangements.html#ga02d21f6bfee6423fceb6a3695954c33b":[0,8,118],
-"group__speakerArrangements.html#ga07019a8f7d26ec6d67e3b21a4909ad50":[0,8,257],
-"group__speakerArrangements.html#ga076816df2f77a47f7ffa7f954624886a":[0,8,339],
-"group__speakerArrangements.html#ga07bcd44b9922095ccd79f2195ad80e2b":[0,8,166],
-"group__speakerArrangements.html#ga07f09cbbdc4d96c628d69523a40d67ba":[0,8,162],
+"group__speakerArrangements.html#ga01056324cffd7c063a51196cd8fd6847":[0,8,133],
+"group__speakerArrangements.html#ga02d21f6bfee6423fceb6a3695954c33b":[0,8,121],
+"group__speakerArrangements.html#ga07019a8f7d26ec6d67e3b21a4909ad50":[0,8,265],
+"group__speakerArrangements.html#ga076816df2f77a47f7ffa7f954624886a":[0,8,352],
+"group__speakerArrangements.html#ga07bcd44b9922095ccd79f2195ad80e2b":[0,8,173],
+"group__speakerArrangements.html#ga07f09cbbdc4d96c628d69523a40d67ba":[0,8,169],
 "group__speakerArrangements.html#ga0874c430db7340ecf1c48962eaf436d0":[0,8,66],
-"group__speakerArrangements.html#ga0a7e4c0b7f089d11a7fb48afac04a074":[0,8,253],
-"group__speakerArrangements.html#ga0a881b193fdb5ee3949d4da3501cf4c5":[0,8,329],
-"group__speakerArrangements.html#ga0dbaa8d90949e4084abb7878a5d5f91b":[0,8,106],
-"group__speakerArrangements.html#ga0f4c3361e3f81439c234f22f2c526829":[0,8,211],
-"group__speakerArrangements.html#ga137e13924264d25e2b23315c90a1a735":[0,8,209],
-"group__speakerArrangements.html#ga13c1699c11fba17352b83a1b3a7cfcc8":[0,8,163],
-"group__speakerArrangements.html#ga153beb2d5d562ed4fc8643bf51c711d8":[0,8,103],
+"group__speakerArrangements.html#ga0a7e4c0b7f089d11a7fb48afac04a074":[0,8,261],
+"group__speakerArrangements.html#ga0a881b193fdb5ee3949d4da3501cf4c5":[0,8,342],
+"group__speakerArrangements.html#ga0dbaa8d90949e4084abb7878a5d5f91b":[0,8,109],
+"group__speakerArrangements.html#ga0f4c3361e3f81439c234f22f2c526829":[0,8,219],
+"group__speakerArrangements.html#ga137e13924264d25e2b23315c90a1a735":[0,8,217],
+"group__speakerArrangements.html#ga13c1699c11fba17352b83a1b3a7cfcc8":[0,8,170],
+"group__speakerArrangements.html#ga153beb2d5d562ed4fc8643bf51c711d8":[0,8,106],
 "group__speakerArrangements.html#ga1604729c414047881e20341108871354":[0,8,50],
-"group__speakerArrangements.html#ga16ff5025a411dc1c3b7fc305dfe53073":[0,8,313],
-"group__speakerArrangements.html#ga19addfe92087609dea4ef8c257becfbf":[0,8,302],
+"group__speakerArrangements.html#ga16ff5025a411dc1c3b7fc305dfe53073":[0,8,326],
+"group__speakerArrangements.html#ga17add6f7e226c7057f023d5fb79ea514":[0,8,81],
+"group__speakerArrangements.html#ga19887804c5277a7d95cb691486752326":[0,8,370],
+"group__speakerArrangements.html#ga19addfe92087609dea4ef8c257becfbf":[0,8,315],
 "group__speakerArrangements.html#ga1a373406598a8f7208d98e94a039d377":[0,8,47],
-"group__speakerArrangements.html#ga1ab315f9942e83ed753c115f427d16a3":[0,8,169],
-"group__speakerArrangements.html#ga1b17445201a92bee4c23dd16e5cd1728":[0,8,351],
-"group__speakerArrangements.html#ga1b19ef3d9cbdfb96c008f4586b186997":[0,8,120],
-"group__speakerArrangements.html#ga1b7e67dba5f5333b64eb847d3d78668d":[0,8,306],
-"group__speakerArrangements.html#ga1b93e71fddaa428f500d5c00389e1983":[0,8,145],
-"group__speakerArrangements.html#ga1c30f7ea8d0b380ec954fd35e1cbc33e":[0,8,190],
-"group__speakerArrangements.html#ga1d0d1ec6684406ef2ca93eb7bd921bb3":[0,8,290],
-"group__speakerArrangements.html#ga1d7c7f813f01cd3f4478ecc81e46e82c":[0,8,139],
-"group__speakerArrangements.html#ga1e80c914f10746070e3ffe6e85eb5c1f":[0,8,208],
+"group__speakerArrangements.html#ga1ab315f9942e83ed753c115f427d16a3":[0,8,176],
+"group__speakerArrangements.html#ga1b17445201a92bee4c23dd16e5cd1728":[0,8,364],
+"group__speakerArrangements.html#ga1b19ef3d9cbdfb96c008f4586b186997":[0,8,123],
+"group__speakerArrangements.html#ga1b74afd94b2e5d860d1140c948b4dfff":[0,8,77],
+"group__speakerArrangements.html#ga1b7e67dba5f5333b64eb847d3d78668d":[0,8,319],
+"group__speakerArrangements.html#ga1b93e71fddaa428f500d5c00389e1983":[0,8,148],
+"group__speakerArrangements.html#ga1c30f7ea8d0b380ec954fd35e1cbc33e":[0,8,197],
+"group__speakerArrangements.html#ga1d0d1ec6684406ef2ca93eb7bd921bb3":[0,8,302],
+"group__speakerArrangements.html#ga1d7c7f813f01cd3f4478ecc81e46e82c":[0,8,142],
+"group__speakerArrangements.html#ga1e80c914f10746070e3ffe6e85eb5c1f":[0,8,216],
 "group__speakerArrangements.html#ga1eb079a06c32ed8dfe5640d1ea129beb":[0,8,10],
-"group__speakerArrangements.html#ga1f2886d3047f9f7b5fd699b1d9fa6a79":[0,8,371],
+"group__speakerArrangements.html#ga1f2886d3047f9f7b5fd699b1d9fa6a79":[0,8,388],
 "group__speakerArrangements.html#ga1f29f3c176afccd1a3b9572cbc58ded3":[0,8,59],
-"group__speakerArrangements.html#ga2057f29b65596edf1cb80ccc6a041b83":[0,8,198],
+"group__speakerArrangements.html#ga2057f29b65596edf1cb80ccc6a041b83":[0,8,206],
 "group__speakerArrangements.html#ga20ceaf9e134bcb9d31d268f2bca6f990":[0,8,6],
-"group__speakerArrangements.html#ga2133b89c1fce6c11540a55ede3d00715":[0,8,94],
-"group__speakerArrangements.html#ga2211a95b3ce1e534c1da0ad1824c4018":[0,8,365],
-"group__speakerArrangements.html#ga22796d2f7f109bde16a525429c8194af":[0,8,185],
-"group__speakerArrangements.html#ga22b0cac49e8ef5b3d9a1836abd021720":[0,8,296],
-"group__speakerArrangements.html#ga230b03c83c3ad137460b4ab78fdede4a":[0,8,233],
-"group__speakerArrangements.html#ga24d4f4886be5ec7ac6fa441212f9b402":[0,8,288],
-"group__speakerArrangements.html#ga272cd10cad55c182440769f24c656cc0":[0,8,369],
-"group__speakerArrangements.html#ga27352e019fb6f0d3b4d10b643f79d813":[0,8,108],
-"group__speakerArrangements.html#ga28381a787f5d2e84e16067329d0efc00":[0,8,259],
-"group__speakerArrangements.html#ga2990e1e187ac62b502407cad4fea5ae7":[0,8,368],
+"group__speakerArrangements.html#ga2133b89c1fce6c11540a55ede3d00715":[0,8,97],
+"group__speakerArrangements.html#ga2211a95b3ce1e534c1da0ad1824c4018":[0,8,382],
+"group__speakerArrangements.html#ga22796d2f7f109bde16a525429c8194af":[0,8,192],
+"group__speakerArrangements.html#ga22b0cac49e8ef5b3d9a1836abd021720":[0,8,309],
+"group__speakerArrangements.html#ga230b03c83c3ad137460b4ab78fdede4a":[0,8,241],
+"group__speakerArrangements.html#ga24d4f4886be5ec7ac6fa441212f9b402":[0,8,300],
+"group__speakerArrangements.html#ga270ac2f122e02a0570bb5eff60e7f9d1":[0,8,164],
+"group__speakerArrangements.html#ga272cd10cad55c182440769f24c656cc0":[0,8,386],
+"group__speakerArrangements.html#ga27352e019fb6f0d3b4d10b643f79d813":[0,8,111],
+"group__speakerArrangements.html#ga28381a787f5d2e84e16067329d0efc00":[0,8,267],
+"group__speakerArrangements.html#ga2990e1e187ac62b502407cad4fea5ae7":[0,8,385],
 "group__speakerArrangements.html#ga29b55e791de7fa8d4efdb6948d40db09":[0,8,20],
 "group__speakerArrangements.html#ga2a834a6c97df49e2fa45315ff7045533":[0,8,48],
-"group__speakerArrangements.html#ga2abe9ebdaff5cae2f2581a558cb3eb02":[0,8,245],
-"group__speakerArrangements.html#ga2b7412e5a07fbbce4e641a8fa7b81001":[0,8,269],
+"group__speakerArrangements.html#ga2abe9ebdaff5cae2f2581a558cb3eb02":[0,8,253],
+"group__speakerArrangements.html#ga2b7412e5a07fbbce4e641a8fa7b81001":[0,8,281],
 "group__speakerArrangements.html#ga2d6583c536b80d854cbd733eea9877f9":[0,8,68],
-"group__speakerArrangements.html#ga2ebfc79a0e5ef338247e31239967632d":[0,8,110],
-"group__speakerArrangements.html#ga2f2f2eb56bcf2977ad670a752c69d793":[0,8,315],
-"group__speakerArrangements.html#ga2f656b124363f1656327bf5fb9e7dc48":[0,8,281],
-"group__speakerArrangements.html#ga2fb8698f83d75be166b99fdbce9e82f1":[0,8,105],
+"group__speakerArrangements.html#ga2ebfc79a0e5ef338247e31239967632d":[0,8,113],
+"group__speakerArrangements.html#ga2f2f2eb56bcf2977ad670a752c69d793":[0,8,328],
+"group__speakerArrangements.html#ga2f656b124363f1656327bf5fb9e7dc48":[0,8,293],
+"group__speakerArrangements.html#ga2fb8698f83d75be166b99fdbce9e82f1":[0,8,108],
 "group__speakerArrangements.html#ga2fd1d5b534428e6414e46829089313f9":[0,8,5],
-"group__speakerArrangements.html#ga300b4574ad12477ff99286519b754dfe":[0,8,137],
-"group__speakerArrangements.html#ga301aef980be40689f6a32d2f2ea5990d":[0,8,240],
-"group__speakerArrangements.html#ga3087980012d3e5dee03f977677790623":[0,8,248],
-"group__speakerArrangements.html#ga30a288eb79dfa6b08afb569234e831d2":[0,8,235],
-"group__speakerArrangements.html#ga3151e2974547b528528e913542dd5292":[0,8,284],
-"group__speakerArrangements.html#ga31865a34aa4e3eca16df14729ff1629f":[0,8,203],
-"group__speakerArrangements.html#ga319dbf573206d0bb1a8b77e7f476548d":[0,8,378],
-"group__speakerArrangements.html#ga329178a60998946671c5de893797dddf":[0,8,104],
-"group__speakerArrangements.html#ga32b8626cc036129ae6465115e7d33c5a":[0,8,88],
-"group__speakerArrangements.html#ga341a094c1693e21946264eb706155c32":[0,8,336],
-"group__speakerArrangements.html#ga3475b1b161d22aca3939960e461307a5":[0,8,224],
-"group__speakerArrangements.html#ga34a5ea5d19e507a4cc75aaf5ca038e70":[0,8,221],
-"group__speakerArrangements.html#ga34c39373e8684ea0bdd623206d23f92a":[0,8,57],
-"group__speakerArrangements.html#ga34fbc53e44aafa8ca50155a58bd056fe":[0,8,91],
-"group__speakerArrangements.html#ga350fe92a4a9f185ff5a7141e7cbada14":[0,8,83],
-"group__speakerArrangements.html#ga3531cf9980f8fbeb289280f70cb82eb0":[0,8,56],
-"group__speakerArrangements.html#ga35ac01519b72d4f2ebc88a7621467378":[0,8,223],
-"group__speakerArrangements.html#ga35c11fa95eb4ed5340307b725c53180d":[0,8,237],
-"group__speakerArrangements.html#ga3633546c0ee46e3c70c52843faf722e6":[0,8,51],
-"group__speakerArrangements.html#ga365c311dce7ea3c41e6674d0c31893d9":[0,8,2],
-"group__speakerArrangements.html#ga36a920fcf904e74af45153417e6bda20":[0,8,370],
-"group__speakerArrangements.html#ga3789962208da8454667b34aa666981db":[0,8,309],
-"group__speakerArrangements.html#ga3818a39d5d27234b78a6dfa41385c749":[0,8,75],
-"group__speakerArrangements.html#ga38bd79e07efa7b1b2825a614e25e597e":[0,8,43],
-"group__speakerArrangements.html#ga38c557da6a4db5884d2d688c30cc5553":[0,8,194],
-"group__speakerArrangements.html#ga39cdd95afef98e1901ebdb99183e91f2":[0,8,201],
-"group__speakerArrangements.html#ga39dd41aa48652def01c2b774f3a46a02":[0,8,178],
-"group__speakerArrangements.html#ga3a6e7551ec2aebccdb70236a29eaae2d":[0,8,131],
-"group__speakerArrangements.html#ga3b0b6d1ed6af07daa84a016f9a594d59":[0,8,260],
-"group__speakerArrangements.html#ga3cb0fc4337ff0f43bf119b20c7f5d810":[0,8,295],
-"group__speakerArrangements.html#ga3e1ccb637aac3918a31d5b061bcaabe4":[0,8,11],
-"group__speakerArrangements.html#ga41826ce2877ff6e8fc93c8d4aa85647e":[0,8,61],
-"group__speakerArrangements.html#ga419904483b34cd1d809100f7388d50b7":[0,8,186],
-"group__speakerArrangements.html#ga42ee84421893fe9759b400d0bd3becaf":[0,8,243],
-"group__speakerArrangements.html#ga44710b9a538279e604b98213e8acdbec":[0,8,80],
-"group__speakerArrangements.html#ga447cbeb4a66d7a12f6c36240b666331a":[0,8,184],
-"group__speakerArrangements.html#ga4496b8a1fc103ed42e399eca71048d12":[0,8,147],
-"group__speakerArrangements.html#ga44ee3dd3579cc26082915d76a28be70f":[0,8,125],
-"group__speakerArrangements.html#ga45b8a48950dee4f9713bda0a5b9ca196":[0,8,251],
-"group__speakerArrangements.html#ga4623d9c5afc0883aa25409a89fc4b01c":[0,8,244],
-"group__speakerArrangements.html#ga47554e8c117d0119288c796708533bd5":[0,8,346],
-"group__speakerArrangements.html#ga48d6c553097c808e4d720a20af732555":[0,8,173],
-"group__speakerArrangements.html#ga49ccafdb4653781c17fa20f933a29af2":[0,8,258],
-"group__speakerArrangements.html#ga4a24b9cdab9b5ed5af4ae28cbe8f7205":[0,8,334]
+"group__speakerArrangements.html#ga300b4574ad12477ff99286519b754dfe":[0,8,140],
+"group__speakerArrangements.html#ga301aef980be40689f6a32d2f2ea5990d":[0,8,248],
+"group__speakerArrangements.html#ga3087980012d3e5dee03f977677790623":[0,8,256],
+"group__speakerArrangements.html#ga30a288eb79dfa6b08afb569234e831d2":[0,8,243],
+"group__speakerArrangements.html#ga3151e2974547b528528e913542dd5292":[0,8,296],
+"group__speakerArrangements.html#ga3160617565b0ad36d34a025fe119bbb6":[0,8,306],
+"group__speakerArrangements.html#ga31865a34aa4e3eca16df14729ff1629f":[0,8,211],
+"group__speakerArrangements.html#ga319dbf573206d0bb1a8b77e7f476548d":[0,8,395],
+"group__speakerArrangements.html#ga31c77ba2ccde7c76357149b9be8d1141":[0,8,167],
+"group__speakerArrangements.html#ga329178a60998946671c5de893797dddf":[0,8,107]
 };
