@@ -50,11 +50,12 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 ".html",
-"classSteinberg_1_1Vst_1_1ConnectionProxy.html#a12db172f74059f7eceb63714f4589aa0",
-"classSteinberg_1_1Vst_1_1ParameterContainer.html#a17ccf658ed2936c9d740dd1c5fada5dc",
-"classSteinberg_1_1Vst_1_1StringListParameter.html#a57131772fda4fd320e3d8cd7c7c981b7",
-"group__sdkBase.html",
-"structVST3_1_1UID.html#a20b2abb54d43add1d16c4c4660c43922"
+"classSteinberg_1_1Vst_1_1ComponentBase.html#ae8391f8417d768adbf055876641276cb",
+"classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html#a7fdfae5a8e4484cd756f500d797d019b",
+"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#adc3fc77f74a27de4c7238ffebda644bb",
+"functions_eval.html",
+"structSteinberg_1_1Vst_1_1RTTransferT.html",
+"vstrepresentation_8cpp.html#ac61d0f949ae6f50b934ce608f71ca4c1"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
