@@ -6,36 +6,36 @@ var NAVTREEINDEX0 =
 ".html":[4,0,0],
 ".html":[4,0,0,0],
 ".html":[4,0,0,1],
-"AudioIO_8h.html":[5,0,14],
-"AudioIO_8mm.html":[5,0,15],
-"AudioIO_8mm.html#ac032d233a8ebfcd82fd49d0824eefb18":[5,0,15,0],
-"AudioIO_8mm.html#ae10fe1cc8210f9fbd6bd159c65c8ef87":[5,0,15,1],
-"HostApp_8h.html":[5,0,28],
-"HostApp_8mm.html":[5,0,29],
+"AudioIO_8h.html":[5,0,15],
+"AudioIO_8mm.html":[5,0,16],
+"AudioIO_8mm.html#ac032d233a8ebfcd82fd49d0824eefb18":[5,0,16,0],
+"AudioIO_8mm.html#ae10fe1cc8210f9fbd6bd159c65c8ef87":[5,0,16,1],
+"HostApp_8h.html":[5,0,31],
+"HostApp_8mm.html":[5,0,32],
 "How.html":[1],
-"MidiIO_8h.html":[5,0,33],
-"MidiIO_8mm.html":[5,0,34],
-"NSDataIBStream_8h.html":[5,0,42],
-"NSDataIBStream_8mm.html":[5,0,43],
-"PresetBrowserViewController_8h.html":[5,0,53],
-"PresetBrowserViewController_8mm.html":[5,0,54],
-"PresetManager_8h.html":[5,0,55],
-"PresetManager_8mm.html":[5,0,56],
-"PresetSaveViewController_8h.html":[5,0,57],
-"PresetSaveViewController_8mm.html":[5,0,58],
-"SettingsViewController_8h.html":[5,0,66],
-"SettingsViewController_8h.html#a4deb5edab4ea5afce6e46372937444e2":[5,0,66,0],
-"SettingsViewController_8mm.html":[5,0,67],
-"SettingsViewController_8mm.html#a4deb5edab4ea5afce6e46372937444e2":[5,0,67,0],
-"VST3Editor_8h.html":[5,0,82],
-"VST3Editor_8mm.html":[5,0,83],
-"VST3Plugin_8h.html":[5,0,84],
-"VST3Plugin_8mm.html":[5,0,85],
-"VST3Plugin_8mm.html#a65451ddd317f3c796347114f42638024":[5,0,85,1],
-"VST3Plugin_8mm.html#a6763fb3bf363ffc54ee132d466c50297":[5,0,85,0],
-"VST3Plugin_8mm.html#ab2feb4fc133a7b3e0cdb5f9cdf941382":[5,0,85,2],
-"VSTInterAppAudioAppDelegateBase_8h.html":[5,0,105],
-"VSTInterAppAudioAppDelegateBase_8mm.html":[5,0,106],
+"MidiIO_8h.html":[5,0,38],
+"MidiIO_8mm.html":[5,0,39],
+"NSDataIBStream_8h.html":[5,0,47],
+"NSDataIBStream_8mm.html":[5,0,48],
+"PresetBrowserViewController_8h.html":[5,0,58],
+"PresetBrowserViewController_8mm.html":[5,0,59],
+"PresetManager_8h.html":[5,0,60],
+"PresetManager_8mm.html":[5,0,61],
+"PresetSaveViewController_8h.html":[5,0,62],
+"PresetSaveViewController_8mm.html":[5,0,63],
+"SettingsViewController_8h.html":[5,0,71],
+"SettingsViewController_8h.html#a4deb5edab4ea5afce6e46372937444e2":[5,0,71,0],
+"SettingsViewController_8mm.html":[5,0,72],
+"SettingsViewController_8mm.html#a4deb5edab4ea5afce6e46372937444e2":[5,0,72,0],
+"VST3Editor_8h.html":[5,0,89],
+"VST3Editor_8mm.html":[5,0,90],
+"VST3Plugin_8h.html":[5,0,91],
+"VST3Plugin_8mm.html":[5,0,92],
+"VST3Plugin_8mm.html#a65451ddd317f3c796347114f42638024":[5,0,92,1],
+"VST3Plugin_8mm.html#a6763fb3bf363ffc54ee132d466c50297":[5,0,92,0],
+"VST3Plugin_8mm.html#ab2feb4fc133a7b3e0cdb5f9cdf941382":[5,0,92,2],
+"VSTInterAppAudioAppDelegateBase_8h.html":[5,0,112],
+"VSTInterAppAudioAppDelegateBase_8mm.html":[5,0,113],
 "aaxentry_8cpp.html":[5,0,0],
 "aaxentry_8cpp.html#a11ef6f2b3053d009d2a02df2e8b91e4c":[5,0,0,0],
 "aaxentry_8cpp.html#a20ec2dc15aae43864287ac1324f7ae6a":[5,0,0,5],
@@ -65,27 +65,30 @@ var NAVTREEINDEX0 =
 "aaxwrapper__parameters_8cpp.html#aaa67275c53290bd99d516d4b9a5d7d76":[5,0,7,2],
 "aaxwrapper__parameters_8cpp.html#ae1442fa4c8580c698ec15ad2c81d861e":[5,0,7,0],
 "aaxwrapper__parameters_8h.html":[5,0,8],
+"alignedalloc_8h.html":[5,0,9],
+"alignedalloc_8h.html#aad3f24cc8aa05a74184f0ca1c9a91ca4":[5,0,9,1],
+"alignedalloc_8h.html#ab9aaea0732e868f54e5136b3dbd1eea0":[5,0,9,0],
 "annotated.html":[4,0],
-"aucarbonview_8h.html":[5,0,9],
-"aucarbonview_8mm.html":[5,0,10],
-"aucocoaview_8h.html":[5,0,11],
-"aucocoaview_8mm.html":[5,0,12],
-"audiobuffers_8h.html":[5,0,13],
-"audiobuffers_8h.html#a8c4a6da5d995b37cadedae307f2d2c6c":[5,0,13,0],
-"ausdk_8mm.html":[5,0,16],
-"ausdk_8mm.html#a50c2c53f304ec73ab38e263a613bc08a":[5,0,16,0],
-"ausdk_8mm.html#a8d2f585b61931548923953c378682bae":[5,0,16,2],
-"ausdk_8mm.html#a99407fa1f48220810f330b6b87d0ec94":[5,0,16,1],
-"auwrapper_8h.html":[5,0,17],
-"auwrapper_8h.html#ac05bad6da5537412e27595cc5b594ec0":[5,0,17,0],
-"auwrapper_8mm.html":[5,0,18],
-"auwrapper_8mm.html#a8f0ebdb7c0c33ce520bf24285d2a7e8a":[5,0,18,1],
-"auwrapper_8mm.html#aaaa58be85853abd13ca0f726d1c47eec":[5,0,18,2],
-"auwrapper_8mm.html#ad618dfeb6a874b97b0cffeeb5b8476a1":[5,0,18,0],
-"auwrapper_8mm.html#afaaf6a7ee35c2ec50044cec6010f3b93":[5,0,18,3],
-"basewrapper_8cpp.html":[5,0,19],
-"basewrapper_8h.html":[5,0,20],
-"basewrapper_8sdk_8cpp.html":[5,0,21],
+"aucarbonview_8h.html":[5,0,10],
+"aucarbonview_8mm.html":[5,0,11],
+"aucocoaview_8h.html":[5,0,12],
+"aucocoaview_8mm.html":[5,0,13],
+"audiobuffers_8h.html":[5,0,14],
+"audiobuffers_8h.html#a8c4a6da5d995b37cadedae307f2d2c6c":[5,0,14,0],
+"ausdk_8mm.html":[5,0,17],
+"ausdk_8mm.html#a50c2c53f304ec73ab38e263a613bc08a":[5,0,17,0],
+"ausdk_8mm.html#a8d2f585b61931548923953c378682bae":[5,0,17,2],
+"ausdk_8mm.html#a99407fa1f48220810f330b6b87d0ec94":[5,0,17,1],
+"auwrapper_8h.html":[5,0,18],
+"auwrapper_8h.html#ac05bad6da5537412e27595cc5b594ec0":[5,0,18,0],
+"auwrapper_8mm.html":[5,0,19],
+"auwrapper_8mm.html#a8f0ebdb7c0c33ce520bf24285d2a7e8a":[5,0,19,1],
+"auwrapper_8mm.html#aaaa58be85853abd13ca0f726d1c47eec":[5,0,19,2],
+"auwrapper_8mm.html#ad618dfeb6a874b97b0cffeeb5b8476a1":[5,0,19,0],
+"auwrapper_8mm.html#afaaf6a7ee35c2ec50044cec6010f3b93":[5,0,19,3],
+"basewrapper_8cpp.html":[5,0,20],
+"basewrapper_8h.html":[5,0,21],
+"basewrapper_8sdk_8cpp.html":[5,0,22],
 "classSteinberg_1_1CPluginView.html":[2,1,1],
 "classSteinberg_1_1CPluginView.html#a0144570339d77dd0b571af3dbb7f73be":[2,1,1,17],
 "classSteinberg_1_1CPluginView.html#a05d5160eff1e7032591b2a94be56ba39":[2,1,1,12],
@@ -246,8 +249,5 @@ var NAVTREEINDEX0 =
 "classSteinberg_1_1Vst_1_1ComponentBase.html#aae7bbbf07353224bb0ba77a091b87d33":[2,0,6,4],
 "classSteinberg_1_1Vst_1_1ComponentBase.html#ab3b1f8979c4bbe983e42010925959fd3":[2,0,6,0],
 "classSteinberg_1_1Vst_1_1ComponentBase.html#ab599093d44aa82deac5e46dba5cb8d18":[2,0,6,7],
-"classSteinberg_1_1Vst_1_1ComponentBase.html#adbcbdfd9061c4f951db444f60d358b12":[2,0,6,12],
-"classSteinberg_1_1Vst_1_1ComponentBase.html#ae8391f8417d768adbf055876641276cb":[2,0,6,2],
-"classSteinberg_1_1Vst_1_1ComponentBase.html#af5db5c33db4c9fa57a18b66fb714830c":[2,0,6,3],
-"classSteinberg_1_1Vst_1_1ConnectionProxy.html":[4,0,0,1,12]
+"classSteinberg_1_1Vst_1_1ComponentBase.html#adbcbdfd9061c4f951db444f60d358b12":[2,0,6,12]
 };
