@@ -1,5 +1,8 @@
 var NAVTREEINDEX1 =
 {
+"classSteinberg_1_1Vst_1_1ComponentBase.html#ae8391f8417d768adbf055876641276cb":[2,0,6,2],
+"classSteinberg_1_1Vst_1_1ComponentBase.html#af5db5c33db4c9fa57a18b66fb714830c":[2,0,6,3],
+"classSteinberg_1_1Vst_1_1ConnectionProxy.html":[4,0,0,1,12],
 "classSteinberg_1_1Vst_1_1ConnectionProxy.html#a12db172f74059f7eceb63714f4589aa0":[4,0,0,1,12,5],
 "classSteinberg_1_1Vst_1_1ConnectionProxy.html#a4487b5c458a52ed743064aad105a244d":[4,0,0,1,12,7],
 "classSteinberg_1_1Vst_1_1ConnectionProxy.html#a6c2e8e8b1fbabb82ea67dcf81fb0c6b6":[4,0,0,1,12,3],
@@ -9,6 +12,24 @@ var NAVTREEINDEX1 =
 "classSteinberg_1_1Vst_1_1ConnectionProxy.html#ae03c2fc2709da3bc22c6f765185fd793":[4,0,0,1,12,8],
 "classSteinberg_1_1Vst_1_1ConnectionProxy.html#af7bb4bec2475d18c304cc1263092e2cc":[4,0,0,1,12,6],
 "classSteinberg_1_1Vst_1_1ConnectionProxy.html#afc8b9232e82d8a56bc262978dac5856c":[4,0,0,1,12,4],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html":[4,0,0,1,24],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a0658f09730e3694a67ebed87c6d06138":[4,0,0,1,24,6],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a0d0f05deba6d875f545adb38dbff1853":[4,0,0,1,24,5],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a1198f6e88e7ba2ba5965aa4f0a592d72":[4,0,0,1,24,4],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a11ba504740a2f7c2e89688344141be45":[4,0,0,1,24,1],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a23592d2f6bfb88d19ae499ddb644b3f6":[4,0,0,1,24,9],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a2c8c2d0a612cd628e955dc6e9676ea85":[4,0,0,1,24,8],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a49505377ab844ba48d3b85fd224f7d63":[4,0,0,1,24,11],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a6530852c0fc0ded04f913c5d6de9bc16":[4,0,0,1,24,7],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a66d8feb44d790d1c96e76ffd13b54bb0":[4,0,0,1,24,12],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a82c9767f227ed858413efa54450309ea":[4,0,0,1,24,3],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#a97ca1031d43944ec348aab7d5a060b8c":[4,0,0,1,24,10],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#ae2931e09e0fd8eac15c83f0254b4e4ac":[4,0,0,1,24,13],
+"classSteinberg_1_1Vst_1_1DataExchangeHandler.html#aea634a2e1293658a1e343bbc8bf71dd7":[4,0,0,1,24,2],
+"classSteinberg_1_1Vst_1_1DataExchangeReceiverHandler.html":[4,0,0,1,25],
+"classSteinberg_1_1Vst_1_1DataExchangeReceiverHandler.html#a04f7bfae5ffb6c3841cad64acfed4747":[4,0,0,1,25,0],
+"classSteinberg_1_1Vst_1_1DataExchangeReceiverHandler.html#a1f2bdf21855cf544c941e22557450a58":[4,0,0,1,25,1],
+"classSteinberg_1_1Vst_1_1DataExchangeReceiverHandler.html#a3b307b566f37e2addb73488ba6c67fe7":[4,0,0,1,25,2],
 "classSteinberg_1_1Vst_1_1EditController.html":[2,0,7],
 "classSteinberg_1_1Vst_1_1EditController.html#a0d848355600e651408719e8a288426ef":[2,0,7,24],
 "classSteinberg_1_1Vst_1_1EditController.html#a1a882472b7c228eb1f709c7f15b15999":[2,0,7,4],
@@ -186,24 +207,24 @@ var NAVTREEINDEX1 =
 "classSteinberg_1_1Vst_1_1NoteExpressionTypeContainer.html#ac93bea44934ede96c71738cd52fa29ba":[2,0,16,10],
 "classSteinberg_1_1Vst_1_1NoteExpressionTypeContainer.html#ae6d96845d749ee274d85820210b2de82":[2,0,16,9],
 "classSteinberg_1_1Vst_1_1NoteExpressionTypeContainer.html#ae706465d9b2048175c378291fdfeb518":[2,0,16,6],
-"classSteinberg_1_1Vst_1_1ParamChanges.html":[4,0,0,1,20],
-"classSteinberg_1_1Vst_1_1ParamChanges.html#a0b6f0fb23c90a7f61804948458756b4c":[4,0,0,1,20,2],
-"classSteinberg_1_1Vst_1_1ParamChanges.html#a1974e241cd715633518756450a8599bc":[4,0,0,1,20,5],
-"classSteinberg_1_1Vst_1_1ParamChanges.html#a1d82c755fa67c189b94dec5c76121824":[4,0,0,1,20,8],
-"classSteinberg_1_1Vst_1_1ParamChanges.html#a1e68d8b8453af59faf7bdd8353a45958":[4,0,0,1,20,9],
-"classSteinberg_1_1Vst_1_1ParamChanges.html#a3d64a0fd4bd7066dc9d2ae1bfa495572":[4,0,0,1,20,0],
-"classSteinberg_1_1Vst_1_1ParamChanges.html#a65b4fe001a665525b4704b6ee3b864ea":[4,0,0,1,20,10],
-"classSteinberg_1_1Vst_1_1ParamChanges.html#a6b8036f810ac3cd2a17d2606f34dc9e8":[4,0,0,1,20,1],
-"classSteinberg_1_1Vst_1_1ParamChanges.html#a850bc14c2676e3ad3c25217b548c2b43":[4,0,0,1,20,3],
-"classSteinberg_1_1Vst_1_1ParamChanges.html#aa9728817d91fee2593fc8b6480c773e1":[4,0,0,1,20,4],
-"classSteinberg_1_1Vst_1_1ParamChanges.html#ab7eb03e949dfdd22d46a912533d7c07d":[4,0,0,1,20,11],
-"classSteinberg_1_1Vst_1_1ParamChanges.html#ad9ef33d81be2e39cc162a3ac4f9a8983":[4,0,0,1,20,7],
-"classSteinberg_1_1Vst_1_1ParamChanges.html#ae97fb1a2f6be8948118247dba3f8c509":[4,0,0,1,20,6],
-"classSteinberg_1_1Vst_1_1ParamPoint.html":[4,0,0,1,19],
-"classSteinberg_1_1Vst_1_1ParamPoint.html#a0621e63d2febf2175e01558ba11b18cf":[4,0,0,1,19,3],
-"classSteinberg_1_1Vst_1_1ParamPoint.html#a1bf2279035479a36b3e1520bf4aef893":[4,0,0,1,19,0],
-"classSteinberg_1_1Vst_1_1ParamPoint.html#a81d85b4c1dc3729d33806edc322bbd34":[4,0,0,1,19,2],
-"classSteinberg_1_1Vst_1_1ParamPoint.html#a90bb924a3c6d53a745bfe6652cdaa7dd":[4,0,0,1,19,1],
+"classSteinberg_1_1Vst_1_1ParamChanges.html":[4,0,0,1,22],
+"classSteinberg_1_1Vst_1_1ParamChanges.html#a0b6f0fb23c90a7f61804948458756b4c":[4,0,0,1,22,2],
+"classSteinberg_1_1Vst_1_1ParamChanges.html#a1974e241cd715633518756450a8599bc":[4,0,0,1,22,5],
+"classSteinberg_1_1Vst_1_1ParamChanges.html#a1d82c755fa67c189b94dec5c76121824":[4,0,0,1,22,8],
+"classSteinberg_1_1Vst_1_1ParamChanges.html#a1e68d8b8453af59faf7bdd8353a45958":[4,0,0,1,22,9],
+"classSteinberg_1_1Vst_1_1ParamChanges.html#a3d64a0fd4bd7066dc9d2ae1bfa495572":[4,0,0,1,22,0],
+"classSteinberg_1_1Vst_1_1ParamChanges.html#a65b4fe001a665525b4704b6ee3b864ea":[4,0,0,1,22,10],
+"classSteinberg_1_1Vst_1_1ParamChanges.html#a6b8036f810ac3cd2a17d2606f34dc9e8":[4,0,0,1,22,1],
+"classSteinberg_1_1Vst_1_1ParamChanges.html#a850bc14c2676e3ad3c25217b548c2b43":[4,0,0,1,22,3],
+"classSteinberg_1_1Vst_1_1ParamChanges.html#aa9728817d91fee2593fc8b6480c773e1":[4,0,0,1,22,4],
+"classSteinberg_1_1Vst_1_1ParamChanges.html#ab7eb03e949dfdd22d46a912533d7c07d":[4,0,0,1,22,11],
+"classSteinberg_1_1Vst_1_1ParamChanges.html#ad9ef33d81be2e39cc162a3ac4f9a8983":[4,0,0,1,22,7],
+"classSteinberg_1_1Vst_1_1ParamChanges.html#ae97fb1a2f6be8948118247dba3f8c509":[4,0,0,1,22,6],
+"classSteinberg_1_1Vst_1_1ParamPoint.html":[4,0,0,1,21],
+"classSteinberg_1_1Vst_1_1ParamPoint.html#a0621e63d2febf2175e01558ba11b18cf":[4,0,0,1,21,3],
+"classSteinberg_1_1Vst_1_1ParamPoint.html#a1bf2279035479a36b3e1520bf4aef893":[4,0,0,1,21,0],
+"classSteinberg_1_1Vst_1_1ParamPoint.html#a81d85b4c1dc3729d33806edc322bbd34":[4,0,0,1,21,2],
+"classSteinberg_1_1Vst_1_1ParamPoint.html#a90bb924a3c6d53a745bfe6652cdaa7dd":[4,0,0,1,21,1],
 "classSteinberg_1_1Vst_1_1Parameter.html":[2,0,17],
 "classSteinberg_1_1Vst_1_1Parameter.html#a0ccc625642bc5f50bad1ecf1de846017":[2,0,17,16],
 "classSteinberg_1_1Vst_1_1Parameter.html#a21aef1eeb23ef6e414cba252690795a5":[2,0,17,7],
@@ -228,26 +249,5 @@ var NAVTREEINDEX1 =
 "classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html#a2409ad0a1739756bcf2889765ee14938":[2,2,5,5],
 "classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html#a40eebc46ee9addec3780f266037c642f":[2,2,5,10],
 "classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html#a5bc38e228c5ff68f4193697272b90963":[2,2,5,6],
-"classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html#a7ecbfd66175891f0d25dd3e70348e242":[2,2,5,8],
-"classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html#a7fdfae5a8e4484cd756f500d797d019b":[2,2,5,2],
-"classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html#a81daa8962de04d31bd39748347572b6f":[2,2,5,3],
-"classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html#a8eb5993e076e7fbac47a9713a8083fd0":[2,2,5,1],
-"classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html#a958d810af44271155222fb51b9a1bca6":[2,2,5,7],
-"classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html#aa1728750481b853c3246037c1ba1c68b":[2,2,5,9],
-"classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html#aa9a2796814321a32d6d4790b06d47d63":[2,2,5,4],
-"classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html#aae9e5d42c6d5c365662d7d936fcdbdc3":[2,2,5,12],
-"classSteinberg_1_1Vst_1_1ParameterChanges.html":[2,2,4],
-"classSteinberg_1_1Vst_1_1ParameterChanges.html#a1a882472b7c228eb1f709c7f15b15999":[2,2,4,4],
-"classSteinberg_1_1Vst_1_1ParameterChanges.html#a46ca129ca2f1fe147c7defc0658d7295":[2,2,4,5],
-"classSteinberg_1_1Vst_1_1ParameterChanges.html#a7b7f09ace42f57bf958a1a379e935ea9":[2,2,4,2],
-"classSteinberg_1_1Vst_1_1ParameterChanges.html#a81daa8962de04d31bd39748347572b6f":[2,2,4,3],
-"classSteinberg_1_1Vst_1_1ParameterChanges.html#ab02ba6d7a0043fecec571f8c4bbae516":[2,2,4,0],
-"classSteinberg_1_1Vst_1_1ParameterChanges.html#acfb73c5aee1d941dc8bd1ddbe81a257b":[2,2,4,7],
-"classSteinberg_1_1Vst_1_1ParameterChanges.html#ae25dd37cc3fdc8e358826a08dc8566f2":[2,2,4,1],
-"classSteinberg_1_1Vst_1_1ParameterChanges.html#aecf67b64e5c0c9880530199fa9d7cc9a":[2,2,4,6],
-"classSteinberg_1_1Vst_1_1ParameterChanges.html#affa318ea1f104f4c9a2bcc359dd9c4dd":[2,2,4,8],
-"classSteinberg_1_1Vst_1_1ParameterContainer.html":[2,0,20],
-"classSteinberg_1_1Vst_1_1ParameterContainer.html#a023243865c40e3198f716d09ad53c585":[2,0,20,3],
-"classSteinberg_1_1Vst_1_1ParameterContainer.html#a0321ac02fa41dfbea9fd1339c7946c8b":[2,0,20,8],
-"classSteinberg_1_1Vst_1_1ParameterContainer.html#a09ad76517b311128144d1a5d0dbfee99":[2,0,20,13]
+"classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html#a7ecbfd66175891f0d25dd3e70348e242":[2,2,5,8]
 };
