@@ -1,5 +1,26 @@
 var NAVTREEINDEX2 =
 {
+"classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html#a7fdfae5a8e4484cd756f500d797d019b":[2,2,5,2],
+"classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html#a81daa8962de04d31bd39748347572b6f":[2,2,5,3],
+"classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html#a8eb5993e076e7fbac47a9713a8083fd0":[2,2,5,1],
+"classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html#a958d810af44271155222fb51b9a1bca6":[2,2,5,7],
+"classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html#aa1728750481b853c3246037c1ba1c68b":[2,2,5,9],
+"classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html#aa9a2796814321a32d6d4790b06d47d63":[2,2,5,4],
+"classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html#aae9e5d42c6d5c365662d7d936fcdbdc3":[2,2,5,12],
+"classSteinberg_1_1Vst_1_1ParameterChanges.html":[2,2,4],
+"classSteinberg_1_1Vst_1_1ParameterChanges.html#a1a882472b7c228eb1f709c7f15b15999":[2,2,4,4],
+"classSteinberg_1_1Vst_1_1ParameterChanges.html#a46ca129ca2f1fe147c7defc0658d7295":[2,2,4,5],
+"classSteinberg_1_1Vst_1_1ParameterChanges.html#a7b7f09ace42f57bf958a1a379e935ea9":[2,2,4,2],
+"classSteinberg_1_1Vst_1_1ParameterChanges.html#a81daa8962de04d31bd39748347572b6f":[2,2,4,3],
+"classSteinberg_1_1Vst_1_1ParameterChanges.html#ab02ba6d7a0043fecec571f8c4bbae516":[2,2,4,0],
+"classSteinberg_1_1Vst_1_1ParameterChanges.html#acfb73c5aee1d941dc8bd1ddbe81a257b":[2,2,4,7],
+"classSteinberg_1_1Vst_1_1ParameterChanges.html#ae25dd37cc3fdc8e358826a08dc8566f2":[2,2,4,1],
+"classSteinberg_1_1Vst_1_1ParameterChanges.html#aecf67b64e5c0c9880530199fa9d7cc9a":[2,2,4,6],
+"classSteinberg_1_1Vst_1_1ParameterChanges.html#affa318ea1f104f4c9a2bcc359dd9c4dd":[2,2,4,8],
+"classSteinberg_1_1Vst_1_1ParameterContainer.html":[2,0,20],
+"classSteinberg_1_1Vst_1_1ParameterContainer.html#a023243865c40e3198f716d09ad53c585":[2,0,20,3],
+"classSteinberg_1_1Vst_1_1ParameterContainer.html#a0321ac02fa41dfbea9fd1339c7946c8b":[2,0,20,8],
+"classSteinberg_1_1Vst_1_1ParameterContainer.html#a09ad76517b311128144d1a5d0dbfee99":[2,0,20,13],
 "classSteinberg_1_1Vst_1_1ParameterContainer.html#a17ccf658ed2936c9d740dd1c5fada5dc":[2,0,20,12],
 "classSteinberg_1_1Vst_1_1ParameterContainer.html#a3e0742c4b4e499d7a19e1d1aab945d40":[2,0,20,11],
 "classSteinberg_1_1Vst_1_1ParameterContainer.html#a45c61e90b4a6fc07b6597c9acc55b483":[2,0,20,4],
@@ -29,34 +50,33 @@ var NAVTREEINDEX2 =
 "classSteinberg_1_1Vst_1_1PlugInterfaceSupport.html#a53b31091ef4b0735bd6e336992a4ee6e":[2,2,6,4],
 "classSteinberg_1_1Vst_1_1PlugInterfaceSupport.html#a6aff0e9fe16fb13679074f0610f6c82c":[2,2,6,0],
 "classSteinberg_1_1Vst_1_1PlugInterfaceSupport.html#af94a822c9390d013ab16bba205db47c2":[2,2,6,1],
-"classSteinberg_1_1Vst_1_1PlugProvider.html":[4,0,0,1,13],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#a020894745e82fb107fc4a869a8832d86":[4,0,0,1,13,2],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#a0c4daae75c9c796e333143d736bc766c":[4,0,0,1,13,20],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#a0ff857240296663db1f7c55c057204e1":[4,0,0,1,13,15],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#a12cbed77ca2d669e478a375473de6fb1":[4,0,0,1,13,14],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#a131548654f635c364467a1dd563e6b85":[4,0,0,1,13,8],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#a283a915b4c73ccad57dc6c0aca2fc224":[4,0,0,1,13,22],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#a547929ce1c484ec21872a64c72d22882":[4,0,0,1,13,9],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#a6049925777740077b65848662a42fd12":[4,0,0,1,13,13],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#a6249cbd10d897a88d111a89c2ca6b6b6":[4,0,0,1,13,23],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#a6e0a0488e3319db98db002bdce062d2b":[4,0,0,1,13,12],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#a7b48e5060e87f05aa6dbe009c49590b3":[4,0,0,1,13,5],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#a7ddbf523610d9a2456ef7b40f1ef488e":[4,0,0,1,13,17],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#a7f91cb0563a7c3753263b36530e624a1":[4,0,0,1,13,3],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#ab3729c4eddeab38f21f7e34ebd18dc25":[4,0,0,1,13,6],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#ab3aa0d2066929e476a55a482d1fc30b6":[4,0,0,1,13,0],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#ab3e7cc706c522b3231f9156bba461436":[4,0,0,1,13,4],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#abda27e260ba5fd0a31f038d57e2fab17":[4,0,0,1,13,18],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#acb7f3ade3027a9b53397308800272789":[4,0,0,1,13,1],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#adc08e3eb47e0ab3d050cfadc386d95f0":[4,0,0,1,13,11],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#adec9a6f39ce77aa4383fef325929fb92":[4,0,0,1,13,19],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#ae1e194cb41fe51987a519a92abf23d3f":[4,0,0,1,13,10],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#aea3aa16cc1d285b2fc58eda39683fc8f":[4,0,0,1,13,21],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#af532604d58ac09daa58a28f20af17ba4":[4,0,0,1,13,7],
-"classSteinberg_1_1Vst_1_1PlugProvider.html#afb7291e735d94bb9e936cf78c95e2928":[4,0,0,1,13,16],
-"classSteinberg_1_1Vst_1_1PluginContextFactory.html":[4,0,0,1,14],
-"classSteinberg_1_1Vst_1_1PluginContextFactory.html#a2400af6b76b72f7cfb23172352124110":[4,0,0,1,14,0],
-"classSteinberg_1_1Vst_1_1PluginContextFactory.html#a26bc7df45b240e136545ce1419b56a16":[4,0,0,1,14,1],
+"classSteinberg_1_1Vst_1_1PlugProvider.html":[4,0,0,1,15],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#a020894745e82fb107fc4a869a8832d86":[4,0,0,1,15,2],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#a0c4daae75c9c796e333143d736bc766c":[4,0,0,1,15,19],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#a0ff857240296663db1f7c55c057204e1":[4,0,0,1,15,14],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#a12cbed77ca2d669e478a375473de6fb1":[4,0,0,1,15,13],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#a131548654f635c364467a1dd563e6b85":[4,0,0,1,15,8],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#a22bcbf7c186e8f0ecd486e31ee936461":[4,0,0,1,15,21],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#a547929ce1c484ec21872a64c72d22882":[4,0,0,1,15,9],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#a6049925777740077b65848662a42fd12":[4,0,0,1,15,12],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#a6249cbd10d897a88d111a89c2ca6b6b6":[4,0,0,1,15,22],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#a6e0a0488e3319db98db002bdce062d2b":[4,0,0,1,15,11],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#a7b48e5060e87f05aa6dbe009c49590b3":[4,0,0,1,15,5],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#a7ddbf523610d9a2456ef7b40f1ef488e":[4,0,0,1,15,16],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#a7f91cb0563a7c3753263b36530e624a1":[4,0,0,1,15,3],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#ab3729c4eddeab38f21f7e34ebd18dc25":[4,0,0,1,15,6],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#ab3aa0d2066929e476a55a482d1fc30b6":[4,0,0,1,15,0],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#ab3e7cc706c522b3231f9156bba461436":[4,0,0,1,15,4],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#ab89459e0f8333c820b84811bd128a7f7":[4,0,0,1,15,20],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#abda27e260ba5fd0a31f038d57e2fab17":[4,0,0,1,15,17],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#abfa14a169f62d20586d1d173d7af068c":[4,0,0,1,15,15],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#acb7f3ade3027a9b53397308800272789":[4,0,0,1,15,1],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#adec9a6f39ce77aa4383fef325929fb92":[4,0,0,1,15,18],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#ae1e194cb41fe51987a519a92abf23d3f":[4,0,0,1,15,10],
+"classSteinberg_1_1Vst_1_1PlugProvider.html#af532604d58ac09daa58a28f20af17ba4":[4,0,0,1,15,7],
+"classSteinberg_1_1Vst_1_1PluginContextFactory.html":[4,0,0,1,16],
+"classSteinberg_1_1Vst_1_1PluginContextFactory.html#a2400af6b76b72f7cfb23172352124110":[4,0,0,1,16,0],
+"classSteinberg_1_1Vst_1_1PluginContextFactory.html#a26bc7df45b240e136545ce1419b56a16":[4,0,0,1,16,1],
 "classSteinberg_1_1Vst_1_1PresetFile.html":[2,0,21],
 "classSteinberg_1_1Vst_1_1PresetFile.html#a0518e18874378e575de0d7a7a56f9023":[2,0,21,5],
 "classSteinberg_1_1Vst_1_1PresetFile.html#a06fc87d81c62e9abb8790b6e5713c55ba7c523f5cdb8166ac95e994b9e6359476":[2,0,21,1],
@@ -106,36 +126,36 @@ var NAVTREEINDEX2 =
 "classSteinberg_1_1Vst_1_1PresetFile.html#ae394d46565e1278b4997f35e161898e3":[2,0,21,43],
 "classSteinberg_1_1Vst_1_1PresetFile.html#ae6e9621d0074acc283a236156e93abe6":[2,0,21,24],
 "classSteinberg_1_1Vst_1_1PresetFile.html#af39bcb8613b4028536559731594e757c":[2,0,21,36],
-"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html":[4,0,0,1,22],
-"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#a020c02ad959a478c725d64abae5e8d11":[4,0,0,1,22,16],
-"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#a0d8ff8b229cca804a0514262ada65ce8":[4,0,0,1,22,8],
-"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#a0ebde9dd35138c4d87d0e5a102cf6fde":[4,0,0,1,22,9],
-"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#a1a42aaff50c5c2959a581479607c8a3d":[4,0,0,1,22,11],
-"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#a21d4f1df023df06d8cb29ac8274306cb":[4,0,0,1,22,4],
-"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#a2c2babe7ff176a98f544f09f02a73a36":[4,0,0,1,22,17],
-"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#a349d1a7e778cd101f7609d79611e1c16":[4,0,0,1,22,3],
-"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#a37cc34f080a3768a3442f22173c6adda":[4,0,0,1,22,22],
-"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#a3a7e1cb0ed09b2ba7de35de90b28503a":[4,0,0,1,22,19],
-"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#a3fd826fdc1672063bd03036f040e95c2":[4,0,0,1,22,20],
-"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#a41044566e94bca78c1a43683b693246c":[4,0,0,1,22,7],
-"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#a470063bcbfa3926575a08339618272e4":[4,0,0,1,22,6],
-"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#a5ec985d07cbd7575dc5eac5f4ec90dec":[4,0,0,1,22,2],
-"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#a689f0f65a0de2af6108ee3dbf1a6b373":[4,0,0,1,22,1],
-"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#a7da6d11d8972056673d68cac595b4bf8":[4,0,0,1,22,18],
-"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#a81a27ce50e78368b0d0de1e8767fd32d":[4,0,0,1,22,24],
-"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#a91c32624fbc975ae630fcb9d4e7e7525":[4,0,0,1,22,21],
-"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#aaeb820be39fa40532e38b84aaca59ed5":[4,0,0,1,22,15],
-"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#abfcfc2492de9e82daf8480b7a27ef911":[4,0,0,1,22,5],
-"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#ac5fc7ad15c792b693be325a982cbfa2a":[4,0,0,1,22,14],
-"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#ac89c69e3be91157c697b2edfa0e2ef77":[4,0,0,1,22,12],
-"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#ae40c5b12ded747e7f7ab4d52bd7c8907":[4,0,0,1,22,0],
-"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#aeceba345384210331d042ba6f5a97a95":[4,0,0,1,22,13],
-"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#af5969c1a507e339c0c50106505404079":[4,0,0,1,22,10],
-"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#af67eb8f2a635daf77e223d665d57bfd4":[4,0,0,1,22,23],
-"classSteinberg_1_1Vst_1_1ProcessDataSlicer.html":[4,0,0,1,23],
-"classSteinberg_1_1Vst_1_1ProcessDataSlicer.html#a8a5d3a26394df1031ca6a30c243e9565":[4,0,0,1,23,1],
-"classSteinberg_1_1Vst_1_1ProcessDataSlicer.html#aba28ee97ffe6d508e26f534ec7e62f8f":[4,0,0,1,23,2],
-"classSteinberg_1_1Vst_1_1ProcessDataSlicer.html#adb177e088f35d41ccff42c6c93aa673b":[4,0,0,1,23,0],
+"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html":[4,0,0,1,26],
+"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#a020c02ad959a478c725d64abae5e8d11":[4,0,0,1,26,16],
+"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#a0d8ff8b229cca804a0514262ada65ce8":[4,0,0,1,26,8],
+"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#a0ebde9dd35138c4d87d0e5a102cf6fde":[4,0,0,1,26,9],
+"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#a1a42aaff50c5c2959a581479607c8a3d":[4,0,0,1,26,11],
+"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#a21d4f1df023df06d8cb29ac8274306cb":[4,0,0,1,26,4],
+"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#a2c2babe7ff176a98f544f09f02a73a36":[4,0,0,1,26,17],
+"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#a349d1a7e778cd101f7609d79611e1c16":[4,0,0,1,26,3],
+"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#a37cc34f080a3768a3442f22173c6adda":[4,0,0,1,26,22],
+"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#a3a7e1cb0ed09b2ba7de35de90b28503a":[4,0,0,1,26,19],
+"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#a3fd826fdc1672063bd03036f040e95c2":[4,0,0,1,26,20],
+"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#a41044566e94bca78c1a43683b693246c":[4,0,0,1,26,7],
+"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#a470063bcbfa3926575a08339618272e4":[4,0,0,1,26,6],
+"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#a5ec985d07cbd7575dc5eac5f4ec90dec":[4,0,0,1,26,2],
+"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#a689f0f65a0de2af6108ee3dbf1a6b373":[4,0,0,1,26,1],
+"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#a7da6d11d8972056673d68cac595b4bf8":[4,0,0,1,26,18],
+"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#a81a27ce50e78368b0d0de1e8767fd32d":[4,0,0,1,26,24],
+"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#a91c32624fbc975ae630fcb9d4e7e7525":[4,0,0,1,26,21],
+"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#aaeb820be39fa40532e38b84aaca59ed5":[4,0,0,1,26,15],
+"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#abfcfc2492de9e82daf8480b7a27ef911":[4,0,0,1,26,5],
+"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#ac5fc7ad15c792b693be325a982cbfa2a":[4,0,0,1,26,14],
+"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#ac89c69e3be91157c697b2edfa0e2ef77":[4,0,0,1,26,12],
+"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#ae40c5b12ded747e7f7ab4d52bd7c8907":[4,0,0,1,26,0],
+"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#aeceba345384210331d042ba6f5a97a95":[4,0,0,1,26,13],
+"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#af5969c1a507e339c0c50106505404079":[4,0,0,1,26,10],
+"classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#af67eb8f2a635daf77e223d665d57bfd4":[4,0,0,1,26,23],
+"classSteinberg_1_1Vst_1_1ProcessDataSlicer.html":[4,0,0,1,27],
+"classSteinberg_1_1Vst_1_1ProcessDataSlicer.html#a8a5d3a26394df1031ca6a30c243e9565":[4,0,0,1,27,1],
+"classSteinberg_1_1Vst_1_1ProcessDataSlicer.html#aba28ee97ffe6d508e26f534ec7e62f8f":[4,0,0,1,27,2],
+"classSteinberg_1_1Vst_1_1ProcessDataSlicer.html#adb177e088f35d41ccff42c6c93aa673b":[4,0,0,1,27,0],
 "classSteinberg_1_1Vst_1_1ProgramList.html":[2,0,10],
 "classSteinberg_1_1Vst_1_1ProgramList.html#a03672ebc5c493f1caa8f647dd62e7019":[2,0,10,16],
 "classSteinberg_1_1Vst_1_1ProgramList.html#a064d4941eb4a37a951ba11db619139a1":[2,0,10,2],
@@ -229,25 +249,5 @@ var NAVTREEINDEX2 =
 "classSteinberg_1_1Vst_1_1SingleComponentEffect.html#aae75b97c8b97b30648a3fbe8e3ecf942":[2,0,23,17],
 "classSteinberg_1_1Vst_1_1SingleComponentEffect.html#ab5393bfe75dac26ada3d2f33b5f372cf":[2,0,23,12],
 "classSteinberg_1_1Vst_1_1SingleComponentEffect.html#ac8369734067dcb5f9288a67db686e5f4":[2,0,23,4],
-"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#acf5189a9e37c263015c22a7f81b750c8":[2,0,23,13],
-"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#adc3fc77f74a27de4c7238ffebda644bb":[2,0,23,5],
-"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#adc63b47c5958e737abb364f126a7391f":[2,0,23,26],
-"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#add6d889f0a8a72718b1ac12e049b55dc":[2,0,23,21],
-"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#adfed165246ab5af336ca44ec4fc3be63":[2,0,23,7],
-"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#aed058baf0101b334a42e4e0f09bcfd0e":[2,0,23,16],
-"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#aee9f447229f5bf7247c00d39f4bb748d":[2,0,23,14],
-"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#af19a632def3662c234414c690503c36f":[2,0,23,25],
-"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#af98a434f211539013a174bbe191156e3":[2,0,23,9],
-"classSteinberg_1_1Vst_1_1SpeakerArray.html":[4,0,0,1,11],
-"classSteinberg_1_1Vst_1_1SpeakerArray.html#a1c206276093ebc1cdaa9be54a901ce1b":[4,0,0,1,11,8],
-"classSteinberg_1_1Vst_1_1SpeakerArray.html#a3e14bc0618d2942f538b771104268bef":[4,0,0,1,11,3],
-"classSteinberg_1_1Vst_1_1SpeakerArray.html#a3f1cae73c7bc34d528fc6985beee5600":[4,0,0,1,11,7],
-"classSteinberg_1_1Vst_1_1SpeakerArray.html#a45a06cc98257a31820ae72df7bb84314":[4,0,0,1,11,6],
-"classSteinberg_1_1Vst_1_1SpeakerArray.html#a46342207540a92616e060073b43f57f3":[4,0,0,1,11,9],
-"classSteinberg_1_1Vst_1_1SpeakerArray.html#a69c381f94a8c0a06ea19e98f71b3f826":[4,0,0,1,11,2],
-"classSteinberg_1_1Vst_1_1SpeakerArray.html#a99fb83031ce9923c84392b4e92f956b5aceba67855d498983e892a86a4725c662":[4,0,0,1,11,1],
-"classSteinberg_1_1Vst_1_1SpeakerArray.html#ac29b5ae06a98cb03a0f046667a1075e6":[4,0,0,1,11,0],
-"classSteinberg_1_1Vst_1_1SpeakerArray.html#ac76e244dc55fc95106885718c4b6bdc3":[4,0,0,1,11,5],
-"classSteinberg_1_1Vst_1_1SpeakerArray.html#afef9cc041dcdf172dd2114307f5b3ae7":[4,0,0,1,11,4],
-"classSteinberg_1_1Vst_1_1StringListParameter.html":[2,0,19]
+"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#acf5189a9e37c263015c22a7f81b750c8":[2,0,23,13]
 };
