@@ -1,5 +1,25 @@
 var NAVTREEINDEX3 =
 {
+"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#adc3fc77f74a27de4c7238ffebda644bb":[2,0,23,5],
+"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#adc63b47c5958e737abb364f126a7391f":[2,0,23,26],
+"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#add6d889f0a8a72718b1ac12e049b55dc":[2,0,23,21],
+"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#adfed165246ab5af336ca44ec4fc3be63":[2,0,23,7],
+"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#aed058baf0101b334a42e4e0f09bcfd0e":[2,0,23,16],
+"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#aee9f447229f5bf7247c00d39f4bb748d":[2,0,23,14],
+"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#af19a632def3662c234414c690503c36f":[2,0,23,25],
+"classSteinberg_1_1Vst_1_1SingleComponentEffect.html#af98a434f211539013a174bbe191156e3":[2,0,23,9],
+"classSteinberg_1_1Vst_1_1SpeakerArray.html":[4,0,0,1,11],
+"classSteinberg_1_1Vst_1_1SpeakerArray.html#a1c206276093ebc1cdaa9be54a901ce1b":[4,0,0,1,11,8],
+"classSteinberg_1_1Vst_1_1SpeakerArray.html#a3e14bc0618d2942f538b771104268bef":[4,0,0,1,11,3],
+"classSteinberg_1_1Vst_1_1SpeakerArray.html#a3f1cae73c7bc34d528fc6985beee5600":[4,0,0,1,11,7],
+"classSteinberg_1_1Vst_1_1SpeakerArray.html#a45a06cc98257a31820ae72df7bb84314":[4,0,0,1,11,6],
+"classSteinberg_1_1Vst_1_1SpeakerArray.html#a46342207540a92616e060073b43f57f3":[4,0,0,1,11,9],
+"classSteinberg_1_1Vst_1_1SpeakerArray.html#a69c381f94a8c0a06ea19e98f71b3f826":[4,0,0,1,11,2],
+"classSteinberg_1_1Vst_1_1SpeakerArray.html#a99fb83031ce9923c84392b4e92f956b5aceba67855d498983e892a86a4725c662":[4,0,0,1,11,1],
+"classSteinberg_1_1Vst_1_1SpeakerArray.html#ac29b5ae06a98cb03a0f046667a1075e6":[4,0,0,1,11,0],
+"classSteinberg_1_1Vst_1_1SpeakerArray.html#ac76e244dc55fc95106885718c4b6bdc3":[4,0,0,1,11,5],
+"classSteinberg_1_1Vst_1_1SpeakerArray.html#afef9cc041dcdf172dd2114307f5b3ae7":[4,0,0,1,11,4],
+"classSteinberg_1_1Vst_1_1StringListParameter.html":[2,0,19],
 "classSteinberg_1_1Vst_1_1StringListParameter.html#a57131772fda4fd320e3d8cd7c7c981b7":[2,0,19,3],
 "classSteinberg_1_1Vst_1_1StringListParameter.html#a5a9dee2a0836631d70d59cde796132a0":[2,0,19,9],
 "classSteinberg_1_1Vst_1_1StringListParameter.html#a64274ff145c58620b9b7c32fff087049":[2,0,19,8],
@@ -10,29 +30,37 @@ var NAVTREEINDEX3 =
 "classSteinberg_1_1Vst_1_1StringListParameter.html#af7aab53314d6d62ad5b017ba85ab50b5":[2,0,19,6],
 "classSteinberg_1_1Vst_1_1StringListParameter.html#af7e7f0fc9f3c394f66dc5a8947742272":[2,0,19,7],
 "classSteinberg_1_1Vst_1_1StringListParameter.html#afe9e2d41b95886ea385ad5d482ffee58":[2,0,19,1],
-"classSteinberg_1_1Vst_1_1TestBase.html":[4,0,0,1,17],
-"classSteinberg_1_1Vst_1_1TestBase.html#a0e0fe11841b030f07950700afd64d822":[4,0,0,1,17,9],
-"classSteinberg_1_1Vst_1_1TestBase.html#a144500b31544cf7c45c8562ebd9985fe":[4,0,0,1,17,2],
-"classSteinberg_1_1Vst_1_1TestBase.html#a3d1fb91255e41edeeaee8794cd488720":[4,0,0,1,17,5],
-"classSteinberg_1_1Vst_1_1TestBase.html#a41fc7431ae821e2bc34f1a767d20fcd3":[4,0,0,1,17,10],
-"classSteinberg_1_1Vst_1_1TestBase.html#a61757a2824b38b279c3be2ed20ccddeb":[4,0,0,1,17,4],
-"classSteinberg_1_1Vst_1_1TestBase.html#a7d0b00b1d6236ce752a133e9ef713c11":[4,0,0,1,17,0],
-"classSteinberg_1_1Vst_1_1TestBase.html#a8fda54dda5b1ff98350169bc6612317c":[4,0,0,1,17,6],
-"classSteinberg_1_1Vst_1_1TestBase.html#a9b4ec98f480506d062a27f0eef17374e":[4,0,0,1,17,3],
-"classSteinberg_1_1Vst_1_1TestBase.html#aa2a890cf23bc6df3266783a3d8e4da09":[4,0,0,1,17,7],
-"classSteinberg_1_1Vst_1_1TestBase.html#ad2150d88fc7754ff1131930bd90728a3":[4,0,0,1,17,1],
-"classSteinberg_1_1Vst_1_1TestBase.html#aee0912e53e2d7f7ae563fad4e96c5d13":[4,0,0,1,17,8],
-"classSteinberg_1_1Vst_1_1TestEnh.html":[4,0,0,1,18],
-"classSteinberg_1_1Vst_1_1TestEnh.html#a13adc72f47daf6dc87f28e58b52c72d0":[4,0,0,1,18,5],
-"classSteinberg_1_1Vst_1_1TestEnh.html#a3d1fb91255e41edeeaee8794cd488720":[4,0,0,1,18,4],
-"classSteinberg_1_1Vst_1_1TestEnh.html#a76b5743ddf47012b09501e7118c30c32":[4,0,0,1,18,6],
-"classSteinberg_1_1Vst_1_1TestEnh.html#a7e28225b684b0706cf18619a3528cfe5":[4,0,0,1,18,1],
-"classSteinberg_1_1Vst_1_1TestEnh.html#a9b4ec98f480506d062a27f0eef17374e":[4,0,0,1,18,3],
-"classSteinberg_1_1Vst_1_1TestEnh.html#aea063e38c16b155569e7637de2c311e0":[4,0,0,1,18,2],
-"classSteinberg_1_1Vst_1_1TestEnh.html#aeeab75fa34b77d026422bf02ea2a7716":[4,0,0,1,18,0],
-"classSteinberg_1_1Vst_1_1TestEnh.html#aeeab75fa34b77d026422bf02ea2a7716a8355e558f1af9d7da5983731536001ec":[4,0,0,1,18,0,0],
-"classSteinberg_1_1Vst_1_1TestEnh.html#aeeab75fa34b77d026422bf02ea2a7716a9b13d2a9d89354f5b3252d7312cd6abb":[4,0,0,1,18,0,1],
-"classSteinberg_1_1Vst_1_1TestEnh.html#aeeab75fa34b77d026422bf02ea2a7716aaa20000cdc4614e9b78a9ab7b85b3137":[4,0,0,1,18,0,2],
+"classSteinberg_1_1Vst_1_1SystemTime.html":[4,0,0,1,29],
+"classSteinberg_1_1Vst_1_1SystemTime.html#a1fcda6c4393139a8fc5829cc40b1ffa3":[4,0,0,1,29,0],
+"classSteinberg_1_1Vst_1_1SystemTime.html#a3d4d83863fe3ba2a9a3c2522f2296c35":[4,0,0,1,29,1],
+"classSteinberg_1_1Vst_1_1SystemTime.html#a4cc7df3b4c5338541b7f34ec5a224b17":[4,0,0,1,29,4],
+"classSteinberg_1_1Vst_1_1SystemTime.html#a88e16809277e28b813c4aa1cbacfa766":[4,0,0,1,29,6],
+"classSteinberg_1_1Vst_1_1SystemTime.html#ab0702bde43ba6af1653a1a076678edc0":[4,0,0,1,29,2],
+"classSteinberg_1_1Vst_1_1SystemTime.html#addcda218bcea11ad44303edb9c96d6df":[4,0,0,1,29,5],
+"classSteinberg_1_1Vst_1_1SystemTime.html#af3f456af1e1a602b02313470b72b544f":[4,0,0,1,29,3],
+"classSteinberg_1_1Vst_1_1TestBase.html":[4,0,0,1,19],
+"classSteinberg_1_1Vst_1_1TestBase.html#a0e0fe11841b030f07950700afd64d822":[4,0,0,1,19,9],
+"classSteinberg_1_1Vst_1_1TestBase.html#a144500b31544cf7c45c8562ebd9985fe":[4,0,0,1,19,2],
+"classSteinberg_1_1Vst_1_1TestBase.html#a3d1fb91255e41edeeaee8794cd488720":[4,0,0,1,19,5],
+"classSteinberg_1_1Vst_1_1TestBase.html#a41fc7431ae821e2bc34f1a767d20fcd3":[4,0,0,1,19,10],
+"classSteinberg_1_1Vst_1_1TestBase.html#a61757a2824b38b279c3be2ed20ccddeb":[4,0,0,1,19,4],
+"classSteinberg_1_1Vst_1_1TestBase.html#a7d0b00b1d6236ce752a133e9ef713c11":[4,0,0,1,19,0],
+"classSteinberg_1_1Vst_1_1TestBase.html#a8fda54dda5b1ff98350169bc6612317c":[4,0,0,1,19,6],
+"classSteinberg_1_1Vst_1_1TestBase.html#a9b4ec98f480506d062a27f0eef17374e":[4,0,0,1,19,3],
+"classSteinberg_1_1Vst_1_1TestBase.html#aa2a890cf23bc6df3266783a3d8e4da09":[4,0,0,1,19,7],
+"classSteinberg_1_1Vst_1_1TestBase.html#ad2150d88fc7754ff1131930bd90728a3":[4,0,0,1,19,1],
+"classSteinberg_1_1Vst_1_1TestBase.html#aee0912e53e2d7f7ae563fad4e96c5d13":[4,0,0,1,19,8],
+"classSteinberg_1_1Vst_1_1TestEnh.html":[4,0,0,1,20],
+"classSteinberg_1_1Vst_1_1TestEnh.html#a13adc72f47daf6dc87f28e58b52c72d0":[4,0,0,1,20,5],
+"classSteinberg_1_1Vst_1_1TestEnh.html#a3d1fb91255e41edeeaee8794cd488720":[4,0,0,1,20,4],
+"classSteinberg_1_1Vst_1_1TestEnh.html#a76b5743ddf47012b09501e7118c30c32":[4,0,0,1,20,6],
+"classSteinberg_1_1Vst_1_1TestEnh.html#a7e28225b684b0706cf18619a3528cfe5":[4,0,0,1,20,1],
+"classSteinberg_1_1Vst_1_1TestEnh.html#a9b4ec98f480506d062a27f0eef17374e":[4,0,0,1,20,3],
+"classSteinberg_1_1Vst_1_1TestEnh.html#aea063e38c16b155569e7637de2c311e0":[4,0,0,1,20,2],
+"classSteinberg_1_1Vst_1_1TestEnh.html#aeeab75fa34b77d026422bf02ea2a7716":[4,0,0,1,20,0],
+"classSteinberg_1_1Vst_1_1TestEnh.html#aeeab75fa34b77d026422bf02ea2a7716a8355e558f1af9d7da5983731536001ec":[4,0,0,1,20,0,0],
+"classSteinberg_1_1Vst_1_1TestEnh.html#aeeab75fa34b77d026422bf02ea2a7716a9b13d2a9d89354f5b3252d7312cd6abb":[4,0,0,1,20,0,1],
+"classSteinberg_1_1Vst_1_1TestEnh.html#aeeab75fa34b77d026422bf02ea2a7716aaa20000cdc4614e9b78a9ab7b85b3137":[4,0,0,1,20,0,2],
 "classSteinberg_1_1Vst_1_1Unit.html":[2,0,9],
 "classSteinberg_1_1Vst_1_1Unit.html#a1536c30a1d382bd559f6cd4f82f928d7":[2,0,9,3],
 "classSteinberg_1_1Vst_1_1Unit.html#a296c1726513b59a6c28f501a6559b4d7":[2,0,9,7],
@@ -159,14 +187,19 @@ var NAVTREEINDEX3 =
 "classVST3_1_1Hosting_1_1PluginFactory.html#ab400f65393af1a14131cd2714ad04692":[4,0,1,0,2,8],
 "classVST3_1_1Hosting_1_1PluginFactory.html#abb7f24962eee9efd4e0b5bc87a1382cf":[4,0,1,0,2,4],
 "classes.html":[4,1],
-"connectionproxy_8cpp.html":[5,0,22],
-"connectionproxy_8cpp.html#a66aea247135e1846f335a23d9cf6bbcb":[5,0,22,0],
-"connectionproxy_8h.html":[5,0,23],
-"doc__public__sdk_8h.html":[5,0,24],
-"doc__public__sdk__limited_8h.html":[5,0,25],
-"eventlist_8cpp.html":[5,0,26],
-"eventlist_8cpp.html#a14da991e5b59eb10c9ad2d5fb90bbaee":[5,0,26,0],
-"eventlist_8h.html":[5,0,27],
+"connectionproxy_8cpp.html":[5,0,23],
+"connectionproxy_8cpp.html#a66aea247135e1846f335a23d9cf6bbcb":[5,0,23,0],
+"connectionproxy_8h.html":[5,0,24],
+"dataexchange_8cpp.html":[5,0,25],
+"dataexchange_8cpp.html#abf26a9c9bb662f8dee939c833413a0d0":[5,0,25,0],
+"dataexchange_8h.html":[5,0,26],
+"dataexchange_8h.html#a1df79da3fa9e3615e855efe07534b62b":[5,0,26,4],
+"dataexchange_8h.html#ab1444bade1e2d33212f2fe2e8c760acf":[5,0,26,3],
+"doc__public__sdk_8h.html":[5,0,27],
+"doc__public__sdk__limited_8h.html":[5,0,28],
+"eventlist_8cpp.html":[5,0,29],
+"eventlist_8cpp.html#a14da991e5b59eb10c9ad2d5fb90bbaee":[5,0,29,0],
+"eventlist_8h.html":[5,0,30],
 "exceptionSteinberg_1_1Vst_1_1HostAttributeList.html":[2,2,1],
 "exceptionSteinberg_1_1Vst_1_1HostAttributeList.html#a16ad5bae15e27321262938d8be3ab2f6":[2,2,1,4],
 "exceptionSteinberg_1_1Vst_1_1HostAttributeList.html#a7c6a0e107b24297dd13296f9d21bf492":[2,2,1,3],
@@ -183,15 +216,15 @@ var NAVTREEINDEX3 =
 "exceptionSteinberg_1_1Vst_1_1HostMessage.html#abe5688697369115f0e7e72c362258a75":[2,2,2,0],
 "exceptionSteinberg_1_1Vst_1_1HostMessage.html#acea3be2c0b1776d7e08d4c105b073701":[2,2,2,2],
 "exceptionSteinberg_1_1Vst_1_1HostMessage.html#afa5e6400ac20881481fc810e945868fe":[2,2,2,1],
-"exceptionSteinberg_1_1Vst_1_1StringResult.html":[4,0,0,1,21],
-"exceptionSteinberg_1_1Vst_1_1StringResult.html#a5846f06504dc4625283cd31b524a5f1c":[4,0,0,1,21,2],
-"exceptionSteinberg_1_1Vst_1_1StringResult.html#a664997bd1f020b18ef7dbd1193b5bef5":[4,0,0,1,21,4],
-"exceptionSteinberg_1_1Vst_1_1StringResult.html#a9196305174afe4846ca762869408f4c2":[4,0,0,1,21,1],
-"exceptionSteinberg_1_1Vst_1_1StringResult.html#aceeefd83ecd3c2384778ac88c22cf96b":[4,0,0,1,21,3],
-"exceptionSteinberg_1_1Vst_1_1StringResult.html#aed655be6be495be7869040dcdf77a0b3":[4,0,0,1,21,0],
+"exceptionSteinberg_1_1Vst_1_1StringResult.html":[4,0,0,1,23],
+"exceptionSteinberg_1_1Vst_1_1StringResult.html#a5846f06504dc4625283cd31b524a5f1c":[4,0,0,1,23,2],
+"exceptionSteinberg_1_1Vst_1_1StringResult.html#a664997bd1f020b18ef7dbd1193b5bef5":[4,0,0,1,23,4],
+"exceptionSteinberg_1_1Vst_1_1StringResult.html#a9196305174afe4846ca762869408f4c2":[4,0,0,1,23,1],
+"exceptionSteinberg_1_1Vst_1_1StringResult.html#aceeefd83ecd3c2384778ac88c22cf96b":[4,0,0,1,23,3],
+"exceptionSteinberg_1_1Vst_1_1StringResult.html#aed655be6be495be7869040dcdf77a0b3":[4,0,0,1,23,0],
 "files.html":[5,0],
-"functions.html":[4,3,0],
 "functions.html":[4,3,0,0],
+"functions.html":[4,3,0],
 "functions_0x62.html":[4,3,0,1],
 "functions_0x63.html":[4,3,0,2],
 "functions_0x64.html":[4,3,0,3],
@@ -216,38 +249,5 @@ var NAVTREEINDEX3 =
 "functions_0x78.html":[4,3,0,22],
 "functions_0x79.html":[4,3,0,23],
 "functions_0x7e.html":[4,3,0,24],
-"functions_enum.html":[4,3,4],
-"functions_eval.html":[4,3,5],
-"functions_func.html":[4,3,1],
-"functions_func.html":[4,3,1,0],
-"functions_func_0x62.html":[4,3,1,1],
-"functions_func_0x63.html":[4,3,1,2],
-"functions_func_0x64.html":[4,3,1,3],
-"functions_func_0x65.html":[4,3,1,4],
-"functions_func_0x66.html":[4,3,1,5],
-"functions_func_0x67.html":[4,3,1,6],
-"functions_func_0x68.html":[4,3,1,7],
-"functions_func_0x69.html":[4,3,1,8],
-"functions_func_0x6c.html":[4,3,1,9],
-"functions_func_0x6d.html":[4,3,1,10],
-"functions_func_0x6e.html":[4,3,1,11],
-"functions_func_0x6f.html":[4,3,1,12],
-"functions_func_0x70.html":[4,3,1,13],
-"functions_func_0x71.html":[4,3,1,14],
-"functions_func_0x72.html":[4,3,1,15],
-"functions_func_0x73.html":[4,3,1,16],
-"functions_func_0x74.html":[4,3,1,17],
-"functions_func_0x75.html":[4,3,1,18],
-"functions_func_0x76.html":[4,3,1,19],
-"functions_func_0x77.html":[4,3,1,20],
-"functions_func_0x78.html":[4,3,1,21],
-"functions_func_0x7e.html":[4,3,1,22],
-"functions_prop.html":[4,3,6],
-"functions_type.html":[4,3,3],
-"functions_vars.html":[4,3,2],
-"globals.html":[5,1,0],
-"globals_defs.html":[5,1,5],
-"globals_enum.html":[5,1,4],
-"globals_func.html":[5,1,1],
-"globals_type.html":[5,1,3]
+"functions_enum.html":[4,3,4]
 };
