@@ -8,7 +8,7 @@ var searchData=
   ['paramchanges',['ParamChanges',['../classSteinberg_1_1Vst_1_1ParamChanges.html#a3d64a0fd4bd7066dc9d2ae1bfa495572',1,'Steinberg::Vst::ParamChanges']]],
   ['parameter',['Parameter',['../classSteinberg_1_1Vst_1_1Parameter.html',1,'Steinberg::Vst']]],
   ['parameter',['Parameter',['../structSteinberg_1_1Vst_1_1SampleAccurate_1_1Parameter.html',1,'Steinberg::Vst::SampleAccurate']]],
-  ['parameter',['Parameter',['../classSteinberg_1_1Vst_1_1Parameter.html#a722d0b273a6e3633c189fb21eaaa483c',1,'Steinberg::Vst::Parameter::Parameter()'],['../classSteinberg_1_1Vst_1_1Parameter.html#a388e837bf6198abab80b877ca32b5e26',1,'Steinberg::Vst::Parameter::Parameter(const ParameterInfo &amp;)'],['../classSteinberg_1_1Vst_1_1Parameter.html#a75669d5409d1f3c14d0786633330046e',1,'Steinberg::Vst::Parameter::Parameter(const TChar *title, ParamID tag, const TChar *units=nullptr, ParamValue defaultValueNormalized=0., int32 stepCount=0, int32 flags=ParameterInfo::kCanAutomate, UnitID unitID=kRootUnitId, const TChar *shortTitle=nullptr)'],['../structSteinberg_1_1Vst_1_1SampleAccurate_1_1Parameter.html#ad3d81d5f760d49289f4d673db08021e5',1,'Steinberg::Vst::SampleAccurate::Parameter::Parameter()'],['../classSteinberg_1_1Vst_1_1ProgramList.html#a358b386509845867bf922db4a27535c6',1,'Steinberg::Vst::ProgramList::parameter()']]],
+  ['parameter',['parameter',['../classSteinberg_1_1Vst_1_1ProgramList.html#a358b386509845867bf922db4a27535c6',1,'Steinberg::Vst::ProgramList::parameter()'],['../classSteinberg_1_1Vst_1_1Parameter.html#a722d0b273a6e3633c189fb21eaaa483c',1,'Steinberg::Vst::Parameter::Parameter()'],['../classSteinberg_1_1Vst_1_1Parameter.html#a388e837bf6198abab80b877ca32b5e26',1,'Steinberg::Vst::Parameter::Parameter(const ParameterInfo &amp;)'],['../classSteinberg_1_1Vst_1_1Parameter.html#a75669d5409d1f3c14d0786633330046e',1,'Steinberg::Vst::Parameter::Parameter(const TChar *title, ParamID tag, const TChar *units=nullptr, ParamValue defaultValueNormalized=0., int32 stepCount=0, int32 flags=ParameterInfo::kCanAutomate, UnitID unitID=kRootUnitId, const TChar *shortTitle=nullptr)'],['../structSteinberg_1_1Vst_1_1SampleAccurate_1_1Parameter.html#ad3d81d5f760d49289f4d673db08021e5',1,'Steinberg::Vst::SampleAccurate::Parameter::Parameter()']]],
   ['parameterchange',['ParameterChange',['../structSteinberg_1_1Vst_1_1ParameterChangeTransfer_1_1ParameterChange.html',1,'Steinberg::Vst::ParameterChangeTransfer']]],
   ['parameterchanges',['ParameterChanges',['../classSteinberg_1_1Vst_1_1ParameterChanges.html',1,'Steinberg::Vst']]],
   ['parameterchanges',['ParameterChanges',['../classSteinberg_1_1Vst_1_1ParameterChanges.html#ab02ba6d7a0043fecec571f8c4bbae516',1,'Steinberg::Vst::ParameterChanges']]],
@@ -16,8 +16,8 @@ var searchData=
   ['parameterchanges_2eh',['parameterchanges.h',['../parameterchanges_8h.html',1,'']]],
   ['parameterchangetransfer',['ParameterChangeTransfer',['../classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html',1,'Steinberg::Vst']]],
   ['parameterchangetransfer',['ParameterChangeTransfer',['../classSteinberg_1_1Vst_1_1ParameterChangeTransfer.html#a8eb5993e076e7fbac47a9713a8083fd0',1,'Steinberg::Vst::ParameterChangeTransfer']]],
-  ['parametercontainer',['ParameterContainer',['../classSteinberg_1_1Vst_1_1ParameterContainer.html#a754120b3ba17224055c6de192ec053a2',1,'Steinberg::Vst::ParameterContainer']]],
   ['parametercontainer',['ParameterContainer',['../classSteinberg_1_1Vst_1_1ParameterContainer.html',1,'Steinberg::Vst']]],
+  ['parametercontainer',['ParameterContainer',['../classSteinberg_1_1Vst_1_1ParameterContainer.html#a754120b3ba17224055c6de192ec053a2',1,'Steinberg::Vst::ParameterContainer']]],
   ['parameterflags',['ParameterFlags',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ParameterInfo.html#ae3a5143ca8d0e271dbc259645a4ae645',1,'Steinberg::Vst::ParameterInfo']]],
   ['parameterinfo',['ParameterInfo',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ParameterInfo.html',1,'Steinberg::Vst']]],
   ['parameterptrvector',['ParameterPtrVector',['../classSteinberg_1_1Vst_1_1ParameterContainer.html#a6c53528dbca2a65e9fd7e368c4e17b27',1,'Steinberg::Vst::ParameterContainer']]],
@@ -27,8 +27,8 @@ var searchData=
   ['parametervaluequeue',['ParameterValueQueue',['../classSteinberg_1_1Vst_1_1ParameterValueQueue.html',1,'Steinberg::Vst']]],
   ['parametervaluequeue',['ParameterValueQueue',['../classSteinberg_1_1Vst_1_1ParameterValueQueue.html#a5a1a3c9dbce87993a2ef498ffd2102b0',1,'Steinberg::Vst::ParameterValueQueue']]],
   ['paramid',['paramID',['../classSteinberg_1_1Vst_1_1ParameterValueQueue.html#a044984f36e927dae9c14ca9d8d787a15',1,'Steinberg::Vst::ParameterValueQueue']]],
-  ['parampoint',['ParamPoint',['../classSteinberg_1_1Vst_1_1ParamPoint.html#a1bf2279035479a36b3e1520bf4aef893',1,'Steinberg::Vst::ParamPoint']]],
   ['parampoint',['ParamPoint',['../classSteinberg_1_1Vst_1_1ParamPoint.html',1,'Steinberg::Vst']]],
+  ['parampoint',['ParamPoint',['../classSteinberg_1_1Vst_1_1ParamPoint.html#a1bf2279035479a36b3e1520bf4aef893',1,'Steinberg::Vst::ParamPoint']]],
   ['params',['params',['../classSteinberg_1_1Vst_1_1ParameterContainer.html#a09ad76517b311128144d1a5d0dbfee99',1,'Steinberg::Vst::ParameterContainer']]],
   ['parentunitid',['parentUnitId',['../../vstinterfaces/structSteinberg_1_1Vst_1_1UnitInfo.html#a5cd97a596c57f5f28ebad702f2d6f06a',1,'Steinberg::Vst::UnitInfo']]],
   ['parse',['parse',['../structVST3_1_1Version.html#aa3c108150e67944cf502263146882575',1,'VST3::Version']]],
@@ -83,8 +83,8 @@ var searchData=
   ['predefined_20preset_20attributes',['Predefined Preset Attributes',['../../vstinterfaces/group__presetAttributes.html',1,'']]],
   ['presetbrowserviewcontroller_2eh',['PresetBrowserViewController.h',['../PresetBrowserViewController_8h.html',1,'']]],
   ['presetbrowserviewcontroller_2emm',['PresetBrowserViewController.mm',['../PresetBrowserViewController_8mm.html',1,'']]],
-  ['presetfile',['PresetFile',['../classSteinberg_1_1Vst_1_1PresetFile.html#a9db1b48345e92320b0dffc446d5e3483',1,'Steinberg::Vst::PresetFile']]],
   ['presetfile',['PresetFile',['../classSteinberg_1_1Vst_1_1PresetFile.html',1,'Steinberg::Vst']]],
+  ['presetfile',['PresetFile',['../classSteinberg_1_1Vst_1_1PresetFile.html#a9db1b48345e92320b0dffc446d5e3483',1,'Steinberg::Vst::PresetFile']]],
   ['presetmanager',['PresetManager',['../classSteinberg_1_1Vst_1_1InterAppAudio_1_1PresetManager.html#a40e63f530976a9ce740373e806bd08d6',1,'Steinberg::Vst::InterAppAudio::PresetManager']]],
   ['presetmanager',['PresetManager',['../classSteinberg_1_1Vst_1_1InterAppAudio_1_1PresetManager.html',1,'Steinberg::Vst::InterAppAudio']]],
   ['presetmanager_2eh',['PresetManager.h',['../PresetManager_8h.html',1,'']]],
@@ -93,14 +93,15 @@ var searchData=
   ['presetsaveviewcontroller_2emm',['PresetSaveViewController.mm',['../PresetSaveViewController_8mm.html',1,'']]],
   ['pressure',['pressure',['../../vstinterfaces/structSteinberg_1_1Vst_1_1PolyPressureEvent.html#ac870e1249bab4a2a68cc4126761d24ef',1,'Steinberg::Vst::PolyPressureEvent::pressure()'],['../structSteinberg_1_1Vst_1_1MPE_1_1Setup.html#ac74d3877c4ed65e4dbd0b3ce6da64f5f',1,'Steinberg::Vst::MPE::Setup::pressure()']]],
   ['print',['print',['../../base/classSteinberg_1_1FUID.html#a87f395d2dab31085a814b066b94e2f0a',1,'Steinberg::FUID::print(int32 style, char8 *string=nullptr, size_t stringBufferSize=0) const '],['../../base/classSteinberg_1_1FUID.html#af4c3e90529c90252f58d856dfbf43c6a',1,'Steinberg::FUID::print(char8 *string=nullptr, int32 style=kINLINE_UID) const ']]],
+  ['printerror',['printError',['../classSteinberg_1_1Vst_1_1PlugProvider.html#abfa14a169f62d20586d1d173d7af068c',1,'Steinberg::Vst::PlugProvider']]],
   ['printfloat',['printFloat',['../../base/classSteinberg_1_1UString.html#a0444f6da111b2df3c6289775e3eb24b6',1,'Steinberg::UString']]],
   ['printint',['printInt',['../../base/classSteinberg_1_1UString.html#ab1482d79e1ddf9a1cff1c41ea93df50e',1,'Steinberg::UString']]],
   ['printtestheader',['printTestHeader',['../classSteinberg_1_1Vst_1_1TestBase.html#aa2a890cf23bc6df3266783a3d8e4da09',1,'Steinberg::Vst::TestBase']]],
   ['process',['process',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IAudioProcessor.html#a6b98eb31cf38ba96a28b303c13c64e13',1,'Steinberg::Vst::IAudioProcessor::process()'],['../classSteinberg_1_1Vst_1_1AudioEffect.html#a2a13e09cc9ec3dd1b8617a38e3c07af5',1,'Steinberg::Vst::AudioEffect::process()'],['../classSteinberg_1_1Vst_1_1BypassProcessor.html#a161773ebfd666a2c9c5ceb7764da3fec',1,'Steinberg::Vst::BypassProcessor::process()'],['../structSteinberg_1_1Vst_1_1BypassProcessor_1_1Delay.html#a527d5a9fd900143afb37fd62da983285',1,'Steinberg::Vst::BypassProcessor::Delay::process()'],['../classSteinberg_1_1Vst_1_1SingleComponentEffect.html#adc63b47c5958e737abb364f126a7391f',1,'Steinberg::Vst::SingleComponentEffect::process()'],['../classSteinberg_1_1Vst_1_1ProcessDataSlicer.html#a8a5d3a26394df1031ca6a30c243e9565',1,'Steinberg::Vst::ProcessDataSlicer::process()']]],
   ['processcontext',['processContext',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ProcessData.html#ad27334aa1361d4ff3b139ca305bf1fad',1,'Steinberg::Vst::ProcessData']]],
   ['processcontext',['ProcessContext',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ProcessContext.html',1,'Steinberg::Vst']]],
-  ['processcontextrequirements',['ProcessContextRequirements',['../classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#ae40c5b12ded747e7f7ab4d52bd7c8907',1,'Steinberg::Vst::ProcessContextRequirements::ProcessContextRequirements()'],['../classSteinberg_1_1Vst_1_1AudioEffect.html#acf51f81f4a57d1be775b5dd4ad64734b',1,'Steinberg::Vst::AudioEffect::processContextRequirements()'],['../classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a2aaa8a8f65932a7e8157ef6a251ddd6f',1,'Steinberg::Vst::SingleComponentEffect::processContextRequirements()']]],
   ['processcontextrequirements',['ProcessContextRequirements',['../classSteinberg_1_1Vst_1_1ProcessContextRequirements.html',1,'Steinberg::Vst']]],
+  ['processcontextrequirements',['ProcessContextRequirements',['../classSteinberg_1_1Vst_1_1ProcessContextRequirements.html#ae40c5b12ded747e7f7ab4d52bd7c8907',1,'Steinberg::Vst::ProcessContextRequirements::ProcessContextRequirements()'],['../classSteinberg_1_1Vst_1_1AudioEffect.html#acf51f81f4a57d1be775b5dd4ad64734b',1,'Steinberg::Vst::AudioEffect::processContextRequirements()'],['../classSteinberg_1_1Vst_1_1SingleComponentEffect.html#a2aaa8a8f65932a7e8157ef6a251ddd6f',1,'Steinberg::Vst::SingleComponentEffect::processContextRequirements()']]],
   ['processcontextrequirements_2eh',['processcontextrequirements.h',['../processcontextrequirements_8h.html',1,'']]],
   ['processdata',['ProcessData',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ProcessData.html#a100f97803b72565daedee80e34bbb7f0',1,'Steinberg::Vst::ProcessData']]],
   ['processdata',['ProcessData',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ProcessData.html',1,'Steinberg::Vst']]],
@@ -120,19 +121,19 @@ var searchData=
   ['programindexmap',['ProgramIndexMap',['../classSteinberg_1_1Vst_1_1EditControllerEx1.html#a1926d11ac5eb67ab443e956596b136bf',1,'Steinberg::Vst::EditControllerEx1::ProgramIndexMap()'],['../classSteinberg_1_1Vst_1_1EditControllerEx1.html#adff4e706a786b881134df97ce6755050',1,'Steinberg::Vst::EditControllerEx1::programIndexMap()']]],
   ['programinfos',['programInfos',['../classSteinberg_1_1Vst_1_1ProgramList.html#a932cfb942e9ea765480dbd9524fed209',1,'Steinberg::Vst::ProgramList']]],
   ['programinfovector',['ProgramInfoVector',['../classSteinberg_1_1Vst_1_1ProgramList.html#a43790e03c786a44ac4501bf277e660e6',1,'Steinberg::Vst::ProgramList']]],
-  ['programlist',['ProgramList',['../classSteinberg_1_1Vst_1_1ProgramList.html',1,'Steinberg::Vst']]],
   ['programlist',['ProgramList',['../classSteinberg_1_1Vst_1_1ProgramList.html#a064d4941eb4a37a951ba11db619139a1',1,'Steinberg::Vst::ProgramList::ProgramList(const String128 name, ProgramListID listId, UnitID unitId)'],['../classSteinberg_1_1Vst_1_1ProgramList.html#af096804513689f8f3e210b22c69df785',1,'Steinberg::Vst::ProgramList::ProgramList(const ProgramList &amp;programList)']]],
+  ['programlist',['ProgramList',['../classSteinberg_1_1Vst_1_1ProgramList.html',1,'Steinberg::Vst']]],
   ['programlistid',['programListId',['../../vstinterfaces/structSteinberg_1_1Vst_1_1UnitInfo.html#afef3772baf373fc218c8b091d9eeb6bb',1,'Steinberg::Vst::UnitInfo']]],
   ['programlistinfo',['ProgramListInfo',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ProgramListInfo.html',1,'Steinberg::Vst']]],
   ['programlists',['programLists',['../classSteinberg_1_1Vst_1_1EditControllerEx1.html#a215db3e492d1cc53b75f16239f2afc23',1,'Steinberg::Vst::EditControllerEx1']]],
   ['programlistwithpitchnames',['ProgramListWithPitchNames',['../classSteinberg_1_1Vst_1_1ProgramListWithPitchNames.html',1,'Steinberg::Vst']]],
   ['programlistwithpitchnames',['ProgramListWithPitchNames',['../classSteinberg_1_1Vst_1_1ProgramListWithPitchNames.html#ac35cdc8c766d4de4e9677d278c01382a',1,'Steinberg::Vst::ProgramListWithPitchNames']]],
   ['programnames',['programNames',['../classSteinberg_1_1Vst_1_1ProgramList.html#a374d0d28218114229c2469dec596b9ff',1,'Steinberg::Vst::ProgramList']]],
-  ['programs',['Programs',['../structVST3_1_1Vst2xState.html#a6a250ebf1916f9297dbedc8fc488ddb4',1,'VST3::Vst2xState::Programs()'],['../structVST3_1_1Vst2xState.html#a69649642bc65a780bbab905b1c57aba7',1,'VST3::Vst2xState::programs()']]],
+  ['programs',['programs',['../structVST3_1_1Vst2xState.html#a69649642bc65a780bbab905b1c57aba7',1,'VST3::Vst2xState::programs()'],['../structVST3_1_1Vst2xState.html#a6a250ebf1916f9297dbedc8fc488ddb4',1,'VST3::Vst2xState::Programs()']]],
   ['programvalues',['ProgramValues',['../structVST3_1_1Vst2xProgram.html#a2bc036956ebdabf74742defb97bee043',1,'VST3::Vst2xProgram']]],
   ['progresstype',['ProgressType',['../../vstinterfaces/classSteinberg_1_1Vst_1_1IProgress.html#a69d16526a64609e721e3a65f3353d666',1,'Steinberg::Vst::IProgress']]],
   ['projecttimemusic',['projectTimeMusic',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ProcessContext.html#a4c1e16437e0c0858fa5288107e5b187f',1,'Steinberg::Vst::ProcessContext']]],
   ['projecttimesamples',['projectTimeSamples',['../../vstinterfaces/structSteinberg_1_1Vst_1_1ProcessContext.html#a359d649ae34734b9876ad5a6a2f691f7',1,'Steinberg::Vst::ProcessContext']]],
-  ['ptr',['ptr',['../../base/classSteinberg_1_1IPtr.html#a7c145f458643ff993b929f236d4a2ac0',1,'Steinberg::FUnknownPtr::ptr()'],['../classVST3_1_1Hosting_1_1Module.html#a6b597424e1e3214bbaa370140e784b15',1,'VST3::Hosting::Module::Ptr()'],['../vst2persistence_8cpp.html#ab6679b8a3625461c4f6c523048234022',1,'ptr():&#160;vst2persistence.cpp']]],
+  ['ptr',['Ptr',['../classVST3_1_1Hosting_1_1Module.html#a6b597424e1e3214bbaa370140e784b15',1,'VST3::Hosting::Module::Ptr()'],['../../base/classSteinberg_1_1IPtr.html#a7c145f458643ff993b929f236d4a2ac0',1,'Steinberg::FUnknownPtr::ptr()'],['../vst2persistence_8cpp.html#ab6679b8a3625461c4f6c523048234022',1,'ptr():&#160;vst2persistence.cpp']]],
   ['push',['push',['../classSteinberg_1_1OneReaderOneWriter_1_1RingBuffer.html#abbabbc28c5f4f8830e2ed06b19ea9549',1,'Steinberg::OneReaderOneWriter::RingBuffer::push(ItemT &amp;&amp;item) noexcept'],['../classSteinberg_1_1OneReaderOneWriter_1_1RingBuffer.html#a91f11a2997e9e08387ea391c50fc1e98',1,'Steinberg::OneReaderOneWriter::RingBuffer::push(const ItemT &amp;item) noexcept']]]
 ];
